@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Ilya Kotov                                      *
+ *   Copyright (C) 2007-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,13 +25,10 @@
 
 #include "srconverter.h"
 
-SRConverter::SRConverter(QObject* parent) : Effect(parent)
+SRConverter::SRConverter() : Effect()
 {
-    m_isSrcAlloc = FALSE;
     int converter_type_array[] = {SRC_SINC_BEST_QUALITY, SRC_SINC_MEDIUM_QUALITY, SRC_SINC_FASTEST,
                                   SRC_ZERO_ORDER_HOLD,  SRC_LINEAR};
-    m_srcIn = 0;
-    m_srcOut = 0;
     m_src_state = 0;
     m_srcError = 0;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
@@ -48,74 +45,66 @@ SRConverter::~SRConverter()
     m_src_data.end_of_input = 0;
     m_src_data.input_frames = 0;
     m_src_data.output_frames = 0;
-    if (m_isSrcAlloc)
-    {
-        free(m_srcIn);
-        free(m_srcOut);
-        free(m_wOut);
-        m_isSrcAlloc = FALSE;
-    }
 }
 
-ulong SRConverter::process(char *in_data, const ulong size, char **out_data)
+void SRConverter::applyEffect(Buffer *b)
 {
-    if (m_isSrcAlloc)
+    if (m_src_state && b->nbytes > 0)
     {
-        free(m_srcIn);
-        free(m_srcOut);
-        free(m_wOut);
-        m_isSrcAlloc = FALSE;
-    }
-    ulong wbytes = 0;
-
-    if (m_src_state && size > 0)
-    {
-        int lrLength = size/2;
-        int overLrLength= (int)floor(lrLength*(m_src_data.src_ratio+1));
-        m_srcIn = (float*) malloc(sizeof(float)*lrLength);
-        m_srcOut = (float*) malloc(sizeof(float)*overLrLength);
-        m_wOut = (short int*) malloc(sizeof(short int)*overLrLength);
-        src_short_to_float_array((short int*)in_data, m_srcIn, lrLength);
-        m_isSrcAlloc = TRUE;
-        m_src_data.data_in = m_srcIn;
-        m_src_data.data_out = m_srcOut;
+        m_src_data.input_frames = b->nbytes / 2 / channels();
+        m_src_data.data_in = new float [m_src_data.input_frames * channels()];
+        m_src_data.output_frames = m_src_data.src_ratio * m_src_data.input_frames + 1;
         m_src_data.end_of_input = 0;
-        m_src_data.input_frames = lrLength/2;
-        m_src_data.output_frames = overLrLength/2;
+        m_src_data.data_out = new float [m_src_data.output_frames * channels()];
+        src_short_to_float_array((short*) b->data, m_src_data.data_in,
+                                 m_src_data.input_frames * channels());
         if ((m_srcError = src_process(m_src_state, &m_src_data)) > 0)
         {
             qWarning("SRConverter: src_process(): %s\n", src_strerror(m_srcError));
         }
         else
         {
-            src_float_to_short_array(m_srcOut, m_wOut, m_src_data.output_frames_gen*2);
-            wbytes = m_src_data.output_frames_gen*4;
-            *out_data = new char[wbytes];
-            memcpy(*out_data, (char*) m_wOut, wbytes);
+            qint16 *out_data = new qint16 [m_src_data.output_frames_gen * channels()];
+            src_float_to_short_array(m_src_data.data_out, out_data,
+                                     m_src_data.output_frames_gen*channels());
+            b->nbytes = m_src_data.output_frames_gen * channels() * 2;
+            if(b->nbytes > b->size)
+            {
+                delete [] b->data;
+                b->data = (uchar *) out_data;
+            }
+            else
+            {
+                memcpy(b->data, out_data, b->nbytes);
+                delete [] out_data;
+            }
+
         }
+        delete [] m_src_data.data_in;
+        delete [] m_src_data.data_out;
     }
-    return wbytes;
 }
 
-void SRConverter::configure(quint32 freq, int chan, int res)
+void SRConverter::configure(quint32 freq, int chan,  Qmmp::AudioFormat format)
 {
     freeSRC();
-    uint rate = freq;
+    if(freq != m_overSamplingFs)
     {
-        m_src_state = src_new(m_converter_type, 2, &m_srcError);
+        m_src_state = src_new(m_converter_type, chan, &m_srcError);
         if (m_src_state)
         {
-            m_src_data.src_ratio = (float)m_overSamplingFs/(float)rate;
-            rate = m_overSamplingFs;
+            m_src_data.src_ratio = (float)m_overSamplingFs/(float)freq;
+            src_set_ratio(m_src_state, m_src_data.src_ratio);
         }
         else
             qDebug("SRConverter: src_new(): %s", src_strerror(m_srcError));
     }
-    Effect::configure(m_overSamplingFs, chan, res);
+    Effect::configure(m_overSamplingFs, chan, format);
 }
 
 void SRConverter::freeSRC()
 {
-    if (m_src_state != NULL)
+    if (m_src_state)
         m_src_state = src_delete(m_src_state);
+    m_src_state = 0;
 }
