@@ -39,7 +39,7 @@ void QmmpFileDialog::handleSelected(/*const QStringList& s */)
 
 bool QmmpFileDialog::modal()const
 {
-    return FALSE;
+    return false;
 }
 
 QmmpFileDialog::~QmmpFileDialog()
@@ -120,7 +120,7 @@ const FileDialogProperties QmmpFileDialogFactory::properties() const
     FileDialogProperties properties;
     properties.name = tr("Qmmp File Dialog");
     properties.shortName = "qmmp_dialog";
-    properties.hasAbout =TRUE;
+    properties.hasAbout =true;
     return properties;
 }
 
@@ -143,4 +143,4 @@ QTranslator *QmmpFileDialogFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(QmmpFileDialogFactory)
+Q_EXPORT_PLUGIN2(qmmpfiledialog, QmmpFileDialogFactory)
