@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fi">
+<TS version="2.0" language="cs">
 <context>
     <name>QmmpFileDialog</name>
     <message>
@@ -104,13 +104,10 @@ Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
-        <source>already exists.</source>
-        <translation>již existuje.</translation>
-    </message>
-    <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
-        <source>Do you want to replace it?</source>
-        <translation>Chcete jej nahradit?</translation>
+        <source>%1 already exists.
+Do you want to replace it?</source>
+        <translation>%1 již existuje.
+Přejete si jej nahradit?</translation>
     </message>
 </context>
 </TS>
