@@ -1,12 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fi">
+<TS version="2.0" language="de_DE">
 <context>
     <name>QmmpFileDialog</name>
     <message>
         <location filename="../qmmpfiledialog.ui" line="13"/>
         <source>Add Files</source>
-        <translation>Dateien hinzufügen</translation>
+        <translation>Datei(en) hinzufügen</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialog.ui" line="37"/>
@@ -19,7 +19,7 @@
         <location filename="../qmmpfiledialog.ui" line="72"/>
         <location filename="../qmmpfiledialog.ui" line="97"/>
         <source>...</source>
-        <translation>...</translation>
+        <translation>…</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialog.ui" line="50"/>
@@ -104,13 +104,10 @@ Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
-        <source>already exists.</source>
-        <translation>existiert bereits.</translation>
-    </message>
-    <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
-        <source>Do you want to replace it?</source>
-        <translation>Möchten Sie es ersetzen?</translation>
+        <source>%1 already exists.
+Do you want to replace it?</source>
+        <translation>%1 existiert bereits.
+Möchten Sie es ersetzen?</translation>
     </message>
 </context>
 </TS>
