@@ -102,12 +102,8 @@ Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
     </message>
     <message>
         <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
-        <source>already exists.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
-        <source>Do you want to replace it?</source>
+        <source>%1 already exists.
+Do you want to replace it?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
