@@ -104,13 +104,10 @@ Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
     </message>
     <message>
         <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
-        <source>already exists.</source>
-        <translation>уже существует.</translation>
-    </message>
-    <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
-        <source>Do you want to replace it?</source>
-        <translation>Заменить?</translation>
+        <source>%1 already exists.
+Do you want to replace it?</source>
+        <translation>%1 уже существует.
+Заменить?</translation>
     </message>
 </context>
 </TS>
