@@ -104,13 +104,9 @@ Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
-        <source>already exists.</source>
-        <translation>早已存在。</translation>
-    </message>
-    <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
-        <source>Do you want to replace it?</source>
-        <translation>您想替換它嗎？</translation>
+        <source>%1 already exists.
+Do you want to replace it?</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
