@@ -45,51 +45,35 @@
 <context>
     <name>LyricsWindow</name>
     <message>
-        <location filename="../lyricswindow.cpp" line="113"/>
+        <location filename="../lyricswindow.cpp" line="63"/>
+        <source>Done</source>
+        <translation>Atlikta</translation>
+    </message>
+    <message>
+        <location filename="../lyricswindow.cpp" line="66"/>
+        <source>Error</source>
+        <translation>Klaida</translation>
+    </message>
+    <message>
+        <location filename="../lyricswindow.cpp" line="97"/>
         <source>Lyrics: %1 - %2</source>
         <translation>Dainos tekstas: %1 - %2</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="88"/>
-        <location filename="../lyricswindow.ui" line="67"/>
+        <location filename="../lyricswindow.ui" line="60"/>
         <source>No connection</source>
         <translation>Nėra ryšio</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="75"/>
+        <location filename="../lyricswindow.cpp" line="85"/>
         <source>Not found</source>
         <translation>Nerasta</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="91"/>
-        <source>Looking up host...</source>
-        <translation>Ieškau serverio...</translation>
-    </message>
-    <message>
-        <location filename="../lyricswindow.cpp" line="94"/>
-        <source>Connecting...</source>
-        <translation>Susijungiu...</translation>
-    </message>
-    <message>
-        <location filename="../lyricswindow.cpp" line="97"/>
-        <source>Sending request...</source>
-        <translation>Siunčiu užklausą...</translation>
-    </message>
-    <message>
-        <location filename="../lyricswindow.cpp" line="100"/>
+        <location filename="../lyricswindow.cpp" line="96"/>
         <source>Receiving</source>
         <translation>Gaunu</translation>
     </message>
-    <message>
-        <location filename="../lyricswindow.cpp" line="103"/>
-        <source>Connected</source>
-        <translation>Susijungiau</translation>
-    </message>
-    <message>
-        <location filename="../lyricswindow.cpp" line="106"/>
-        <source>Closing connection...</source>
-        <translation>Atsijungiu...</translation>
-    </message>
     <message>
         <location filename="../lyricswindow.ui" line="14"/>
         <source>Lyrics Plugin</source>
@@ -110,10 +94,5 @@
         <source>Search</source>
         <translation>Ieškoti</translation>
     </message>
-    <message>
-        <location filename="../lyricswindow.ui" line="87"/>
-        <source>Close</source>
-        <translation>Uždaryti</translation>
-    </message>
 </context>
 </TS>
