@@ -29,9 +29,9 @@ const GeneralProperties NotifierFactory::properties() const
     GeneralProperties properties;
     properties.name = tr("Notifier Plugin");
     properties.shortName = "notifier";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = TRUE;
-    properties.visibilityControl = FALSE;
+    properties.hasAbout = true;
+    properties.hasSettings = true;
+    properties.visibilityControl = false;
     return properties;
 }
 
@@ -60,4 +60,4 @@ QTranslator *NotifierFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(NotifierFactory)
+Q_EXPORT_PLUGIN2(notifier,NotifierFactory)
