@@ -27,7 +27,10 @@
 #include <QSettings>
 #include <QDir>
 #include <QApplication>
+#include <QFont>
 #include <qmmp/soundcore.h>
+#include <qmmp/metadatamanager.h>
+#include <qmmpui/metadataformatter.h>
 
 #include "popupwidget.h"
 
@@ -37,35 +40,36 @@ PopupWidget::PopupWidget(QWidget *parent)
     setWindowFlags(Qt::X11BypassWindowManagerHint |
                    Qt::WindowStaysOnTopHint | Qt::Dialog | Qt::FramelessWindowHint);
     setFrameStyle(QFrame::Box | QFrame::Plain);
-    setAttribute(Qt::WA_QuitOnClose, FALSE);
-    QHBoxLayout *hlayout = new QHBoxLayout(this);
-    QLabel *pixlabel = new QLabel(this);
-    pixlabel->setPixmap(QPixmap(":/notifier_icon.png"));
-    pixlabel->setFixedSize(32,32);
-    hlayout->addWidget(pixlabel);
-    //layout
-    QVBoxLayout *vlayout = new QVBoxLayout();
-    hlayout->addLayout (vlayout);
-    setLayout(hlayout);
-    //first line
+    setAttribute(Qt::WA_QuitOnClose, false);
+    QHBoxLayout *hlayout = new QHBoxLayout(this); //layout
+    m_pixlabel = new QLabel(this);
+    m_pixlabel->setPixmap(QPixmap(":/notifier_icon.png"));
+    m_pixlabel->setFixedSize(32,32);
+    hlayout->addWidget(m_pixlabel);
+
     m_label1 = new QLabel(this);
-    vlayout->addWidget(m_label1);
-    //second line
-    m_label2 = new QLabel(this);
-    vlayout->addWidget(m_label2);
-    //resize(sizeHint()); //update size hint
+    hlayout->addWidget (m_label1);
+
     //settings
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.beginGroup("Notifier");
     int delay = settings.value("message_delay", 2000).toInt();
     m_pos = settings.value("message_pos", PopupWidget::BOTTOMLEFT).toUInt();
     setWindowOpacity(settings.value("opacity", 1.0).toDouble());
+    QString fontname = settings.value("font").toString();
+    m_coverSize = settings.value("cover_size", 64).toInt();
+    m_template = settings.value("template",DEFAULT_TEMPLATE).toString();
     settings.endGroup();
+    //font
+    QFont font;
+    if(!fontname.isEmpty())
+        font.fromString(fontname);
+    setFont(font);
     //timer
     m_timer = new QTimer(this);
     m_timer->setInterval(delay);
-    m_timer->setSingleShot (TRUE);
-    connect(m_timer, SIGNAL(timeout ()), SLOT(deleteLater()));
+    m_timer->setSingleShot (true);
+    connect(m_timer, SIGNAL(timeout ()), SLOT(hide()));
 }
 
 PopupWidget::~PopupWidget()
@@ -73,54 +77,59 @@ PopupWidget::~PopupWidget()
 
 void PopupWidget::mousePressEvent (QMouseEvent *)
 {
-    deleteLater();
+    hide();
 }
 
 void PopupWidget::showMetaData()
 {
     m_timer->stop();
+    QString title = m_template;
+
     SoundCore *core = SoundCore::instance();
-    QString title = core->metaData(Qmmp::TITLE);
-    if (title.isEmpty())
-        title = core->metaData(Qmmp::URL).section('/',-1);
     if (core->totalTime() > 0)
     {
-        title.append(" ");
-        title.append(QString("(%1:%2)").arg(core->totalTime()/60000).arg(core->totalTime()%60000/1000, 2, 10, QChar('0')));
-    }
-    m_label1->setText("<b>" + title + "</b>");
-
-    QString info = core->metaData(Qmmp::ARTIST);
-    if (!info.isEmpty() && !core->metaData(Qmmp::ALBUM).isEmpty())
-        info.append(" - " + core->metaData(Qmmp::ALBUM));
-    if (!info.isEmpty())
-    {
-        m_label2->setText(info);
-        m_label2->show();
+        int l = core->totalTime()/1000;
+        title.replace("%l",QString("%1:%2").arg(l/60).arg(l%60, 2, 10, QChar('0')));
     }
     else
-        m_label2->hide();
-    qApp->processEvents();
-    resize(sizeHint());
-    qApp->processEvents();
-    updatePosition();
-    qApp->processEvents();
+        title.replace("%l","");
+    MetaDataFormatter f(title);
+    title = f.parse(core->metaData());
+
+    m_label1->setText(title);
+
+    QPixmap pix = MetaDataManager::instance()->getCover(core->metaData(Qmmp::URL));
+    if(!pix.isNull())
+    {
+        m_pixlabel->setFixedSize(m_coverSize,m_coverSize);
+        m_pixlabel->setPixmap(pix.scaled(m_coverSize,m_coverSize));
+    }
+    else
+    {
+        m_pixlabel->setPixmap(QPixmap(":/notifier_icon.png"));
+        m_pixlabel->setFixedSize(32,32);
+    }
     show();
+    qApp->processEvents();
+    updateGeometry();
+    resize(sizeHint());
+    updatePosition();
     m_timer->start();
 }
 
 void PopupWidget::showVolume(int v)
 {
+    m_pixlabel->setPixmap(QPixmap(":/notifier_icon.png"));
+    m_pixlabel->setFixedSize(32,32);
     m_timer->stop();
+    m_label1->setAlignment(Qt::AlignVCenter);
     m_label1->setText("<b>" + tr("Volume:") + QString (" %1\%").arg(v)+ + "</b>");
 
-    m_label2->hide();
-    qApp->processEvents();
-    resize(sizeHint());
-    qApp->processEvents();
-    updatePosition();
-    qApp->processEvents();
     show();
+    qApp->processEvents();
+    updateGeometry();
+    resize(sizeHint());
+    updatePosition();
     m_timer->start();
 }
 
