@@ -21,10 +21,10 @@
 #define SETTINGSDIALOG_H
 
 #include <QDialog>
-
-
 #include "ui_settingsdialog.h"
 
+class Action;
+
 /**
 	@author Ilya Kotov <forkotov02@hotmail.ru>
 */
@@ -40,7 +40,13 @@ public:
 public slots:
     virtual void accept();
 
+private slots:
+    void setFont();
+    void insertExpression(QAction *);
+    void on_resetButton_clicked();
+
 private:
+    void createMenu();
     Ui::SettingsDialog ui;
     QMap<uint, QPushButton*> m_buttons;
 
