@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,59 +19,55 @@
  ***************************************************************************/
 
 #include <QMenu>
-#include <QHttp>
+#include <QNetworkAccessManager>
+#include <QNetworkRequest>
+#include <QNetworkProxy>
+#include <QNetworkReply>
 #include <QByteArray>
 #include <QCryptographicHash>
 #include <QUrl>
 #include <QTime>
+#include <QTimer>
 #include <QDateTime>
 #include <QDir>
 #include <qmmp/soundcore.h>
+#include <qmmp/qmmpsettings.h>
 #include <qmmp/qmmp.h>
-
 #include "scrobbler.h"
 
-#define PROTOCOL_VER "1.2"
+#define PROTOCOL_VER "1.2.1"
 #define CLIENT_ID "qmm"
-#define CLIENT_VER "0.2"
+#define CLIENT_VER "0.3"
 
 
 Scrobbler::Scrobbler(const QString &url,
                      const QString &login,
                      const QString &passw,
                      const QString &name,
-                     QObject *parent)
-        : QObject(parent)
+                     QObject *parent) : QObject(parent)
 {
-    m_http = new QHttp(this);
-    m_http->setHost(url, 80);
+    m_failure_count = 0;
+    m_handshake_count = 0;
+    m_http = new QNetworkAccessManager(this);
     m_state = Qmmp::Stopped;
     m_login = login;
     m_passw = passw;
     m_server = url;
     m_name = name;
-    //load global proxy settings
-    if (Qmmp::useProxy())
-        m_http->setProxy(Qmmp::proxy().host(),
-                         Qmmp::proxy().port(),
-                         Qmmp::useProxyAuth() ? Qmmp::proxy().userName() : QString(),
-                         Qmmp::useProxyAuth() ? Qmmp::proxy().password() : QString());
-
+    connect(QmmpSettings::instance(), SIGNAL(networkSettingsChanged()), SLOT(setupProxy()));
+    setupProxy();
     m_disabled = m_login.isEmpty() || m_passw.isEmpty();
     m_passw = QString(QCryptographicHash::hash(m_passw.toAscii(), QCryptographicHash::Md5).toHex());
-    connect(m_http, SIGNAL(requestFinished (int, bool)), SLOT(processResponse(int, bool)));
-    connect(m_http, SIGNAL(readyRead (const QHttpResponseHeader&)),
-            SLOT(readResponse(const QHttpResponseHeader&)));
-
+    connect(m_http, SIGNAL(finished (QNetworkReply *)), SLOT(processResponse(QNetworkReply *)));
     m_core = SoundCore::instance();
     connect (m_core, SIGNAL(metaDataChanged()), SLOT(updateMetaData()));
     connect (m_core, SIGNAL(stateChanged (Qmmp::State)), SLOT(setState(Qmmp::State)));
-
     m_time = new QTime();
     m_submitedSongs = 0;
-    m_handshakeid = 0;
-    m_submitid = 0;
-    m_notificationid = 0;
+    m_handshakeReply = 0;
+    m_submitReply = 0;
+    m_notificationReply = 0;
+    m_ua = QString("iScrobbler/1.5.1qmmp-plugins/%1").arg(Qmmp::strVersion()).toAscii();
 
     QFile file(QDir::homePath() +"/.qmmp/scrobbler_" + m_name + ".cache");
 
@@ -122,69 +118,39 @@ Scrobbler::Scrobbler(const QString &url,
 Scrobbler::~Scrobbler()
 {
     delete m_time;
-    QFile file(QDir::homePath() +"/.qmmp/scrobbler_" + m_name + ".cache");
-    if (m_songCache.isEmpty())
-    {
-        file.remove();
-        return;
-    }
-    file.open(QIODevice::WriteOnly);
-    foreach(SongInfo m, m_songCache)
-    {
-        file.write(QString("title=%1").arg(m.metaData(Qmmp::TITLE)).toUtf8() +"\n");
-        file.write(QString("artist=%1").arg(m.metaData(Qmmp::ARTIST)).toUtf8() +"\n");
-        file.write(QString("album=%1").arg(m.metaData(Qmmp::ALBUM)).toUtf8() +"\n");
-        file.write(QString("comment=%1").arg(m.metaData(Qmmp::COMMENT)).toUtf8() +"\n");
-        file.write(QString("genre=%1").arg(m.metaData(Qmmp::GENRE)).toUtf8() +"\n");
-        file.write(QString("year=%1").arg(m.metaData(Qmmp::YEAR)).toUtf8() +"\n");
-        file.write(QString("track=%1").arg(m.metaData(Qmmp::TRACK)).toUtf8() +"\n");
-        file.write(QString("length=%1").arg(m.length()).toUtf8() +"\n");
-        file.write(QString("time=%1").arg(m.timeStamp()).toUtf8() +"\n");
-    }
-    file.close();
+    syncCache();
 }
 
 void Scrobbler::setState(Qmmp::State state)
 {
     m_state = state;
-    if (m_disabled)
-        return;
     switch ((uint) state)
     {
     case Qmmp::Playing:
-    {
         m_start_ts = QDateTime::currentDateTime().toTime_t();
         m_time->restart();
-        if (!isReady() && m_handshakeid == 0)
+        if (!isReady() && !m_handshakeReply)
             handshake();
         break;
-    }
-    case Qmmp::Paused:
-    {
-        break;
-    }
     case Qmmp::Stopped:
-    {
         if (!m_song.metaData().isEmpty()
-                && ((m_time->elapsed ()/1000 > 240)
-                    || (m_time->elapsed ()/1000 > int(m_song.length()/2)))
-                && (m_time->elapsed ()/1000 > 60))
+            && ((m_time->elapsed ()/1000 > 240) || (m_time->elapsed ()/1000 > int(m_song.length()/2)))
+            && (m_time->elapsed ()/1000 > 60))
         {
             m_song.setTimeStamp(m_start_ts);
             m_songCache << m_song;
+            syncCache();
         }
 
         m_song.clear();
         if (m_songCache.isEmpty())
             break;
 
-        if (m_http->error() != QHttp::NoError)
-            m_http->clearPendingRequests ();
-
-        if (isReady() && m_submitid == 0)
+        if (isReady() && !m_submitReply)
             submit();
         break;
-    }
+    default:
+        ;
     }
 }
 
@@ -206,39 +172,54 @@ void Scrobbler::updateMetaData()
         metadata[Qmmp::ALBUM].replace("&", QUrl::toPercentEncoding("&"));
         metadata[Qmmp::TITLE].replace("&", QUrl::toPercentEncoding("&"));
         m_song = SongInfo(metadata, m_core->totalTime()/1000);
-        if (isReady() && m_notificationid == 0)
+        if (isReady() && !m_notificationReply && !m_submitReply)
             sendNotification(m_song);
     }
 }
 
-void Scrobbler::processResponse(int id, bool error)
+void Scrobbler::processResponse(QNetworkReply *reply)
 {
-    if (error)
-    {
-        qWarning("Scrobbler: %s", qPrintable(m_http->errorString ()));
-        //TODO hard failure handling
+    QString data;
+    if (reply->error() == QNetworkReply::NoError)
+        data = reply->readAll();
+    else
+        data = reply->errorString ();
 
-        if (id == m_submitid)
-            m_submitid = 0;
-        else if (id == m_handshakeid)
-            m_handshakeid = 0;
-        else if (id == m_notificationid)
-            m_notificationid = 0;
-        return;
+    data = data.trimmed();
+    if (data.startsWith("OK"))
+    {
+        m_failure_count = 0;
+        m_handshake_count = 0;
     }
-    QString str(m_array);
-    QStringList strlist = str.split("\n");
 
-    if (id == m_handshakeid)
+    if (reply == m_handshakeReply)
     {
-        m_handshakeid = 0;
+        m_submitUrl.clear();
+        m_session.clear();
+        m_nowPlayingUrl.clear();
+        m_failure_count = 0;
+        QStringList strlist = data.split("\n");
         if (!strlist[0].contains("OK") || strlist.size() < 4)
         {
-            qWarning("Scrobbler[%s]: handshake phase error: %s",qPrintable(m_name), qPrintable(strlist[0]));
-            //TODO: badtime handling
-            return;
+            qWarning("Scrobbler[%s]: handshake phase error", qPrintable(m_name));
+            m_disabled = true;
+            if(strlist[0].contains("BANNED"))
+                qWarning("Scrobbler[%s]: client has been banned", qPrintable(m_name));
+            else if(strlist[0].contains("BADAUTH"))
+                qWarning("Scrobbler[%s]: incorrect user/password", qPrintable(m_name));
+            else if(strlist[0].contains("BADTIME"))
+                qWarning("Scrobbler[%s]: incorrect system time", qPrintable(m_name));
+            else
+            {
+                qWarning("Scrobbler[%s]: service error: %s", qPrintable(m_name), qPrintable(strlist[0]));
+                m_disabled = false;
+                m_handshake_count++;
+                QTimer::singleShot (60000 * qMin(m_handshake_count^2, 120) , this, SLOT(handshake()));
+                qWarning("Scrobbler[%s]: waiting %d minutes...", qPrintable(m_name),
+                         qMin(m_handshake_count^2, 120));
+            }
         }
-        if (strlist.size() > 3) //process handshake response
+        else if (strlist.size() > 3) //process handshake response
         {
             qDebug("Scrobbler[%s]: reading handshake response",qPrintable(m_name));
             qDebug("Scrobbler[%s]: Session ID: %s",qPrintable(m_name),qPrintable(strlist[1]));
@@ -250,73 +231,111 @@ void Scrobbler::processResponse(int id, bool error)
             updateMetaData(); //send now-playing notification for already playing song
             if (!m_songCache.isEmpty()) //submit recent songs
                 submit();
-            return;
         }
     }
-    else if (id == m_submitid)
+    else if (reply == m_submitReply)
     {
-        m_submitid = 0;
-        if (!strlist[0].contains("OK"))
+        m_submitReply = 0;
+        if (!data.startsWith("OK"))
         {
-            qWarning("Scrobbler[%s]: submit error: %s",qPrintable(m_name), qPrintable(strlist[0]));
-            //TODO badsession handling
-            return;
+            qWarning("Scrobbler[%s]: submit error",qPrintable(m_name));
+            if(data.contains("BADSESSION"))
+            {
+                qWarning("Scrobbler[%s]: invalid session ID",qPrintable(m_name));
+                qWarning("Scrobbler[%s]: performing re-handshake",qPrintable(m_name));
+                handshake();
+            }
+            else
+            {
+                qWarning("Scrobbler[%s]: %s",qPrintable(m_name),qPrintable(data));
+                m_failure_count ++;
+            }
         }
-        qWarning("Scrobbler[%s]: submited %d song(s)",qPrintable(m_name), m_submitedSongs);
-        while (m_submitedSongs)
+        else
         {
-            m_submitedSongs--;
-            m_songCache.removeFirst ();
+            qDebug("Scrobbler[%s]: submited %d song(s)",qPrintable(m_name), m_submitedSongs);
+            while (m_submitedSongs)
+            {
+                m_submitedSongs--;
+                m_songCache.removeFirst ();
+            }
+            if (!m_songCache.isEmpty()) //submit remaining songs
+                submit();
+            else
+                updateMetaData();
         }
-        if (!m_songCache.isEmpty()) //submit remaining songs
-            submit();
     }
-    else if (id == m_notificationid)
+    else if (reply == m_notificationReply)
     {
-        m_notificationid = 0;
-        if (!strlist[0].contains("OK"))
+        m_notificationReply = 0;
+        if (!data.startsWith("OK"))
         {
-            qWarning("Scrobbler[%s]: notification error: %s",qPrintable(m_name), qPrintable(strlist[0]));
-            //TODO badsession handling
-            return;
+            qWarning("Scrobbler[%s]: notification error",qPrintable(m_name));
+            if(data.contains("BADSESSION"))
+            {
+                qWarning("Scrobbler[%s]: invalid session ID",qPrintable(m_name));
+                qWarning("Scrobbler[%s]: performing re-handshake",qPrintable(m_name));
+                handshake();
+            }
+            else
+            {
+                qWarning("Scrobbler[%s]: %s",qPrintable(m_name),qPrintable(data));
+                m_failure_count ++;
+            }
         }
-        qDebug("Scrobbler[%s]: Now-Playing notification done", qPrintable(m_name));
+        else
+            qDebug("Scrobbler[%s]: Now-Playing notification done", qPrintable(m_name));
     }
-    m_array.clear();
+    if(m_failure_count >= 3)
+    {
+        qWarning("Scrobbler[%s]: performing re-handshake",qPrintable(m_name));
+        handshake();
+    }
+    reply->deleteLater();
 }
 
-void Scrobbler::readResponse(const QHttpResponseHeader &header)
+void Scrobbler::setupProxy()
 {
-    if (header.statusCode () != 200)
+    QmmpSettings *gs = QmmpSettings::instance();
+    if (gs->isProxyEnabled())
     {
-        qWarning("Scrobbler[%s]: error: %s", qPrintable(m_name), qPrintable(header.reasonPhrase ()));
-        //TODO Failure Handling
-        return;
+        QNetworkProxy proxy(QNetworkProxy::HttpProxy, gs->proxy().host(),  gs->proxy().port());
+        if(gs->useProxyAuth())
+        {
+            proxy.setUser(gs->proxy().userName());
+            proxy.setPassword(gs->proxy().password());
+        }
+        m_http->setProxy(proxy);
     }
-    m_array = m_http->readAll();
+    else
+        m_http->setProxy(QNetworkProxy::NoProxy);
 }
 
 void Scrobbler::handshake()
 {
+    if (m_disabled)
+        return;
     qDebug("Scrobbler[%s] handshake request",qPrintable(m_name));
     uint ts = QDateTime::currentDateTime().toTime_t();
     qDebug("Scrobbler[%s]: current time stamp %d",qPrintable(m_name),ts);
     QString auth_tmp = QString("%1%2").arg(m_passw).arg(ts);
     QByteArray auth = QCryptographicHash::hash(auth_tmp.toAscii (), QCryptographicHash::Md5);
     auth = auth.toHex();
-
-    QString url = QString("%1?hs=true&p=%2&c=%3&v=%4&u=%5&t=%6&a=%7")
-                  .arg("/")
-                  .arg(PROTOCOL_VER)
-                  .arg(CLIENT_ID)
-                  .arg(CLIENT_VER)
-                  .arg(m_login)
-                  .arg(ts)
-                  .arg(QString(auth));
-
-    qDebug("Scrobbler[%s]: request url: %s",qPrintable(m_name),qPrintable(url));
-    m_http->setHost(m_server, 80);
-    m_handshakeid = m_http->get(url);
+    QUrl url(QString("http://") + m_server + "/?");
+    url.addQueryItem("hs", "true");
+    url.addQueryItem("p", PROTOCOL_VER);
+    url.addQueryItem("c", CLIENT_ID);
+    url.addQueryItem("v", CLIENT_VER);
+    url.addQueryItem("u", m_login);
+    url.addQueryItem("t", QString::number(ts));
+    url.addQueryItem("a", QString(auth));
+    url.setPort(80);
+    qDebug("Scrobbler[%s]: request url: %s",qPrintable(m_name),qPrintable(url.toString()));
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent",  m_ua);
+    request.setRawHeader("Host",url.host().toAscii());
+    request.setRawHeader("Accept", "*/*");
+    m_handshakeReply = m_http->get(request);
 }
 
 void Scrobbler::submit()
@@ -340,16 +359,16 @@ void Scrobbler::submit()
                 .arg(info.metaData(Qmmp::TRACK))
                 .arg(i);
     }
-    qDebug("%s",qPrintable(body));
+    //qDebug("%s",qPrintable(body));
     QUrl url(m_submitUrl);
-    m_http->setHost(url.host(), url.port(80));
-    QHttpRequestHeader header("POST", url.path());
-    header.setContentType("application/x-www-form-urlencoded");
-    header.setValue("User-Agent","iScrobbler/1.5.1qmmp-plugins/" + Qmmp::strVersion());
-    header.setValue("Host",url.host());
-    header.setValue("Accept", "*/*");
-    header.setContentLength(QUrl::toPercentEncoding(body,":/[]&=%").size());
-    m_submitid = m_http->request(header, QUrl::toPercentEncoding(body,":/[]&=%"));
+    url.setPort(80);
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", m_ua);
+    request.setRawHeader("Host",url.host().toAscii());
+    request.setRawHeader("Accept", "*/*");
+    request.setHeader(QNetworkRequest::ContentLengthHeader,
+                      QUrl::toPercentEncoding(body,":/[]&=%").size());
+    m_submitReply = m_http->post(request, QUrl::toPercentEncoding(body,":/[]&=%"));
 }
 
 void Scrobbler::sendNotification(const SongInfo &info)
@@ -363,14 +382,14 @@ void Scrobbler::sendNotification(const SongInfo &info)
             .arg(info.length())
             .arg(info.metaData(Qmmp::TRACK));
     QUrl url(m_nowPlayingUrl);
-        m_http->setHost(url.host(), url.port(80));
-    QHttpRequestHeader header("POST", url.path());
-    header.setContentType("application/x-www-form-urlencoded");
-    header.setValue("User-Agent","iScrobbler/1.5.1qmmp-plugins/" + Qmmp::strVersion());
-    header.setValue("Host",url.host());
-    header.setValue("Accept", "*/*");
-    header.setContentLength(QUrl::toPercentEncoding(body,":/[]&=%").size());
-    m_notificationid = m_http->request(header, QUrl::toPercentEncoding(body,":/[]&=%"));
+    url.setPort(80);
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", m_ua);
+    request.setRawHeader("Host", url.host().toAscii());
+    request.setRawHeader("Accept", "*/*");
+    request.setHeader(QNetworkRequest::ContentLengthHeader,
+                      QUrl::toPercentEncoding(body,":/[]&=%").size());
+    m_notificationReply = m_http->post(request, QUrl::toPercentEncoding(body,":/[]&=%"));
 }
 
 bool Scrobbler::isReady()
@@ -378,6 +397,30 @@ bool Scrobbler::isReady()
     return !m_submitUrl.isEmpty() && !m_session.isEmpty();
 }
 
+void Scrobbler::syncCache()
+{
+    QFile file(QDir::homePath() +"/.qmmp/scrobbler_" + m_name + ".cache");
+    if (m_songCache.isEmpty())
+    {
+        file.remove();
+        return;
+    }
+    file.open(QIODevice::WriteOnly);
+    foreach(SongInfo m, m_songCache)
+    {
+        file.write(QString("title=%1").arg(m.metaData(Qmmp::TITLE)).toUtf8() +"\n");
+        file.write(QString("artist=%1").arg(m.metaData(Qmmp::ARTIST)).toUtf8() +"\n");
+        file.write(QString("album=%1").arg(m.metaData(Qmmp::ALBUM)).toUtf8() +"\n");
+        file.write(QString("comment=%1").arg(m.metaData(Qmmp::COMMENT)).toUtf8() +"\n");
+        file.write(QString("genre=%1").arg(m.metaData(Qmmp::GENRE)).toUtf8() +"\n");
+        file.write(QString("year=%1").arg(m.metaData(Qmmp::YEAR)).toUtf8() +"\n");
+        file.write(QString("track=%1").arg(m.metaData(Qmmp::TRACK)).toUtf8() +"\n");
+        file.write(QString("length=%1").arg(m.length()).toUtf8() +"\n");
+        file.write(QString("time=%1").arg(m.timeStamp()).toUtf8() +"\n");
+    }
+    file.close();
+}
+
 SongInfo::SongInfo()
 {
     m_length = 0;
