@@ -29,9 +29,9 @@ const GeneralProperties ScrobblerFactory::properties() const
     GeneralProperties properties;
     properties.name = tr("Scrobbler Plugin");
     properties.shortName = "scrobbler";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = TRUE;
-    properties.visibilityControl = FALSE;
+    properties.hasAbout = true;
+    properties.hasSettings = true;
+    properties.visibilityControl = false;
     return properties;
 }
 
@@ -60,4 +60,4 @@ QTranslator *ScrobblerFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(ScrobblerFactory)
+Q_EXPORT_PLUGIN2(scrobbler, ScrobblerFactory)
