@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,7 +41,7 @@ extern "C"
 #endif
 }
 
-#include "detailsdialog.h"
+#include "ffmpegmetadatamodel.h"
 #include "settingsdialog.h"
 #include "decoder_ffmpeg.h"
 #include "decoderffmpegfactory.h"
@@ -54,19 +54,54 @@ bool DecoderFFmpegFactory::supports(const QString &source) const
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     QStringList filters;
     filters << "*.wma" << "*.ape";
+#if (LIBAVCODEC_VERSION_INT >= ((52<<16)+(20<<8)+0))
+    filters << "*.shn";
+#endif
     filters = settings.value("FFMPEG/filters", filters).toStringList();
     foreach(QString filter, filters)
     {
         QRegExp regexp(filter, Qt::CaseInsensitive, QRegExp::Wildcard);
         if (regexp.exactMatch(source))
-            return TRUE;
+            return true;
     }
-    return FALSE;
+    return false;
 }
 
-bool DecoderFFmpegFactory::canDecode(QIODevice *) const
+bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
 {
-    return FALSE;
+    av_register_all();
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QStringList filters;
+#if (LIBAVCODEC_VERSION_INT >= ((51<<16)+(44<<8)+0))
+    filters << "*.wma" << "*.ape";
+#else
+    filters << "*.wma";
+#endif
+#if (LIBAVCODEC_VERSION_INT >= ((52<<16)+(20<<8)+0))
+    filters << "*.shn";
+#endif
+    filters = settings.value("FFMPEG/filters", filters).toStringList();
+
+    AVProbeData  pd;
+    uint8_t buf[8192 + AVPROBE_PADDING_SIZE];
+    pd.filename = 0;
+    pd.buf_size = i->peek((char*)buf, sizeof(buf) - AVPROBE_PADDING_SIZE);
+    pd.buf = buf;
+    if(pd.buf_size < 8192)
+        return false;
+    AVInputFormat *fmt = av_probe_input_format(&pd, 1);
+    if(!fmt)
+    {
+        qWarning("DecoderFFmpegFactory: usupported format");
+        return false;
+    }
+    if(filters.contains("*.wma") && !memcmp(fmt->name, "asf", 3))
+        return true;
+    if(filters.contains("*.mp3") && !memcmp(fmt->name, "mp3", 3))
+        return true;
+    if(filters.contains("*.aac") && !memcmp(fmt->name, "aac", 3))
+        return true;
+    return false;
 }
 
 const DecoderProperties DecoderFFmpegFactory::properties() const
@@ -77,26 +112,36 @@ const DecoderProperties DecoderFFmpegFactory::properties() const
     filters << "*.wma" << "*.ape";
 #else
     filters << "*.wma";
+#endif
+#if (LIBAVCODEC_VERSION_INT >= ((52<<16)+(20<<8)+0))
+    filters << "*.shn";
 #endif
     filters = settings.value("FFMPEG/filters", filters).toStringList();
     DecoderProperties properties;
     properties.name = tr("FFmpeg Plugin");
     properties.filter = filters.join(" ");
     properties.description = tr("FFmpeg Formats");
-    //properties.contentType = "";
+    if(filters.contains("*.wma"))
+        properties.contentType += "audio/x-ms-wma";
+    if(filters.contains("*.mp3"))
+        properties.contentType += " audio/mpeg";
+    if(filters.contains("*.aac"))
+        properties.contentType += " audio/aac audio/aacp";
+    if(filters.contains("*.m4a"))
+        properties.contentType += " audio/x-ffmpeg-shorten";
+    if(filters.contains("*.shn"))
+        properties.contentType += " audio/3gpp audio/3gpp2 audio/mp4 audio/MP4A-LATM audio/mpeg4-generic";
+    properties.contentType = properties.contentType.trimmed();
     properties.shortName = "ffmpeg";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = TRUE;
-    properties.noInput = TRUE;
-    properties.protocols = "file";
+    properties.hasAbout = true;
+    properties.hasSettings = true;
+    properties.noInput = false;
     return properties;
 }
 
-Decoder *DecoderFFmpegFactory::create(QObject *parent, QIODevice *input,
-                                      Output *output, const QString &path)
+Decoder *DecoderFFmpegFactory::create(const QString &path, QIODevice *input)
 {
-    Q_UNUSED(input);
-    return new DecoderFFmpeg(parent, this, output, path);
+    return new DecoderFFmpeg(path, input);
 }
 
 QList<FileInfo *> DecoderFFmpegFactory::createPlayList(const QString &fileName, bool useMetaData)
@@ -105,9 +150,9 @@ QList<FileInfo *> DecoderFFmpegFactory::createPlayList(const QString &fileName,
     avcodec_init();
     avcodec_register_all();
     av_register_all();
-    AVFormatContext *in;
+    AVFormatContext *in = 0;
 
-    if (av_open_input_file(&in, fileName.toLocal8Bit(), NULL,0, NULL) < 0)
+    if (av_open_input_file(&in, fileName.toLocal8Bit(), 0, 0, 0) < 0)
     {
         qDebug("DecoderFFmpegFactory: unable to open file");
         return list;
@@ -131,11 +176,9 @@ QList<FileInfo *> DecoderFFmpegFactory::createPlayList(const QString &fileName,
     return list;
 }
 
-QObject* DecoderFFmpegFactory::showDetails(QWidget *parent, const QString &path)
+MetaDataModel* DecoderFFmpegFactory::createMetaDataModel(const QString &path, QObject *parent)
 {
-    DetailsDialog *d = new DetailsDialog(parent, path);
-    d -> show();
-    return d;
+    return new FFmpegMetaDataModel(path,parent);
 }
 
 void DecoderFFmpegFactory::showSettings(QWidget *parent)
@@ -169,4 +212,4 @@ QTranslator *DecoderFFmpegFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(DecoderFFmpegFactory)
+Q_EXPORT_PLUGIN2(ffmpeg,DecoderFFmpegFactory)
