@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,22 +28,19 @@
 #include <taglib/flacfile.h>
 #include <taglib/xiphcomment.h>
 #include <taglib/tmap.h>
-
-#include <qmmp/constants.h>
+#include <taglib/id3v2header.h>
 #include <qmmp/buffer.h>
 #include <qmmp/output.h>
 #include <qmmp/recycler.h>
-
+#include <qmmp/statehandler.h>
 #include <QObject>
 #include <QFile>
 #include <QIODevice>
 #include <FLAC/all.h>
-
+#include "replaygainreader.h"
 #include "cueparser.h"
 #include "decoder_flac.h"
 
-
-
 static size_t pack_pcm_signed (FLAC__byte *data,
                                const FLAC__int32 * const input[],
                                unsigned wide_samples,
@@ -56,11 +53,10 @@ static size_t pack_pcm_signed (FLAC__byte *data,
     unsigned bytes_per_sample;
     unsigned incr;
 
-    if (bps == 24)
-        bps = 32; /* we encode to 32-bit words */
+    if(bps == 24) // we encode to 32-bit words
+        bps = 32;
     bytes_per_sample = bps / 8;
     incr = bytes_per_sample * channels;
-
     for (channel = 0; channel < channels; channel++)
     {
         samples = wide_samples;
@@ -77,21 +73,18 @@ static size_t pack_pcm_signed (FLAC__byte *data,
                 data[0] = sample;
                 break;
             case 16:
-                data[1] = (FLAC__byte)(sample >> 8);
-                data[0] = (FLAC__byte)sample;
+                data[1] = (FLAC__byte)(sample >> 8) & 0xff;
+                data[0] = (FLAC__byte)sample & 0xff;
                 break;
             case 32:
-                data[3] = (FLAC__byte)(sample >> 16);
-                data[2] = (FLAC__byte)(sample >> 8);
-                data[1] = (FLAC__byte)sample;
+                data[3] = (FLAC__byte)(sample >> 16) & 0xff;
+                data[2] = (FLAC__byte)(sample >> 8) & 0xff;
+                data[1] = (FLAC__byte)sample & 0xff;
                 data[0] = 0;
-                break;
             }
-
             data += incr;
         }
     }
-
     return wide_samples * channels * bytes_per_sample;
 }
 
@@ -100,7 +93,6 @@ static int flac_decode (void *void_data, char *buf, int buf_len)
     DecoderFLAC *dflac = (DecoderFLAC *) void_data;
     unsigned to_copy;
     int bytes_per_sample;
-    FLAC__uint64 decode_position;
 
     bytes_per_sample = dflac->data()->bits_per_sample / 8;
 
@@ -118,23 +110,6 @@ static int flac_decode (void *void_data, char *buf, int buf_len)
         {
             return 0;
         }
-
-        /* Count the bitrate */
-        if (!FLAC__stream_decoder_get_decode_position(
-                    dflac->data()->decoder, &decode_position))
-            decode_position = 0;
-        if (decode_position > dflac->data()->last_decode_position)
-        {
-            int bytes_per_sec = bytes_per_sample * dflac->data()->sample_rate
-                                * dflac->data()->channels;
-
-            dflac->data()->bitrate = int(((float)decode_position -
-                                          dflac->data()->last_decode_position) * 8.0 *
-                                         bytes_per_sec /
-                                         dflac->data()->sample_buffer_fill / 1000);
-        }
-
-        dflac->data()->last_decode_position = decode_position;
     }
 
     to_copy = qMin((unsigned)buf_len, dflac->data()->sample_buffer_fill);
@@ -153,9 +128,8 @@ static FLAC__StreamDecoderReadStatus flac_callback_read (const FLAC__StreamDecod
         void *client_data)
 {
     DecoderFLAC *dflac = (DecoderFLAC *) client_data;
-    qint64 res;
-
-    res = dflac->data()->input->read((char *)buffer, *bytes);
+    qint64 res = dflac->data()->input->read((char *)buffer, *bytes);
+    dflac->data()->last_bytes += res;
 
     if (res > 0)
     {
@@ -183,6 +157,9 @@ static FLAC__StreamDecoderWriteStatus flac_callback_write (const FLAC__StreamDec
     if (dflac->data()->abort)
         return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
 
+    dflac->data()->bitrate = dflac->data()->last_bytes * 8.0 * frame->header.sample_rate /
+                             frame->header.blocksize / 1000.0;
+    dflac->data()->last_bytes = 0;
 
     dflac->data()->sample_buffer_fill = pack_pcm_signed (
                                             dflac->data()->sample_buffer,
@@ -245,7 +222,7 @@ static void flac_callback_metadata (const FLAC__StreamDecoder *,
 
 static FLAC__bool flac_callback_eof (const FLAC__StreamDecoder *, void *)
 {
-    return FALSE;
+    return false;
 }
 
 static void flac_callback_error (const FLAC__StreamDecoder *,
@@ -257,33 +234,20 @@ static void flac_callback_error (const FLAC__StreamDecoder *,
 
 // Decoder class
 
-DecoderFLAC::DecoderFLAC(QObject *parent, DecoderFactory *d, QIODevice *i, Output *o, const QString &path)
-        : Decoder(parent, d, i, o)
+DecoderFLAC::DecoderFLAC(const QString &path, QIODevice *i)
+        : Decoder(i)
 {
-    inited = FALSE;
-    user_stop = FALSE;
-    stat = 0;
-    output_buf = 0;
-    output_bytes = 0;
-    output_at = 0;
-    bks = 0;
-    done = FALSE;
-    m_finish = FALSE;
-    len = 0;
-    freq = 0;
-    bitrate = 0;
-    seekTime = -1.0;
-    m_totalTime = 0.0;
-    chan = 0;
-    output_size = 0;
     m_data = 0;
     m_path = path;
-
-    m_offset = 0;
-    m_length = 0;
     m_data = new flac_data;
     m_data->decoder = NULL;
     data()->input = i;
+    m_parser = 0;
+    length_in_bytes = 0;
+    m_totalBytes = 0;
+    m_sz = 0;
+    m_buf = 0;
+    m_offset = 0;
 }
 
 
@@ -297,70 +261,13 @@ DecoderFLAC::~DecoderFLAC()
         delete data();
         m_data = 0;
     }
-
-    if (output_buf)
-        delete [] output_buf;
-    output_buf = 0;
+    if(m_buf)
+        delete[] m_buf;
+    m_buf = 0;
 }
 
-
-void DecoderFLAC::stop()
-{
-    user_stop = TRUE;
-}
-
-
-void DecoderFLAC::flush(bool final)
-{
-    //qDebug("DecoderFLAC: flush()");
-    ulong min = final ? 0 : bks;
-
-    while ((! done && ! m_finish) && output_bytes > min)
-    {
-        output()->recycler()->mutex()->lock();
-
-        while ((! done && ! m_finish) && output()->recycler()->full())
-        {
-            mutex()->unlock();
-
-            output()->recycler()->cond()->wait(output()->recycler()->mutex());
-
-            mutex()->lock();
-            done = user_stop;
-        }
-
-        if (user_stop || m_finish)
-        {
-            inited = FALSE;
-            done = TRUE;
-        }
-        else
-        {
-            output_bytes -= produceSound(output_buf, output_bytes, bitrate, chan);
-            output_size += bks;
-            output_at = output_bytes;
-        }
-
-        if (output()->recycler()->full())
-        {
-            output()->recycler()->cond()->wakeOne();
-        }
-
-        output()->recycler()->mutex()->unlock();
-    }
-}
-
-
 bool DecoderFLAC::initialize()
 {
-    bks = Buffer::size();
-    inited = user_stop = done = m_finish = FALSE;
-    len = freq = bitrate = 0;
-    stat = chan = 0;
-    output_size = 0;
-    seekTime = -1.0;
-    m_totalTime = 0.0;
-
     if (!data()->input)
     {
         QString p = m_path;
@@ -370,7 +277,7 @@ bool DecoderFLAC::initialize()
             if (!p.endsWith(".flac"))
             {
                 qWarning("DecoderFLAC: invalid url.");
-                return FALSE;
+                return false;
             }
             p.replace(QString(QUrl::toPercentEncoding("#")), "#");
             p.replace(QString(QUrl::toPercentEncoding("?")), "?");
@@ -382,65 +289,69 @@ bool DecoderFLAC::initialize()
             if (xiph_comment && xiph_comment->fieldListMap().contains("CUESHEET"))
             {
                 qDebug("DecoderFLAC: using cuesheet xiph comment.");
-                CUEParser parser(xiph_comment->fieldListMap()["CUESHEET"].toString().toCString(TRUE), p);
-                int track = m_path.section("#", -1).toInt();
-                m_offset = parser.offset(track);
-                m_length = parser.length(track);
+                m_parser = new CUEParser(xiph_comment->fieldListMap()["CUESHEET"].toString()
+                                            .toCString(true), p);
+                m_track = m_path.section("#", -1).toInt();
+                if(m_track > m_parser->count())
+                {
+                    qWarning("DecoderFLAC: invalid cuesheet xiph comment");
+                    return false;
+                }
                 data()->input = new QFile(p);
-                //send metadata
-                QMap<Qmmp::MetaData, QString> metaData = parser.info(track)->metaData();
-                StateHandler::instance()->dispatch(metaData);
+                data()->input->open(QIODevice::ReadOnly);
+                QMap<Qmmp::MetaData, QString> metaData = m_parser->info(m_track)->metaData();
+                StateHandler::instance()->dispatch(metaData); //send metadata
+                ReplayGainReader rg(p);
+                setReplayGainInfo(rg.replayGainInfo());
             }
             else
             {
                 qWarning("DecoderFLAC: unable to find cuesheet comment.");
-                return FALSE;
+                return false;
             }
         }
         else
         {
             qWarning("DecoderFLAC: cannot initialize.  No input.");
-            return FALSE;
+            return false;
         }
     }
 
-    if (! output_buf)
-        output_buf = new char[globalBufferSize];
-    output_at = 0;
-    output_bytes = 0;
-
     if (!data()->input->isOpen())
     {
-        if (!data()->input->open(QIODevice::ReadOnly))
-        {
-            return FALSE;
-        }
+        qWarning("DecoderFLAC: unable to open input file");
+        return false;
     }
 
-
-    if (! output_buf)
-        output_buf = new char[globalBufferSize];
-    output_at = 0;
-    output_bytes = 0;
-
-    if (! data()->input->isOpen())
-    {
-        if (! data()->input->open(QIODevice::ReadOnly))
-        {
-            return FALSE;
-        }
-    }
     m_data->bitrate = -1;
     m_data->abort = 0;
     m_data->sample_buffer_fill = 0;
-    m_data->last_decode_position = 0;
+    m_data->last_bytes = 0;
     if (!m_data->decoder)
     {
         qDebug("DecoderFLAC: creating FLAC__StreamDecoder");
         m_data->decoder = FLAC__stream_decoder_new ();
     }
+    char buf[500];
+    //skip id3v2
+    data()->input->peek(buf, sizeof(buf));
+    ulong id3v2_size = findID3v2(buf, sizeof(buf));
+    if(id3v2_size)
+    {
+        qDebug("DecoderFLAC: skipping id3v2 tag (%lu bytes)", id3v2_size);
+        data()->input->seek(id3v2_size);
+    }
+    data()->input->peek(buf,sizeof(buf));
+    data()->input->seek(0);
     qDebug("DecoderFLAC: setting callbacks");
-    if (FLAC__stream_decoder_init_stream(
+    if(!memcmp(buf, "OggS", 4))
+    {
+        if(!FLAC_API_SUPPORTS_OGG_FLAC)
+        {
+            qWarning("DecoderFLAC: unsupported format");
+            return false;
+        }
+        if (FLAC__stream_decoder_init_ogg_stream(
                 m_data->decoder,
                 flac_callback_read,
                 flac_callback_seek,
@@ -451,139 +362,198 @@ bool DecoderFLAC::initialize()
                 flac_callback_metadata,
                 flac_callback_error,
                 this) != FLAC__STREAM_DECODER_INIT_STATUS_OK)
+        {
+            data()->ok = 0;
+            return false;
+        }
+    }
+    else if (!memcmp(buf, "fLaC", 4))
     {
-        data()->ok = 0;
-        return FALSE;
+        if (FLAC__stream_decoder_init_stream(
+                m_data->decoder,
+                flac_callback_read,
+                flac_callback_seek,
+                flac_callback_tell,
+                flac_callback_length,
+                flac_callback_eof,
+                flac_callback_write,
+                flac_callback_metadata,
+                flac_callback_error,
+                this) != FLAC__STREAM_DECODER_INIT_STATUS_OK)
+        {
+            data()->ok = 0;
+            return false;
+        }
+    }
+    else
+    {
+        qWarning("DecoderFLAC: unsupported format");
+        return false;
     }
 
     if (!FLAC__stream_decoder_process_until_end_of_metadata(
                 data()->decoder))
     {
         data()->ok = 0;
-        return FALSE;
+        return false;
+    }
+    switch(data()->bits_per_sample)
+    {
+    case 8:
+        configure(data()->sample_rate, data()->channels, Qmmp::PCM_S8);
+        break;
+    case 16:
+        configure(data()->sample_rate, data()->channels, Qmmp::PCM_S16LE);
+        break;
+    case 24:
+    case 32:
+        configure(data()->sample_rate, data()->channels, Qmmp::PCM_S32LE);
+        break;
+    default:
+        return false;
+    }
+    if(!m_path.contains("://"))
+    {
+        ReplayGainReader rg(m_path);
+        setReplayGainInfo(rg.replayGainInfo());
     }
-    chan = data()->channels;
-    if (data()->bits_per_sample == 24)
-        configure(data()->sample_rate, data()->channels, 32);
-    else
-        configure(data()->sample_rate, data()->channels, data()->bits_per_sample);
-    m_totalTime = data()->length;
 
-    inited = TRUE;
-    if (m_offset)
-        seekTime = m_offset;
-    if (m_length)
-        m_totalTime = m_length;
+    if(m_parser)
+    {
+        m_length = m_parser->length(m_track);
+        m_offset = m_parser->offset(m_track);
+        length_in_bytes = audioParameters().sampleRate() *
+                          audioParameters().channels() *
+                          audioParameters().sampleSize() * m_length/1000;
+        seek(0);
+    }
+    m_totalBytes = 0;
+    m_sz = audioParameters().sampleSize() * audioParameters().channels();
+
     qDebug("DecoderFLAC: initialize succes");
-    return TRUE;
+    return true;
 }
 
-
 qint64 DecoderFLAC::totalTime()
 {
-    if (! inited)
-        return 0;
-
-    return m_totalTime;
+    if(m_parser)
+        return m_length;
+    return data()->length;
 }
 
-
-void DecoderFLAC::seek(qint64 pos)
+int DecoderFLAC::bitrate()
 {
-    if (m_totalTime > 0)
-        seekTime = pos + m_offset;
+    return data()->bitrate;
 }
 
+void DecoderFLAC::seek(qint64 time)
+{
+    m_totalBytes = audioParameters().sampleRate() *
+                   audioParameters().channels() *
+                   audioParameters().sampleSize() * time/1000;
+    if(m_parser)
+        time += m_offset;
+    FLAC__uint64 target_sample = FLAC__uint64(time * data()->total_samples /data()->length);
+    FLAC__stream_decoder_seek_absolute(data()->decoder, target_sample);
+
+}
+
+qint64 DecoderFLAC::read(char *data, qint64 size)
+{
+    if(m_parser)
+    {
+        if(length_in_bytes - m_totalBytes < m_sz) //end of cue track
+            return 0;
+
+        qint64 len = 0;
+
+        if(m_buf) //read remaining data first
+        {
+            len = qMin(m_buf_size, size);
+            memmove(data, m_buf, len);
+            if(size >= m_buf_size)
+            {
+                delete[] m_buf;
+                m_buf = 0;
+                m_buf_size = 0;
+            }
+            else
+                memmove(m_buf, m_buf + len, size - len);
+        }
+        else
+            len = flac_decode (this, data, size);
+
+        if(len <= 0) //end of file
+            return 0;
+
+        if(len + m_totalBytes <= length_in_bytes)
+        {
+            m_totalBytes += len;
+            return len;
+        }
+
+        qint64 len2 = qMax(qint64(0), length_in_bytes - m_totalBytes);
+        len2 = (len2 / m_sz) * m_sz; //returned size must contain integer number of samples
+        m_totalBytes += len2;
+        //save data of the next track
+        if(m_buf)
+            delete[] m_buf;
+        m_buf_size = len - len2;
+        m_buf = new char[m_buf_size];
+        memmove(m_buf, data + len2, m_buf_size);
+        return len2;
+    }
+    return flac_decode (this, data, size);
+}
 
 void DecoderFLAC::deinit()
 {
-    if (data())
+    if (data()->decoder)
         FLAC__stream_decoder_finish (data()->decoder);
-    inited = user_stop = done = m_finish = FALSE;
-    len = freq = bitrate = 0;
-    stat = chan = 0;
-    output_size = 0;
+
     if (!input() && data()->input) //delete internal input only
     {
         data()->input->close();
         delete data()->input;
         data()->input = 0;
     };
+    if(m_parser)
+        delete m_parser;
+    m_parser = 0;
 }
 
-void DecoderFLAC::run()
+const QString DecoderFLAC::nextURL()
 {
-    mutex()->lock ();
-
-    if (!inited)
+    if(m_parser && m_track +1 <= m_parser->count())
+        return m_parser->trackURL(m_track + 1);
+    else
+        return QString();
+}
+
+void DecoderFLAC::next()
+{
+    if(m_parser && m_track +1 <= m_parser->count())
     {
-        mutex()->unlock();
-        return;
+        m_track++;
+        m_offset = m_parser->length(m_track);
+        m_length = m_parser->length(m_track);
+        length_in_bytes = audioParameters().sampleRate() *
+                          audioParameters().channels() *
+                          audioParameters().sampleSize() * m_length/1000;
+        StateHandler::instance()->dispatch(m_parser->info(m_track)->metaData());
+        m_totalBytes = 0;
     }
-    mutex()->unlock();
+}
 
-    while (!done && !m_finish)
+uint DecoderFLAC::findID3v2(char *data, ulong size) //retuns ID3v2 tag size
+{
+    if (size < 10)
+        return 0;
+    if (!memcmp(data, "ID3", 3))
     {
-        mutex()->lock ();
-        // decode
-
-        if (seekTime >= 0.0)
-        {
-            FLAC__uint64 target_sample = FLAC__uint64(seekTime * data()->total_samples / data()->length);
-            FLAC__stream_decoder_seek_absolute(data()->decoder,
-                                               target_sample);
-            seekTime = -1.0;
-        }
-        len = flac_decode (this, (char *) (output_buf + output_at), bks);
-
-        if (len > 0)
-        {
-            bitrate = data()->bitrate;
-            output_at += len;
-            output_bytes += len;
-
-            if (output())
-                flush();
-
-        }
-        else if (len == 0)
-        {
-            flush(TRUE);
-
-            if (output())
-            {
-                output()->recycler()->mutex()->lock ();
-                // end of stream
-                while (! output()->recycler()->empty() && ! user_stop)
-                {
-                    output()->recycler()->cond()->wakeOne();
-                    mutex()->unlock();
-                    output()->recycler()->cond()->wait(output()->recycler()->mutex());
-                    mutex()->lock ();
-                }
-                output()->recycler()->mutex()->unlock();
-            }
-
-            done = TRUE;
-            m_finish = !user_stop;
-        }
-        else
-        {
-            // error while read
-            qWarning("DecoderFLAC: Error while decoding stream, File appears to be "
-                     "corrupted");
-            m_finish = TRUE;
-        }
-        if (m_length && (StateHandler::instance()->elapsed() >= m_length))
-            m_finish = TRUE;
-        mutex()->unlock();
+        TagLib::ByteVector byteVector(data, size);
+        TagLib::ID3v2::Header header(byteVector);
+        return header.completeTagSize();
     }
-
-    mutex()->lock ();
-
-    if (m_finish)
-        finish();
-
-    mutex()->unlock();
-    deinit();
+    return 0;
 }
