@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,12 +22,13 @@
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
 #include <taglib/flacfile.h>
+#include <taglib/oggflacfile.h>
 #include <taglib/xiphcomment.h>
 #include <taglib/tmap.h>
 
 #include "cueparser.h"
-#include "detailsdialog.h"
 #include "decoder_flac.h"
+#include "flacmetadatamodel.h"
 #include "decoderflacfactory.h"
 
 
@@ -35,81 +36,111 @@
 
 bool DecoderFLACFactory::supports(const QString &source) const
 {
-
-    return (source.right(5).toLower() == ".flac");
+    return source.endsWith(".flac", Qt::CaseInsensitive) || source.endsWith(".oga", Qt::CaseInsensitive);
 }
 
 bool DecoderFLACFactory::canDecode(QIODevice *input) const
 {
     Q_UNUSED(input);
-    return FALSE;
+    return false;
 }
 
 const DecoderProperties DecoderFLACFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("FLAC Plugin");
-    properties.filter = "*.flac";
+    properties.filter = "*.flac *.oga";
     properties.description = tr("FLAC Files");
     //properties.contentType = ;
     properties.shortName = "flac";
     properties.protocols = "flac";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = FALSE;
+    properties.hasAbout = true;
+    properties.hasSettings = false;
     return properties;
 }
 
-Decoder *DecoderFLACFactory::create(QObject *parent, QIODevice *input,
-                                    Output *output, const QString &path)
+Decoder *DecoderFLACFactory::create(const QString &path, QIODevice *i)
 {
-    return new DecoderFLAC(parent, this, input, output, path);
+    return new DecoderFLAC(path, i);
 }
 
 QList<FileInfo *> DecoderFLACFactory::createPlayList(const QString &fileName, bool useMetaData)
 {
+    QList <FileInfo*> list;
+    TagLib::Ogg::XiphComment *tag = 0;
+    TagLib::FLAC::Properties *ap = 0;
+
+    TagLib::FLAC::File *flacFile = 0;
+    TagLib::Ogg::FLAC::File *oggFlacFile = 0;
+
+    if(fileName.endsWith(".flac", Qt::CaseInsensitive))
+    {
+        flacFile = new TagLib::FLAC::File(fileName.toLocal8Bit ());
+        tag = useMetaData ? flacFile->xiphComment() : 0;
+        ap = flacFile->audioProperties();
+    }
+    else if(fileName.endsWith(".oga", Qt::CaseInsensitive))
+    {
+        oggFlacFile = new TagLib::Ogg::FLAC::File(fileName.toLocal8Bit ());
+        tag = useMetaData ? oggFlacFile->tag() : 0;
+        ap = oggFlacFile->audioProperties();
+    }
+    else
+        return list;
+
     FileInfo *info = new FileInfo(fileName);
-
-    TagLib::FLAC::File fileRef(fileName.toLocal8Bit ());
-    TagLib::Tag *tag = useMetaData ? fileRef.tag() : 0;
-
     if (tag && !tag->isEmpty())
     {
         info->setMetaData(Qmmp::ALBUM,
-                          QString::fromUtf8(tag->album().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->album().toCString(true)).trimmed());
         info->setMetaData(Qmmp::ARTIST,
-                          QString::fromUtf8(tag->artist().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->artist().toCString(true)).trimmed());
         info->setMetaData(Qmmp::COMMENT,
-                          QString::fromUtf8(tag->comment().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->comment().toCString(true)).trimmed());
         info->setMetaData(Qmmp::GENRE,
-                          QString::fromUtf8(tag->genre().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->genre().toCString(true)).trimmed());
         info->setMetaData(Qmmp::TITLE,
-                          QString::fromUtf8(tag->title().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->title().toCString(true)).trimmed());
         info->setMetaData(Qmmp::YEAR, tag->year());
         info->setMetaData(Qmmp::TRACK, tag->track());
-    }
 
-    if (fileRef.audioProperties())
-        info->setLength(fileRef.audioProperties()->length());
+        if (tag->fieldListMap().contains("CUESHEET"))
+        {
+            CUEParser parser(tag->fieldListMap()["CUESHEET"].toString().toCString(true), fileName);
+            list = parser.createPlayList();
+            delete info;
+            if(flacFile)
+                delete flacFile;
+            if(oggFlacFile)
+                delete oggFlacFile;
+            return list;
+        }
 
-    //looking for cuesheet comment
-    TagLib::Ogg::XiphComment *xiph_comment = useMetaData ? fileRef.xiphComment() : 0;
-    QList <FileInfo*> list;
-    if (xiph_comment && xiph_comment->fieldListMap().contains("CUESHEET"))
-    {
-        CUEParser parser(xiph_comment->fieldListMap()["CUESHEET"].toString().toCString(TRUE), fileName);
-        list = parser.createPlayList();
-        delete info;
+        //additional metadata
+        TagLib::StringList fld;
+        if(!(fld = tag->fieldListMap()["COMPOSER"]).isEmpty())
+            info->setMetaData(Qmmp::COMPOSER,
+                              QString::fromUtf8(fld.toString().toCString(true)).trimmed());
+        if(!(fld = tag->fieldListMap()["DISCNUMBER"]).isEmpty())
+            info->setMetaData(Qmmp::DISCNUMBER,
+                              QString::fromUtf8(fld.toString().toCString(true)).trimmed());
     }
-    else
-        list << info;
+    if(ap)
+        info->setLength(ap->length());
+    list << info;
+    if(flacFile)
+        delete flacFile;
+    if(oggFlacFile)
+        delete oggFlacFile;
     return list;
 }
 
-QObject* DecoderFLACFactory::showDetails(QWidget *parent, const QString &path)
+MetaDataModel*DecoderFLACFactory::createMetaDataModel(const QString &path, QObject *parent)
 {
-    DetailsDialog *d = new DetailsDialog(parent, path);
-    d -> show();
-    return d;
+    if (!path.contains("://") || path.startsWith("flac://"))
+        return new FLACMetaDataModel(path, parent);
+    else
+        return 0;
 }
 
 void DecoderFLACFactory::showSettings(QWidget *)
@@ -130,4 +161,4 @@ QTranslator *DecoderFLACFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(DecoderFLACFactory)
+Q_EXPORT_PLUGIN2(flac,DecoderFLACFactory)
