@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,8 +30,8 @@
 #include <taglib/apetag.h>
 #include <taglib/tfile.h>
 #include <taglib/mpegfile.h>
-
-#include "detailsdialog.h"
+#include "mpegmetadatamodel.h"
+#include "replaygainreader.h"
 #include "settingsdialog.h"
 #include "decoder_mad.h"
 #include "decodermadfactory.h"
@@ -42,7 +42,7 @@ bool DecoderMADFactory::supports(const QString &source) const
 {
     QString ext = source.right(4).toLower();
     if (ext == ".mp1" || ext == ".mp2" || ext == ".mp3")
-        return TRUE;
+        return true;
     else if (ext == ".wav") //check for mp3 wav files
     {
         QFile file(source);
@@ -52,10 +52,10 @@ bool DecoderMADFactory::supports(const QString &source) const
         file.close();
         if (!memcmp(buf + 8, "WAVE", 4) && !memcmp(buf + 20, "U" ,1))
         {
-            return TRUE;
+            return true;
         }
     }
-    return FALSE;
+    return false;
 }
 
 bool DecoderMADFactory::canDecode(QIODevice *input) const
@@ -64,6 +64,9 @@ bool DecoderMADFactory::canDecode(QIODevice *input) const
 
     if (input->peek(buf,sizeof(buf)) == sizeof(buf))
     {
+        if(!memcmp(buf, "FLV", 3)) //skip flv files
+            return false;
+
         struct mad_stream stream;
         struct mad_header header;
         int dec_res;
@@ -76,9 +79,9 @@ bool DecoderMADFactory::canDecode(QIODevice *input) const
         while ((dec_res = mad_header_decode(&header, &stream)) == -1
                 && MAD_RECOVERABLE(stream.error))
             ;
-        return dec_res != -1 ? TRUE: FALSE;
+        return dec_res != -1 ? true: false;
     }
-    return FALSE;
+    return false;
 }
 
 const DecoderProperties DecoderMADFactory::properties() const
@@ -89,17 +92,22 @@ const DecoderProperties DecoderMADFactory::properties() const
     properties.filter = "*.mp1 *.mp2 *.mp3 *.wav";
     properties.description = tr("MPEG Files");
     properties.contentType = "audio/mp3;audio/mpeg";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = TRUE;
+    properties.hasAbout = true;
+    properties.hasSettings = true;
     return properties;
 }
 
-Decoder *DecoderMADFactory::create(QObject *parent, QIODevice *input, Output *output, const QString &)
+Decoder *DecoderMADFactory::create(const QString &url, QIODevice *input)
 {
-    return new DecoderMAD(parent, this, input, output);
+    Decoder *d = new DecoderMAD(input);
+    if(!url.contains("://")) //local file
+    {
+        ReplayGainReader rg(url);
+        d->setReplayGainInfo(rg.replayGainInfo());
+    }
+    return d;
 }
 
-//FileInfo *DecoderMADFactory::createFileInfo(const QString &source)
 QList<FileInfo *> DecoderMADFactory::createPlayList(const QString &fileName, bool useMetaData)
 {
     FileInfo *info = new FileInfo(fileName);
@@ -118,21 +126,17 @@ QList<FileInfo *> DecoderMADFactory::createPlayList(const QString &fileName, boo
         tag_array[1] = settings.value("tag_2", SettingsDialog::Disabled).toInt();
         tag_array[2] = settings.value("tag_3", SettingsDialog::Disabled).toInt();
 
-
+        QByteArray name;
         for (int i = 0; i < 3; ++i)
         {
             switch ((uint) tag_array[i])
             {
             case SettingsDialog::ID3v1:
-            {
                 codec = QTextCodec::codecForName(settings.value("ID3v1_encoding","ISO-8859-1")
                                                  .toByteArray ());
                 tag = fileRef.ID3v1Tag();
                 break;
-            }
             case SettingsDialog::ID3v2:
-            {
-                QByteArray name;
                 name = settings.value("ID3v2_encoding","UTF-8").toByteArray ();
                 if (name.contains("UTF"))
                     codec = QTextCodec::codecForName ("UTF-8");
@@ -140,18 +144,13 @@ QList<FileInfo *> DecoderMADFactory::createPlayList(const QString &fileName, boo
                     codec = QTextCodec::codecForName(name);
                 tag = fileRef.ID3v2Tag();
                 break;
-            }
             case SettingsDialog::APE:
-            {
                 codec = QTextCodec::codecForName ("UTF-8");
                 tag = fileRef.APETag();
                 break;
-            }
             case SettingsDialog::Disabled:
-            {
                 break;
             }
-            }
             if (tag && !tag->isEmpty())
                 break;
         }
@@ -183,6 +182,22 @@ QList<FileInfo *> DecoderMADFactory::createPlayList(const QString &fileName, boo
                               tag->year());
             info->setMetaData(Qmmp::TRACK,
                               tag->track());
+
+            if(tag == fileRef.ID3v2Tag())
+            {
+                if(!fileRef.ID3v2Tag()->frameListMap()["TCOM"].isEmpty())
+                {
+                    TagLib::String composer;
+                    composer = fileRef.ID3v2Tag()->frameListMap()["TCOM"].front()->toString();
+                    info->setMetaData(Qmmp::COMPOSER,
+                                      codec->toUnicode(composer.toCString(utf)).trimmed());
+                }
+                if(!fileRef.ID3v2Tag()->frameListMap()["TPOS"].isEmpty())
+                {
+                    TagLib::String disc = fileRef.ID3v2Tag()->frameListMap()["TPOS"].front()->toString();
+                    info->setMetaData(Qmmp::DISCNUMBER, QString(disc.toCString()).trimmed());
+                }
+            }
         }
     }
     if (fileRef.audioProperties())
@@ -192,11 +207,9 @@ QList<FileInfo *> DecoderMADFactory::createPlayList(const QString &fileName, boo
     return list;
 }
 
-QObject* DecoderMADFactory::showDetails(QWidget *parent, const QString &path)
+MetaDataModel* DecoderMADFactory::createMetaDataModel(const QString &path, QObject *parent)
 {
-    DetailsDialog *d = new DetailsDialog(parent, path);
-    d -> show();
-    return d;
+   return new MPEGMetaDataModel(path, parent);
 }
 
 void DecoderMADFactory::showSettings(QWidget *parent)
@@ -226,4 +239,4 @@ QTranslator *DecoderMADFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(DecoderMADFactory)
+Q_EXPORT_PLUGIN2(mad, DecoderMADFactory)
