@@ -14,371 +14,327 @@
         <translation>Файли ModPlug</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="133"/>
+        <location filename="../decodermodplugfactory.cpp" line="130"/>
         <source>About ModPlug Audio Plugin</source>
         <translation>Про аудіо-модуль ModPlug</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="134"/>
+        <location filename="../decodermodplugfactory.cpp" line="131"/>
         <source>Qmmp ModPlug Audio Plugin</source>
         <translation>Аудіо-модуль для Qmmp</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="135"/>
+        <location filename="../decodermodplugfactory.cpp" line="132"/>
         <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="136"/>
+        <location filename="../decodermodplugfactory.cpp" line="133"/>
         <source>Based on the Modplug Plugin for Xmms</source>
         <translation>На базі модуля Modplug для Xmms</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="137"/>
+        <location filename="../decodermodplugfactory.cpp" line="134"/>
         <source>Modplug Plugin developers:</source>
-        <translation>Розробники модуля Modplug:</translation>
+        <translation>Розробники модуля ModPlug:</translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="138"/>
+        <location filename="../decodermodplugfactory.cpp" line="135"/>
         <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="139"/>
+        <location filename="../decodermodplugfactory.cpp" line="136"/>
         <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../decodermodplugfactory.cpp" line="140"/>
+        <location filename="../decodermodplugfactory.cpp" line="137"/>
         <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
         <translation></translation>
     </message>
 </context>
 <context>
-    <name>DetailsDialog</name>
+    <name>ModPlugMetaDataModel</name>
     <message>
-        <location filename="../detailsdialog.cpp" line="43"/>
-        <source>File name:</source>
-        <translation>Ім&apos;я файлу:</translation>
+        <location filename="../modplugmetadatamodel.cpp" line="71"/>
+        <source>File name</source>
+        <translation>Ім&apos;я файлу</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="44"/>
-        <source>Title:</source>
-        <translation>Назва:</translation>
+        <location filename="../modplugmetadatamodel.cpp" line="142"/>
+        <source>Type</source>
+        <translation>Тип</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="45"/>
-        <source>Type:</source>
-        <translation>Тип:</translation>
+        <location filename="../modplugmetadatamodel.cpp" line="147"/>
+        <source>Length</source>
+        <translation>Тривалість</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="46"/>
-        <source>Length:</source>
-        <translation>Тривалість:</translation>
+        <location filename="../modplugmetadatamodel.cpp" line="148"/>
+        <source>Speed</source>
+        <translation>Швидкість</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="47"/>
-        <source>Speed:</source>
-        <translation>Швидкість:</translation>
+        <location filename="../modplugmetadatamodel.cpp" line="149"/>
+        <source>Tempo</source>
+        <translation>Темп</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.cpp" line="48"/>
-        <source>Tempo:</source>
-        <translation>Темп:</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.cpp" line="49"/>
-        <source>Samples:</source>
-        <translation>Семпли:</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.cpp" line="50"/>
-        <source>Instruments:</source>
-        <translation>Інструменти:</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.cpp" line="51"/>
-        <source>Patterns:</source>
-        <translation>Зразків:</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.cpp" line="52"/>
-        <source>Channels:</source>
-        <translation>Каналів:</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="13"/>
-        <source>MOD Info</source>
-        <translation>Іформація MOD</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="30"/>
-        <source>General</source>
-        <translation>Загальні</translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="36"/>
-        <location filename="../detailsdialog.ui" line="46"/>
-        <source>-</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="57"/>
+        <location filename="../modplugmetadatamodel.cpp" line="150"/>
+        <location filename="../modplugmetadatamodel.cpp" line="171"/>
         <source>Samples</source>
         <translation>Семпли</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="66"/>
-        <location filename="../detailsdialog.ui" line="86"/>
-        <location filename="../detailsdialog.ui" line="106"/>
-        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
-p, li { white-space: pre-wrap; }
-&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../detailsdialog.ui" line="77"/>
+        <location filename="../modplugmetadatamodel.cpp" line="151"/>
+        <location filename="../modplugmetadatamodel.cpp" line="180"/>
         <source>Instruments</source>
         <translation>Інструменти</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="97"/>
-        <source>Message</source>
-        <translation>Повідомлення</translation>
+        <location filename="../modplugmetadatamodel.cpp" line="152"/>
+        <source>Patterns</source>
+        <translation>Зразків</translation>
     </message>
     <message>
-        <location filename="../detailsdialog.ui" line="133"/>
-        <source>Close</source>
-        <translation>Закрити</translation>
+        <location filename="../modplugmetadatamodel.cpp" line="153"/>
+        <source>Channels</source>
+        <translation>Канали</translation>
+    </message>
+    <message>
+        <location filename="../modplugmetadatamodel.cpp" line="185"/>
+        <source>Comment</source>
+        <translation>Коментар</translation>
     </message>
 </context>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="13"/>
+        <location filename="../settingsdialog.ui" line="14"/>
         <source>ModPlug Plugin Settings</source>
         <translation>Налаштування модуля ModPlug</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="23"/>
+        <location filename="../settingsdialog.ui" line="33"/>
         <source>Quality</source>
         <translation>Якість</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="35"/>
+        <location filename="../settingsdialog.ui" line="45"/>
         <source>Resolution</source>
         <translation>Роздільність</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="41"/>
+        <location filename="../settingsdialog.ui" line="51"/>
         <source>16 bit</source>
         <translation>16 біт</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="48"/>
+        <location filename="../settingsdialog.ui" line="58"/>
         <source>8 bit</source>
         <translation>8 біт</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="64"/>
+        <location filename="../settingsdialog.ui" line="74"/>
         <source>Channels</source>
         <translation>Канали</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="70"/>
+        <location filename="../settingsdialog.ui" line="80"/>
         <source>Stereo</source>
         <translation>Стерео</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="77"/>
+        <location filename="../settingsdialog.ui" line="87"/>
         <source>Mono (downmix)</source>
         <translation>Моно</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="93"/>
+        <location filename="../settingsdialog.ui" line="103"/>
         <source>Resampling</source>
         <translation>Передискретизація</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="99"/>
+        <location filename="../settingsdialog.ui" line="109"/>
         <source>Nearest (fastest)</source>
         <translation>Nearest (найшвидше)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="106"/>
+        <location filename="../settingsdialog.ui" line="116"/>
         <source>Linear (fast)</source>
         <translation>Linear (швидко)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="113"/>
+        <location filename="../settingsdialog.ui" line="123"/>
         <source>Spline (good quality)</source>
         <translation>Spline (висока якість)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="120"/>
+        <location filename="../settingsdialog.ui" line="130"/>
         <source>8-tap Fir (extremely high quality)</source>
         <translation>8-tap Fir (найвища якість)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="136"/>
+        <location filename="../settingsdialog.ui" line="146"/>
         <source>Sampling Rate</source>
         <translation>Дискретизація</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="142"/>
+        <location filename="../settingsdialog.ui" line="152"/>
         <source>48000 Hz</source>
         <translation>48000 Гц</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="149"/>
+        <location filename="../settingsdialog.ui" line="159"/>
         <source>44100 Hz</source>
         <translation>44100 Гц</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="156"/>
+        <location filename="../settingsdialog.ui" line="166"/>
         <source>22050 Hz</source>
         <translation>22050 Гц</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="163"/>
+        <location filename="../settingsdialog.ui" line="173"/>
         <source>11025 Hz</source>
         <translation>11025 Гц</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="174"/>
+        <location filename="../settingsdialog.ui" line="184"/>
         <source>Effects</source>
         <translation>Ефекти</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="180"/>
+        <location filename="../settingsdialog.ui" line="190"/>
         <source>Reverb</source>
         <translation>Реверберація</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="192"/>
-        <location filename="../settingsdialog.ui" line="457"/>
+        <location filename="../settingsdialog.ui" line="202"/>
+        <location filename="../settingsdialog.ui" line="467"/>
         <source>Depth (%)</source>
         <translation>Глибина (%)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="224"/>
-        <location filename="../settingsdialog.ui" line="358"/>
-        <location filename="../settingsdialog.ui" line="489"/>
-        <location filename="../settingsdialog.ui" line="608"/>
+        <location filename="../settingsdialog.ui" line="234"/>
+        <location filename="../settingsdialog.ui" line="368"/>
+        <location filename="../settingsdialog.ui" line="499"/>
+        <location filename="../settingsdialog.ui" line="618"/>
         <source>0</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="250"/>
-        <location filename="../settingsdialog.ui" line="509"/>
+        <location filename="../settingsdialog.ui" line="260"/>
+        <location filename="../settingsdialog.ui" line="519"/>
         <source>Delay (ms)</source>
         <translation>Затримка (мс)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="282"/>
+        <location filename="../settingsdialog.ui" line="292"/>
         <source>40</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="314"/>
+        <location filename="../settingsdialog.ui" line="324"/>
         <source>Bass Boost</source>
         <translation>Підсилення басів</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="326"/>
+        <location filename="../settingsdialog.ui" line="336"/>
         <source>Amount (%)</source>
         <translation>Об&apos;єм (%)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="384"/>
+        <location filename="../settingsdialog.ui" line="394"/>
         <source>Range (Hz)</source>
         <translation>Діапазон (Гц)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="416"/>
+        <location filename="../settingsdialog.ui" line="426"/>
         <source>10</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="448"/>
+        <location filename="../settingsdialog.ui" line="458"/>
         <source>Surround</source>
         <translation>Оточення</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="541"/>
+        <location filename="../settingsdialog.ui" line="551"/>
         <source>5</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="567"/>
+        <location filename="../settingsdialog.ui" line="577"/>
         <source>Preamp</source>
         <translation>Підсилення</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="576"/>
+        <location filename="../settingsdialog.ui" line="586"/>
         <source>Volume</source>
         <translation>Гучність</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="646"/>
+        <location filename="../settingsdialog.ui" line="656"/>
         <source>Note: Setting the preamp
 too high may cause clipping!</source>
         <translation>Примітка: встановлення занадто високого
 підсилення може викликати зрізання!</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="661"/>
+        <location filename="../settingsdialog.ui" line="671"/>
         <source>Misc</source>
         <translation>Різне</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="667"/>
+        <location filename="../settingsdialog.ui" line="677"/>
         <source>General</source>
         <translation>Загальне</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="673"/>
+        <location filename="../settingsdialog.ui" line="683"/>
         <source>Use filename as song title</source>
         <translation>Використовувати і&apos;мя файла як ім&apos;я фрагменту</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="680"/>
+        <location filename="../settingsdialog.ui" line="690"/>
         <source>Noise reduction</source>
         <translation>Шумопридушення</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="690"/>
+        <location filename="../settingsdialog.ui" line="700"/>
         <source>Fast playlist info</source>
         <translation>Швидка інформація списку</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="700"/>
+        <location filename="../settingsdialog.ui" line="710"/>
         <source>Play Amiga MOD</source>
         <translation>Грати Amiga MOD</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="710"/>
+        <location filename="../settingsdialog.ui" line="720"/>
         <source>Looping</source>
         <translation>Зациклення</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="716"/>
+        <location filename="../settingsdialog.ui" line="726"/>
         <source>Don&apos;t loop</source>
         <translation>Не зациклювати</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="723"/>
+        <location filename="../settingsdialog.ui" line="733"/>
         <source>Loop</source>
         <translation>Цикл</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="740"/>
+        <location filename="../settingsdialog.ui" line="750"/>
         <source>time(s)</source>
         <translation>раз(ів)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="760"/>
+        <location filename="../settingsdialog.ui" line="770"/>
         <source>Loop forever</source>
         <translation>Цикл назавжди</translation>
     </message>
