@@ -21,8 +21,9 @@
 #include <QtGui>
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
-
-#include "detailsdialog.h"
+#include <taglib/mpcfile.h>
+#include <taglib/apetag.h>
+#include "mpcmetadatamodel.h"
 #include "decoder_mpc.h"
 #include "decodermpcfactory.h"
 
@@ -37,7 +38,7 @@ bool DecoderMPCFactory::supports(const QString &source) const
 
 bool DecoderMPCFactory::canDecode(QIODevice *) const
 {
-    return FALSE;
+    return false;
 }
 
 const DecoderProperties DecoderMPCFactory::properties() const
@@ -48,51 +49,56 @@ const DecoderProperties DecoderMPCFactory::properties() const
     properties.description = tr("Musepack Files");
     //properties.contentType = ;
     properties.shortName = "mpc";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = FALSE;
+    properties.hasAbout = true;
+    properties.hasSettings = false;
     return properties;
 }
 
-Decoder *DecoderMPCFactory::create(QObject *parent, QIODevice *input,
-                                   Output *output, const QString &)
+Decoder *DecoderMPCFactory::create(const QString &, QIODevice *i)
 {
-    return new DecoderMPC(parent, this, input, output);
+    return new DecoderMPC(i);
 }
 
 QList<FileInfo *> DecoderMPCFactory::createPlayList(const QString &fileName, bool useMetaData)
 {
     FileInfo *info = new FileInfo(fileName);
 
-    TagLib::FileRef fileRef(fileName.toLocal8Bit ());
-    TagLib::Tag *tag = useMetaData ? fileRef.tag() : 0;
+    TagLib::MPC::File fileRef(fileName.toLocal8Bit ());
+    TagLib::APE::Tag *tag = useMetaData ? fileRef.APETag() : 0;
     if (tag && !tag->isEmpty())
     {
         info->setMetaData(Qmmp::ALBUM,
-                       QString::fromUtf8(tag->album().toCString(TRUE)).trimmed());
+                       QString::fromUtf8(tag->album().toCString(true)).trimmed());
         info->setMetaData(Qmmp::ARTIST,
-                       QString::fromUtf8(tag->artist().toCString(TRUE)).trimmed());
+                       QString::fromUtf8(tag->artist().toCString(true)).trimmed());
         info->setMetaData(Qmmp::COMMENT,
-                       QString::fromUtf8(tag->comment().toCString(TRUE)).trimmed());
+                       QString::fromUtf8(tag->comment().toCString(true)).trimmed());
         info->setMetaData(Qmmp::GENRE,
-                       QString::fromUtf8(tag->genre().toCString(TRUE)).trimmed());
+                       QString::fromUtf8(tag->genre().toCString(true)).trimmed());
         info->setMetaData(Qmmp::TITLE,
-                       QString::fromUtf8(tag->title().toCString(TRUE)).trimmed());
+                       QString::fromUtf8(tag->title().toCString(true)).trimmed());
         info->setMetaData(Qmmp::YEAR, tag->year());
         info->setMetaData(Qmmp::TRACK, tag->track());
     }
     if (fileRef.audioProperties())
         info->setLength(fileRef.audioProperties()->length());
+    //additional metadata
+    if(tag)
+    {
+        TagLib::APE::Item fld;
+        if(!(fld = tag->itemListMap()["COMPOSER"]).isEmpty())
+            info->setMetaData(Qmmp::COMPOSER,
+                              QString::fromUtf8(fld.toString().toCString(true)).trimmed());
+    }
 
     QList <FileInfo*> list;
     list << info;
     return list;
 }
 
-QObject* DecoderMPCFactory::showDetails(QWidget *parent, const QString &path)
+MetaDataModel* DecoderMPCFactory::createMetaDataModel(const QString &path, QObject *parent)
 {
-    DetailsDialog *d = new DetailsDialog(parent, path);
-    d -> show();
-    return d;
+    return new MPCMetaDataModel(path, parent);
 }
 
 void DecoderMPCFactory::showSettings(QWidget *)
@@ -113,4 +119,4 @@ QTranslator *DecoderMPCFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(DecoderMPCFactory)
+Q_EXPORT_PLUGIN2(mpc,DecoderMPCFactory)
