@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,10 +20,10 @@
 #include <QtGui>
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
-#include <tag.h>
-
-#include "detailsdialog.h"
+#include <taglib/vorbisfile.h>
+#include "replaygainreader.h"
 #include "decoder_vorbis.h"
+#include "vorbismetadatamodel.h"
 #include "decodervorbisfactory.h"
 
 
@@ -39,9 +39,9 @@ bool DecoderVorbisFactory::canDecode(QIODevice *input) const
     char buf[36];
     if (input->peek(buf, 36) == 36 && !memcmp(buf, "OggS", 4)
             && !memcmp(buf + 29, "vorbis", 6))
-        return TRUE;
+        return true;
 
-    return FALSE;
+    return false;
 }
 
 const DecoderProperties DecoderVorbisFactory::properties() const
@@ -52,61 +52,72 @@ const DecoderProperties DecoderVorbisFactory::properties() const
     properties.filter = "*.ogg";
     properties.description = tr("Ogg Vorbis Files");
     properties.contentType = "application/ogg;audio/x-vorbis+ogg";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = FALSE;
+    properties.hasAbout = true;
+    properties.hasSettings = false;
+    properties.noInput = false;
     return properties;
 }
 
-Decoder *DecoderVorbisFactory::create(QObject *parent, QIODevice *input,
-                                      Output *output, const QString&)
+Decoder *DecoderVorbisFactory::create(const QString &url, QIODevice *input)
 {
-    return new DecoderVorbis(parent, this, input, output);
+    Decoder *d = new DecoderVorbis(url, input);
+    if(!url.contains("://")) //local file
+    {
+        ReplayGainReader rg(url);
+        d->setReplayGainInfo(rg.replayGainInfo());
+    }
+    return d;
+}
+
+MetaDataModel* DecoderVorbisFactory::createMetaDataModel(const QString &path, QObject *parent)
+{
+    return new VorbisMetaDataModel(path, parent);
 }
 
-//FileInfo *DecoderVorbisFactory::createFileInfo(const QString &source)
 QList<FileInfo *> DecoderVorbisFactory::createPlayList(const QString &fileName, bool useMetaData)
 {
     FileInfo *info = new FileInfo(fileName);
 
-    TagLib::FileRef fileRef(fileName.toLocal8Bit ());
-    TagLib::Tag *tag = useMetaData ? fileRef.tag() : 0;
+    TagLib::Ogg::Vorbis::File fileRef(fileName.toLocal8Bit ());
+    TagLib::Ogg::XiphComment *tag = useMetaData ? fileRef.tag() : 0;
 
     if (tag && !tag->isEmpty())
     {
         info->setMetaData(Qmmp::ALBUM,
-                          QString::fromUtf8(tag->album().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->album().toCString(true)).trimmed());
         info->setMetaData(Qmmp::ARTIST,
-                          QString::fromUtf8(tag->artist().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->artist().toCString(true)).trimmed());
         info->setMetaData(Qmmp::COMMENT,
-                          QString::fromUtf8(tag->comment().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->comment().toCString(true)).trimmed());
         info->setMetaData(Qmmp::GENRE,
-                          QString::fromUtf8(tag->genre().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->genre().toCString(true)).trimmed());
         info->setMetaData(Qmmp::TITLE,
-                          QString::fromUtf8(tag->title().toCString(TRUE)).trimmed());
+                          QString::fromUtf8(tag->title().toCString(true)).trimmed());
         info->setMetaData(Qmmp::YEAR, tag->year());
         info->setMetaData(Qmmp::TRACK, tag->track());
     }
 
     if (fileRef.audioProperties())
         info->setLength(fileRef.audioProperties()->length());
+    //additional metadata
+    if(tag)
+    {
+        TagLib::StringList fld;
+        if(!(fld = tag->fieldListMap()["COMPOSER"]).isEmpty())
+            info->setMetaData(Qmmp::COMPOSER,
+                              QString::fromUtf8(fld.toString().toCString(true)).trimmed());
+        if(!(fld = tag->fieldListMap()["DISCNUMBER"]).isEmpty())
+            info->setMetaData(Qmmp::DISCNUMBER,
+                              QString::fromUtf8(fld.toString().toCString(true)).trimmed());
+    }
 
     QList <FileInfo*> list;
     list << info;
     return list;
 }
 
-QObject* DecoderVorbisFactory::showDetails(QWidget *parent, const QString &path)
-{
-    DetailsDialog *d = new DetailsDialog(parent, path);
-    d -> show();
-    return d;
-}
-
 void DecoderVorbisFactory::showSettings(QWidget *)
-{
-    /*SettingsDialog *s = new SettingsDialog(parent);
-    s -> show();*/
-}
+{}
 
 void DecoderVorbisFactory::showAbout(QWidget *parent)
 {
@@ -125,4 +136,4 @@ QTranslator *DecoderVorbisFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(DecoderVorbisFactory)
+Q_EXPORT_PLUGIN2(vorbis,DecoderVorbisFactory)
