@@ -24,46 +24,46 @@
 extern "C"{
 #include <wavpack/wavpack.h>
 }
-
 #include <qmmp/decoder.h>
 
+class CUEParser;
 
 class DecoderWavPack : public Decoder
 {
 public:
-    DecoderWavPack(QObject *, DecoderFactory *, Output *, const QString &);
+    DecoderWavPack(const QString &);
     virtual ~DecoderWavPack();
 
     // Standard Decoder API
     bool initialize();
     qint64 totalTime();
-    void seek(qint64);
-    void stop();
+    int bitrate();
+    qint64 read(char *data, qint64 maxSize);
+    void seek(qint64 time);
+    const QString nextURL();
+    void next();
 
 private:
-    // thread run function
-    void run();
-    WavpackContext *m_context;
     // helper functions
-    void flush(bool = FALSE);
     void deinit();
-
-    bool m_inited, m_user_stop;
-    int m_bps; //bits per sample
-
-    // output buffer
-    char *m_output_buf;
-    qint64 m_output_bytes, m_output_at;
-
-    unsigned int m_bks; //block size
-    bool m_done, m_finish;
-    long m_freq, m_bitrate;
+    qint64 wavpack_decode(char *data, qint64 size);
+    WavpackContext *m_context;    
+    int32_t *m_output_buf; // output buffer
     int m_chan;
-    qint64 m_output_size;
-    qint64 m_totalTime, m_seekTime;
-    QString m_path;
+    quint32 m_freq;
+    qint64 m_totalTime;
+    qint64 length_in_bytes;
+    qint64 m_totalBytes;
     qint64 m_offset;
     qint64 m_length;
+    QString m_path;
+    CUEParser *m_parser;
+    int m_track;
+    int m_bps;
+    char *m_buf; //buffer for remainig data
+    qint64 m_buf_size;
+    qint64 m_sz; //sample size
+
 };
 
 #endif // DECODER_WAVPACK_H
