@@ -20,7 +20,7 @@
 
 #include <QtGui>
 
-#include "detailsdialog.h"
+#include "wavpackmetadatamodel.h"
 #include "decoder_wavpack.h"
 #include "decoderwavpackfactory.h"
 #include "cueparser.h"
@@ -35,7 +35,7 @@ bool DecoderWavPackFactory::supports(const QString &source) const
 
 bool DecoderWavPackFactory::canDecode(QIODevice *) const
 {
-    return FALSE;
+    return false;
 }
 
 const DecoderProperties DecoderWavPackFactory::properties() const
@@ -46,18 +46,16 @@ const DecoderProperties DecoderWavPackFactory::properties() const
     properties.description = tr("WavPack Files");
     //properties.contentType = ;
     properties.shortName = "wavpack";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = FALSE;
-    properties.noInput = TRUE;
+    properties.hasAbout = true;
+    properties.hasSettings = false;
+    properties.noInput = true;
     properties.protocols = "file wvpack";
     return properties;
 }
 
-Decoder *DecoderWavPackFactory::create(QObject *parent, QIODevice *input,
-                                       Output *output, const QString &path)
+Decoder *DecoderWavPackFactory::create(const QString &p, QIODevice *)
 {
-    Q_UNUSED(input);
-    return new DecoderWavPack(parent, this, output, path);
+    return new DecoderWavPack(p);
 }
 
 QList<FileInfo *> DecoderWavPackFactory::createPlayList(const QString &fileName, bool useMetaData)
@@ -98,10 +96,14 @@ QList<FileInfo *> DecoderWavPackFactory::createPlayList(const QString &fileName,
             info->setMetaData(Qmmp::GENRE, QString::fromUtf8(value));
             WavpackGetTagItem (ctx, "Title", value, sizeof(value));
             info->setMetaData(Qmmp::TITLE, QString::fromUtf8(value));
+            WavpackGetTagItem (ctx, "Composer", value, sizeof(value));
+            info->setMetaData(Qmmp::COMPOSER, QString::fromUtf8(value));
             WavpackGetTagItem (ctx, "Year", value, sizeof(value));
             info->setMetaData(Qmmp::YEAR, QString::fromUtf8(value).toInt());
             WavpackGetTagItem (ctx, "Track", value, sizeof(value));
             info->setMetaData(Qmmp::TRACK, QString::fromUtf8(value).toInt());
+            WavpackGetTagItem (ctx, "Disc", value, sizeof(value));
+            info->setMetaData(Qmmp::DISCNUMBER, QString::fromUtf8(value).toInt());
         }
     }
 
@@ -114,11 +116,12 @@ QList<FileInfo *> DecoderWavPackFactory::createPlayList(const QString &fileName,
     return list;
 }
 
-QObject* DecoderWavPackFactory::showDetails(QWidget *parent, const QString &path)
+MetaDataModel* DecoderWavPackFactory::createMetaDataModel(const QString &path, QObject *parent)
 {
-    DetailsDialog *d = new DetailsDialog(parent, path);
-    d -> show();
-    return d;
+    if (!path.contains("://") || path.startsWith("wvpack://"))
+        return new WavPackMetaDataModel(path, parent);
+    else
+        return 0;
 }
 
 void DecoderWavPackFactory::showSettings(QWidget *)
@@ -141,4 +144,4 @@ QTranslator *DecoderWavPackFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(DecoderWavPackFactory)
+Q_EXPORT_PLUGIN2(wavpack,DecoderWavPackFactory)
