@@ -30,8 +30,8 @@ const OutputProperties OutputALSAFactory::properties() const
     OutputProperties properties;
     properties.name = tr("ALSA Plugin");
     properties.shortName = "alsa";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = TRUE;
+    properties.hasAbout = true;
+    properties.hasSettings = true;
     return properties;
 }
 
@@ -66,4 +66,4 @@ QTranslator *OutputALSAFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(OutputALSAFactory)
+Q_EXPORT_PLUGIN2(alsa,OutputALSAFactory)
