@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Ilya Kotov                                      *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -31,10 +31,11 @@ extern "C"
 SettingsDialog::SettingsDialog ( QWidget *parent )
         : QDialog ( parent )
 {
-    ui.setupUi ( this );
-    setAttribute ( Qt::WA_DeleteOnClose );
-    ui.deviceComboBox->setEditable ( TRUE );
+    ui.setupUi (this);
+    setAttribute (Qt::WA_DeleteOnClose);
+    ui.deviceComboBox->setEditable (true);
     getCards();
+    getSoftDevices();
     connect (ui.deviceComboBox, SIGNAL(activated(int)),SLOT(setText(int)));
     connect(ui.mixerCardComboBox, SIGNAL(activated(int)), SLOT(showMixerDevices(int)));
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
@@ -54,8 +55,8 @@ SettingsDialog::SettingsDialog ( QWidget *parent )
     if (d >= 0)
         ui.mixerDeviceComboBox->setCurrentIndex(d);
 
-    ui.mmapCheckBox->setChecked(settings.value("use_mmap", FALSE).toBool());
-
+    ui.mmapCheckBox->setChecked(settings.value("use_mmap", false).toBool());
+    ui.pauseCheckBox->setChecked(settings.value("use_snd_pcm_pause", false).toBool());
     settings.endGroup();
 }
 
@@ -88,6 +89,40 @@ void SettingsDialog::getCards()
     }
 }
 
+void SettingsDialog::getSoftDevices()
+{
+#if SND_LIB_VERSION >= 0x011600 //1.22.00
+    void **hints = 0;
+    int i = 0;
+
+    if(snd_device_name_hint(-1, "pcm", &hints) < 0)
+        return;
+
+    while(hints[i])
+    {
+        char *type = snd_device_name_get_hint (hints[i], "IOID");
+        if (!type || !strcmp (type, "Output"))
+        {
+            char *device_name = snd_device_name_get_hint (hints[i], "NAME");
+            char *device_desc = snd_device_name_get_hint (hints[i], "DESC");
+
+            m_devices << QString(device_name);
+            QString str = QString("%1 (%2)").arg(device_desc).arg(device_name);
+            qDebug("%s", qPrintable(str));
+            ui.deviceComboBox->addItem(str);
+            free (device_name);
+            free (device_desc);
+        }
+        if(type)
+            free (type);
+        ++i;
+    }
+
+    if (hints)
+        snd_device_name_free_hint (hints);
+#endif
+}
+
 void SettingsDialog::getCardDevices(int card)
 {
     int pcm_device = -1, err;
@@ -194,6 +229,7 @@ void SettingsDialog::accept()
     }
     settings.setValue("mixer_device", ui.mixerDeviceComboBox->currentText ());
     settings.setValue("use_mmap", ui.mmapCheckBox->isChecked());
+    settings.setValue("use_snd_pcm_pause", ui.pauseCheckBox->isChecked());
     settings.endGroup();
     QDialog::accept();
 }
