@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="cs">
+<!DOCTYPE TS>
+<TS version="2.0" language="cs">
 <context>
     <name>OutputJACKFactory</name>
     <message>
@@ -8,17 +9,17 @@
         <translation>Modul JACK</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="47"/>
+        <location filename="../outputjackfactory.cpp" line="53"/>
         <source>About Jack Output Plugin</source>
         <translation>O modulu JACK</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="48"/>
+        <location filename="../outputjackfactory.cpp" line="54"/>
         <source>Qmmp Jack Output Plugin</source>
         <translation>Výstupní modul Qmmp JACK</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="49"/>
+        <location filename="../outputjackfactory.cpp" line="55"/>
         <source>Writen by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
         <translation>Autor: Jurij Žuravljov &lt;slalkerg@gmail.com&gt;</translation>
     </message>
