@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="uk">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="uk">
 <context>
     <name>OutputJACKFactory</name>
     <message>
@@ -9,17 +9,17 @@
         <translation>Модуль JACK</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="47"/>
+        <location filename="../outputjackfactory.cpp" line="53"/>
         <source>About Jack Output Plugin</source>
         <translation>Про модуль виводу Jack</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="48"/>
+        <location filename="../outputjackfactory.cpp" line="54"/>
         <source>Qmmp Jack Output Plugin</source>
         <translation>Модуль виводу Jack для Qmmp</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="49"/>
+        <location filename="../outputjackfactory.cpp" line="55"/>
         <source>Writen by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
         <translation>Розробник: Юрій Журавльов &lt;slalkerg@gmail.com&gt;</translation>
     </message>
