@@ -31,7 +31,6 @@ extern "C"
 }
 
 #include "outputoss.h"
-#include <qmmp/constants.h>
 #include <qmmp/buffer.h>
 #include <qmmp/visual.h>
 
@@ -65,9 +64,9 @@ OutputOSS* OutputOSS::instance()
 }
 
 OutputOSS::OutputOSS(QObject * parent)
-        : Output(parent), m_inited(FALSE),
-         m_frequency(-1), m_channels(-1), m_precision(-1),
-        do_select(TRUE),
+        : Output(parent), m_inited(false),
+         m_frequency(-1), m_channels(-1),
+        do_select(true),
         m_audio_fd(-1)
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
@@ -90,12 +89,11 @@ OutputOSS::~OutputOSS()
     }
 }
 
-void OutputOSS::configure(quint32 freq, int chan, int prec)
+void OutputOSS::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
 {
     // we need to configure
-    if (freq != m_frequency || chan != m_channels || prec != m_precision)
+    if (freq != m_frequency || chan != m_channels)
     {
-        qDebug("OutputOSS: frequency=%d, channels=%d, bits=%d", freq, chan, prec);
         // we have already configured, but are changing settings...
         // reset the device
         resetDSP();
@@ -112,15 +110,14 @@ void OutputOSS::configure(quint32 freq, int chan, int prec)
 #endif
         m_frequency = freq;
         m_channels = chan;
-        m_precision = prec;
 
         //m_bps = freq * chan * (prec / 8);
 
         int p;
-        switch (prec)
+        switch (format)
         {
         default:
-        case 16:
+        case Qmmp::PCM_S16LE:
 #if defined(AFMT_S16_NE)
             p = AFMT_S16_NE;
 #else
@@ -128,7 +125,7 @@ void OutputOSS::configure(quint32 freq, int chan, int prec)
 #endif
             break;
 
-        case 8:
+        case Qmmp::PCM_S8:
             p = AFMT_S8;
             break;
 
@@ -136,8 +133,8 @@ void OutputOSS::configure(quint32 freq, int chan, int prec)
 
         if (ioctl(m_audio_fd, SNDCTL_DSP_SETFMT, &p) == -1)
             qWarning("OutputOSS: can't set audio format");
-        if(ioctl(m_audio_fd, SNDCTL_DSP_SAMPLESIZE, &prec) == -1)
-            qDebug("OutputOSS: can't set audio format");
+        /*if(ioctl(m_audio_fd, SNDCTL_DSP_SAMPLESIZE, &prec) == -1)
+            qDebug("OutputOSS: can't set audio format");*/
         int stereo = (chan > 1) ? 1 : 0;
             ioctl(m_audio_fd, SNDCTL_DSP_STEREO, &stereo);
         /*if (ioctl(m_audio_fd, SNDCTL_DSP_SPEED, &m_channels) == -1)
@@ -147,7 +144,7 @@ void OutputOSS::configure(quint32 freq, int chan, int prec)
         if (ioctl(m_audio_fd, SNDCTL_DSP_SPEED, &freq) == -1)
             qWarning("OutputOSS: can't set audio format");
     }
-    Output::configure(freq, chan, prec);
+    Output::configure(freq, chan, format);
 }
 
 void OutputOSS::reset()
@@ -215,19 +212,18 @@ bool OutputOSS::initialize()
 {
     reset();
     if (m_audio_fd < 0)
-        return FALSE;
-    m_inited = TRUE;
-    return TRUE;
+        return false;
+    m_inited = true;
+    return true;
 }
 
 void OutputOSS::uninitialize()
 {
     if (!m_inited)
         return;
-    m_inited = FALSE;
+    m_inited = false;
     m_frequency = -1;
     m_channels = -1;
-    m_precision = -1;
     resetDSP();
     if (m_audio_fd > 0)
     {
@@ -278,7 +274,7 @@ VolumeControlOSS *VolumeControlOSS::instance()
 
 VolumeControlOSS::VolumeControlOSS(QObject *parent) : VolumeControl(parent)
 {
-    m_master = TRUE;
+    m_master = true;
     m_mixer_fd = -1;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
 #if SOUND_VERSION < 0x040000
@@ -287,13 +283,13 @@ VolumeControlOSS::VolumeControlOSS(QObject *parent) : VolumeControl(parent)
 #else
     m_mixer_device = settings.value("OSS/device","/dev/dsp").toString();
     int mixer_fd = -1;
-    bool to_close = FALSE;
+    bool to_close = false;
     if (OutputOSS::instance() && OutputOSS::instance()->audio_fd() > 0)
         mixer_fd = OutputOSS::instance()->audio_fd();
     else
     {
         mixer_fd = open(m_audio_device.toAscii(), O_WRONLY, 0);
-        to_close = TRUE;
+        to_close = true;
     }
     if(mixer_fd > 0)
     {
