@@ -35,8 +35,8 @@ const OutputProperties OutputOSSFactory::properties() const
     OutputProperties properties;
     properties.name = tr("OSS Plugin");
     properties.shortName = "oss";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = TRUE;
+    properties.hasAbout = true;
+    properties.hasSettings = true;
     return properties;
 }
 
@@ -67,4 +67,4 @@ QTranslator *OutputOSSFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(OutputOSSFactory)
+Q_EXPORT_PLUGIN2(oss,OutputOSSFactory)
