@@ -28,8 +28,8 @@ const OutputProperties OutputPulseAudioFactory::properties() const
 {
     OutputProperties properties;
     properties.name = tr("PulseAudio Plugin");
-    properties.hasAbout = TRUE;
-    properties.hasSettings = FALSE;
+    properties.hasAbout = true;
+    properties.hasSettings = false;
     properties.shortName = "pulse";
     return properties;
 }
@@ -64,4 +64,4 @@ QTranslator *OutputPulseAudioFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(OutputPulseAudioFactory)
+Q_EXPORT_PLUGIN2(pulseaudio, OutputPulseAudioFactory)
