@@ -7,7 +7,8 @@
 #ifndef   __buffer_h
 #define   __buffer_h
 
-#include "constants.h"
+#define QMMP_BLOCK_SIZE (2048*6) //512*4*6
+#define QMMP_BUFFER_SIZE (QMMP_BLOCK_SIZE*64)
 
 /*! @brief Audio buffer class.
  * @author Brad Hughes <bhughes@trolltech.com>
@@ -20,34 +21,27 @@ public:
      */
     Buffer()
     {
-        data = new unsigned char[Buffer::size()];
+        data = new unsigned char[QMMP_BLOCK_SIZE];
         nbytes = 0;
         rate = 0;
-        exceeding = 0;
+        size = QMMP_BLOCK_SIZE;
     }
     /*!
      * Destructor.
      */
     ~Buffer()
     {
-        delete data;
+        delete[] data;
         data = 0;
         nbytes = 0;
         rate = 0;
-        exceeding = 0;
+        size = 0;
     }
 
     unsigned char *data;      /*!< Audio data */
     unsigned long nbytes;     /*!< Audio data size */
     unsigned long rate;       /*!< Buffer bitrate */
-    unsigned long exceeding;  /*!< The number of bytes on which the size of buffer exceeds the size of the block */
-    /*!
-     * Returns block size.
-     */
-    static unsigned long size()
-    {
-        return globalBlockSize;
-    }
+    unsigned long size;       /*!< Buffer size */
 };
 
 
