@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Ilya Kotov                                      *
+ *   Copyright (C) 2007-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,24 +21,27 @@
 #include <QStringList>
 #include <QDir>
 #include <QApplication>
-
+#include "qmmpaudioengine.h"
 #include "qmmp.h"
 #include "effectfactory.h"
-#include "constants.h"
 #include "effect.h"
 
-Effect::Effect(QObject *parent)
-        : QObject(parent)
-{}
+Effect::Effect()
+{
+    m_freq = 0;
+    m_chan = 0;
+    m_format = Qmmp::PCM_UNKNOWM;
+    m_factory = 0;
+}
 
 Effect::~Effect()
 {}
 
-void Effect::configure(quint32 freq, int chan, int res)
+void Effect::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
 {
     m_freq = freq;
     m_chan = chan;
-    m_res = res;
+    m_format = format;
 }
 
 quint32 Effect::sampleRate()
@@ -51,22 +54,34 @@ int Effect::channels()
     return m_chan;
 }
 
-int Effect::bitsPerSample()
+Qmmp::AudioFormat Effect::format()
 {
-    return m_res;
+    return m_format;
 }
 
-static QList<EffectFactory*> *factories = 0;
-static QStringList files;
-
-static void checkFactories()
+const AudioParameters  Effect::audioParameters() const
 {
-    if (! factories)
-    {
-        files.clear();
-        factories = new QList<EffectFactory *>;
+    return AudioParameters(m_freq, m_chan, m_format);
+}
 
-         QDir pluginsDir (Qmmp::pluginsPath());
+EffectFactory* Effect::factory() const
+{
+    return m_factory;
+}
+
+//static members
+
+QList<EffectFactory*> *Effect::m_factories = 0;
+QStringList Effect::m_files;
+
+void Effect::checkFactories()
+{
+    if (!m_factories)
+    {
+        m_files.clear();
+        m_factories = new QList<EffectFactory *>;
+
+        QDir pluginsDir (Qmmp::pluginsPath());
         pluginsDir.cd("Effect");
         foreach (QString fileName, pluginsDir.entryList(QDir::Files))
         {
@@ -83,43 +98,46 @@ static void checkFactories()
 
             if (factory)
             {
-                factories->append(factory);
-                files << pluginsDir.absoluteFilePath(fileName);
+                m_factories->append(factory);
+                m_files << pluginsDir.absoluteFilePath(fileName);
                 qApp->installTranslator(factory->createTranslator(qApp));
             }
         }
     }
 }
 
-QList<Effect*> Effect::create(QObject *parent)
+QList<Effect*> Effect::create()
 {
     checkFactories();
     QList<Effect*> effects;
     EffectFactory *factory = 0;
-    foreach (factory, *factories)
+    foreach (factory, *m_factories)
     {
         if(isEnabled(factory))
-            effects.append(factory->create(parent));
+        {
+            effects.append(factory->create());
+            effects.last()->m_factory = factory;
+        }
     }
     return effects;
 }
 
-QList<EffectFactory*> *Effect::effectFactories()
+QList<EffectFactory*> *Effect::factories()
 {
     checkFactories();
-    return factories;
+    return m_factories;
 }
 
-QStringList Effect::effectFiles()
+QStringList Effect::files()
 {
     checkFactories();
-    return files;
+    return m_files;
 }
 
 void Effect::setEnabled(EffectFactory* factory, bool enable)
 {
     checkFactories();
-    if(!factories->contains(factory))
+    if(!m_factories->contains(factory))
         return;
 
     QString name = factory->properties().shortName;
@@ -129,20 +147,28 @@ void Effect::setEnabled(EffectFactory* factory, bool enable)
     if(enable)
     {
         if (!effList.contains(name))
+        {
             effList << name;
+            if(QmmpAudioEngine::instance())
+                QmmpAudioEngine::instance()->addEffect(factory);
+        }
     }
-    else
+    else if (effList.contains(name))
+    {
         effList.removeAll(name);
+        if(QmmpAudioEngine::instance())
+            QmmpAudioEngine::instance()->removeEffect(factory);
+    }
     settings.setValue("Effect/enabled_plugins", effList);
 }
 
 bool Effect::isEnabled(EffectFactory* factory)
 {
     checkFactories();
-    if(!factories->contains(factory))
-        return FALSE;
+    if(!m_factories->contains(factory))
+        return false;
     QString name = factory->properties().shortName;
-    QSettings settings ( Qmmp::configFile(), QSettings::IniFormat );
+    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
     QStringList effList = settings.value("Effect/enabled_plugins").toStringList();
     return effList.contains(name);
 }
