@@ -20,43 +20,40 @@
 #ifndef EFFECT_H
 #define EFFECT_H
 
-#include <QObject>
 #include <QList>
 #include <QStringList>
+#include "audioparameters.h"
+#include "buffer.h"
 
 class EffectFactory;
 
 /*! @brief The Effect class provides the base interface class of audio effects.
  * @author Ilya Kotov <forkotov02@hotmail.ru>
  */
-class Effect : public QObject
+class Effect
 {
-    Q_OBJECT
 public:
     /*!
      * Object contsructor.
-     * @param parent Parent object.
      */
-    Effect(QObject *parent = 0);
+    Effect();
     /*!
      * Destructor.
      */
     virtual ~Effect();
     /*!
-     * Adds effect to the input data pointer \b in_data with the size \b size.
-     * Result is stored in the output data \b out_data.
-     * Return value is the size of the output data.
+     * Adds audio effect to the buffer \b b.
      * Subclass should implement this function.
      */
-    virtual ulong process(char *in_data, const ulong size, char **out_data) = 0;
+    virtual void applyEffect(Buffer *b) = 0;
     /*!
      * Prepares object for usage.
      * Subclasses that reimplement this function must call the base implementation.
-     * @param freq Sample rate.
+     * @param srate Sample rate.
      * @param chan Number of channels.
-     * @param res Bits per sample.
+     * @param f Audio format.
      */
-    virtual void configure(quint32 freq, int chan, int res);
+    virtual void configure(quint32 srate = 44100, int chan = 2, Qmmp::AudioFormat f = Qmmp::PCM_S16LE);
     /*!
      * Returns samplerate.
      */
@@ -66,28 +63,35 @@ public:
      */
     int channels();
     /*!
-     * Returns bits per sample.
+     * Returns audio format.
      */
-    int bitsPerSample();
+    Qmmp::AudioFormat format();
+    /*!
+     * Returns audio parameters for output data.
+     */
+    const AudioParameters audioParameters() const;
+    /*!
+     * Returns assigned factory object.
+     */
+    EffectFactory* factory() const;
     /*!
      * Creates a list of enabled effects.
-     * @param parent Parent object of all created Effect objects.
      */
-    static QList<Effect*> create(QObject *parent);
+    static QList<Effect*> create();
     /*!
      * Returns a list of effect factories.
      */
-    static QList<EffectFactory*> *effectFactories();
+    static QList<EffectFactory*> *factories();
     /*!
      * Returns a list of effect plugin file names.
      */
-    static QStringList effectFiles();
+    static QStringList files();
     /*!
      * Sets whether the effect plugin is enabled.
      * @param factory Effect plugin factory.
      * @param enable Plugin enable state (\b true - enable, \b false - disable)
      */
-    static void setEnabled(EffectFactory* factory, bool enable = TRUE);
+    static void setEnabled(EffectFactory* factory, bool enable = true);
     /*!
      * Returns \b true if input plugin is enabled, otherwise returns \b false
      * @param factory Effect plugin factory.
@@ -95,9 +99,13 @@ public:
     static bool isEnabled(EffectFactory* factory);
 
 private:
+    EffectFactory *m_factory;
     quint32 m_freq;
     int m_chan;
-    int m_res;
+    Qmmp::AudioFormat m_format;
+    static void checkFactories();
+    static QList<EffectFactory*> *m_factories;
+    static QStringList m_files;
 };
 
 #endif
