@@ -27,7 +27,7 @@ class QWidget;
 class QTranslator;
 class Effect;
 
-/*! @brief Helper class to store effect plugin properies.
+/*! @brief Helper class to store effect plugin properties.
  * @author Ilya Kotov <forkotov02@hotmail.ru>
  */
 class EffectProperties
@@ -38,29 +38,28 @@ public:
      */
     EffectProperties()
     {
-        hasAbout = FALSE;
-        hasSettings = FALSE;
+        hasAbout = false;
+        hasSettings = false;
     }
     QString name;      /*!< Effect plugin full name */
     QString shortName; /*!< Effect plugin short name for internal usage */
     bool hasAbout;     /*!< Should be \b true if plugin has about dialog, otherwise returns \b false */
     bool hasSettings;  /*!< Should be \b true if plugin has settings dialog, otherwise returns \b false */
 };
-/*! @brief %Effect plugin interface (effect factory).
+/*! @brief Effect plugin interface (effect factory).
  * @author Ilya Kotov <forkotov02@hotmail.ru>
  */
 class EffectFactory
 {
 public:
     /*!
-     * Returns general plugin properties.
+     * Returns effect plugin properties.
      */
     virtual const EffectProperties properties() const = 0;
     /*!
      * Creates effect provided by plugin.
-     * @param parent Parent object.
      */
-    virtual Effect *create(QObject *parent) = 0;
+    virtual Effect *create() = 0;
     /*!
      * Shows settings dialog.
      * @param parent Parent widget.
