@@ -55,9 +55,9 @@ public:
      * Setups audio parameters of output interface.
      * @param freq Sample rate.
      * @param chan Number of channels.
-     * @param bits Bits per sample
+     * @param format Audio format
      */
-    virtual void configure(quint32 freq, int chan, int bits);
+    virtual void configure(quint32 freq, int chan, Qmmp::AudioFormat format);
     /*!
      * Requests playback to pause. If it was paused already, playback should resume.
      * Subclasses that reimplement this function must call the base implementation.
@@ -101,23 +101,27 @@ public:
      */
     int numChannels();
     /*!
-     * Returns bits per sample.
+     * Returns selected audio format.
      */
-    int sampleSize();
+    Qmmp::AudioFormat format() const;
+    /*!
+     * Returns sample size in bytes.
+     */
+    int sampleSize() const;
     /*!
      * Creates selected output.
      * @param parent Parent object.
      * @return Output subclass object.
      */
-    static Output *create(QObject *parent);
+    static Output *create(QObject *parent = 0);
     /*!
      * Returns a list of output factories.
      */
-    static QList<OutputFactory*> *outputFactories();
+    static QList<OutputFactory*> *factories();
     /*!
      * Returns a list of output plugin file names.
      */
-    static QStringList outputFiles();
+    static QStringList files();
     /*!
      * Selects current output \b factory.
      */
@@ -143,32 +147,33 @@ protected:
 private:
     void run(); //thread run function
     void status();
-    void changeVolume(uchar *data, qint64 size, int chan);
     void dispatch(qint64 elapsed,
-                  qint64 totalTime,
                   int bitrate,
                   int frequency,
-                  int precision,
+                  int bits,
                   int channels);
     void dispatch(const Qmmp::State &state);
-    void dispatchVisual(Buffer *, unsigned long, int, int);
+    void dispatchVisual(Buffer *buffer);
     void clearVisuals();
     QMutex m_mutex;
     Recycler m_recycler;
     StateHandler *m_handler;
     quint32 m_frequency;
-    int m_channels, m_precision, m_kbps;
+    int m_channels, m_kbps;
+    Qmmp::AudioFormat m_format;
     qint64 m_bytesPerMillisecond;
     bool m_userStop, m_pause;
     bool m_finish;
     qint64 m_totalWritten, m_currentMilliseconds;
+    unsigned char *m_visBuffer;
+    qint64 m_visBufferSize;
+
 
     static void checkFactories();
     static void registerFactory(OutputFactory *);
     //TODO use QMap instead
     static QList<OutputFactory*> *m_factories;
     static QStringList m_files;
-    static QTimer *m_timer;
 };
 
 
