@@ -5,14 +5,12 @@
 //
 
 #include "recycler.h"
-#include "constants.h"
 #include "buffer.h"
 
-
-Recycler::Recycler ( unsigned int sz )
-        : add_index ( 0 ), done_index ( 0 ), current_count ( 0 )
+Recycler::Recycler (unsigned int sz)
+        : add_index (0), done_index (0), current_count (0)
 {
-    buffer_count = sz / Buffer::size();
+    buffer_count = sz / QMMP_BLOCK_SIZE;
     if (buffer_count < 4)
     {
         buffer_count = 4;
@@ -20,22 +18,23 @@ Recycler::Recycler ( unsigned int sz )
 
     buffers = new Buffer*[buffer_count];
 
-    for ( unsigned int i = 0; i < buffer_count; i ++ )
+    for (unsigned int i = 0; i < buffer_count; i++)
     {
         buffers[i] = new Buffer;
     }
+    m_blocked = 0;
 }
 
 
 Recycler::~Recycler()
 {
-    for ( unsigned int i = 0; i < buffer_count; i++ )
+    for (unsigned int i = 0; i < buffer_count; i++)
     {
         delete buffers[i];
         buffers[i] = 0;
     }
-
     delete [] buffers;
+    m_blocked = 0;
 }
 
 
@@ -44,6 +43,11 @@ bool Recycler::full() const
     return current_count == buffer_count;
 }
 
+bool Recycler::blocked()
+{
+    return buffers[add_index] == m_blocked;
+}
+
 
 bool Recycler::empty() const
 {
@@ -62,18 +66,10 @@ int Recycler::used() const
 }
 
 
-Buffer *Recycler::get(unsigned long size)
+Buffer *Recycler::get()
 {
     if (full())
         return 0;
-    if (size > Buffer::size() + buffers[add_index]->exceeding)
-    {
-        delete buffers[add_index]->data;
-        buffers[add_index]->data = new unsigned char[size];
-        buffers[add_index]->exceeding = size - Buffer::size();
-        //qDebug("new size = %d, index = %d", size, add_index);
-    }
-
     return buffers[add_index];
 }
 
@@ -84,28 +80,34 @@ void Recycler::add()
     current_count++;
 }
 
-
 Buffer *Recycler::next()
 {
-    return empty() ? 0 : buffers[done_index];
+    if(current_count)
+    {
+        m_blocked = buffers[done_index];
+        return m_blocked;
+    }
+    return 0;
 }
 
-
 void Recycler::done()
 {
-    done_index = ++done_index % buffer_count;
+    m_blocked = 0;
     if (current_count)
+    {
         current_count--;
+        done_index = ++done_index % buffer_count;
+    }
 }
 
-
 void Recycler::clear()
 {
-    add_index = done_index = current_count = 0;
+    current_count = 0;
+    add_index = 0;
+    done_index = 0;
 }
 
-
 unsigned int Recycler::size() const
 {
-    return buffer_count * Buffer::size();
+    return buffer_count * QMMP_BLOCK_SIZE;
 }
