@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,9 +26,12 @@
 #include "output.h"
 #include "visual.h"
 #include "qmmp.h"
+#include "qmmpsettings.h"
 
 class QIODevice;
 class VolumeControl;
+class AbstractEngine;
+class InputSource;
 
 /*! \brief The SoundCore class provides a simple interface for audio playback.
  * @author Ilya Kotov <forkotov02@hotmail.ru>
@@ -67,10 +70,6 @@ public:
      * Returns left volume level.
      */
     int rightVolume();
-    /*!
-     * Returns \b true if software volume is used, otherwise returns \b false
-     */
-    bool softwareVolume();
     /*!
      * Returns the current time (in milliseconds).
      */
@@ -103,18 +102,13 @@ public:
      * Returns the metdata string associated with the given \b key.
      */
     QString metaData(Qmmp::MetaData key);
-    /*!
+     /*!
      * Returns a pointer to the SoundCore instance.
      */
     static SoundCore* instance();
 
 
 public slots:
-    /*!
-     * This funtion allows to force software volume for all output plugins.
-     * @param yes Software volume enable state (\b true - enable, \b false - disable)
-     */
-    void setSoftwareVolume(bool yes);
     /*!
      * Sets volume.
      * @param left - volume of the left channel \b [0..100].
@@ -123,10 +117,10 @@ public slots:
     void setVolume(int left, int right);
     /*!
      * This function plays file or stream with the given path \p source.
-     * Returns \b true if playback started successful or source is not a local file,
+     * Returns \b true if playback has been started successful or source is not a local file,
      * otherwise returns \b false. Useful for invalid files skipping.
      */
-    bool play(const QString &source);
+    bool play(const QString &source, bool queue = false, qint64 offset = -1);
     /*!
      *  Stops playback
      */
@@ -193,17 +187,19 @@ signals:
      * @param right Right channel volume level. It should be \b [0..100]
      */
     void volumeChanged(int left, int right);
+    /*!
+     * Emitted before the playback ends.
+     */
+    void aboutToFinish();
 
 private slots:
-    bool decode();
+    bool enqueue(InputSource *);
+    void startPendingEngine();
+    void updateVolume();
 
 private:
     Decoder* m_decoder;
-    DecoderFactory* m_factory;
-    //QUrl m_url;
-    QString m_source;
-    Output* m_output;
-    QIODevice* m_input;
+    QString m_url;
     uint m_error;
     bool m_paused;
     bool m_useEQ;
@@ -217,6 +213,9 @@ private:
     static SoundCore* m_instance;
     StateHandler *m_handler;
     VolumeControl *m_volumeControl;
+    AbstractEngine *m_engine;
+    AbstractEngine *m_pendingEngine;
+    QList<InputSource *> m_pendingSources;
 };
 
 #endif
