@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,7 +38,7 @@ GeneralHandler::GeneralHandler(QObject *parent)
     m_toolsMenu = 0;
     m_playlistMenu = 0;
     GeneralFactory* factory;
-    foreach(factory, *General::generalFactories())
+    foreach(factory, *General::factories())
     {
         if (General::isEnabled(factory))
         {
@@ -94,18 +94,18 @@ void GeneralHandler::showSettings(GeneralFactory* factory, QWidget* parentWidget
 bool GeneralHandler::visibilityControl()
 {
     GeneralFactory* factory;
-    foreach(factory, *General::generalFactories())
+    foreach(factory, *General::factories())
     {
         if (General::isEnabled(factory) && factory->properties().visibilityControl)
-            return TRUE;
+            return true;
     }
-    return FALSE;
+    return false;
 }
 
-void GeneralHandler::executeCommand(const QString &opt_str)
+void GeneralHandler::executeCommand(const QString &opt_str, const QStringList &args)
 {
     if (CommandLineManager::hasOption(opt_str))
-        m_commandLineManager->executeCommand(opt_str);
+        m_commandLineManager->executeCommand(opt_str, args);
 }
 
 void GeneralHandler::addAction(QAction *action, MenuType type)
