@@ -55,7 +55,7 @@ AboutDialog::AboutDialog(QWidget* parent, Qt::WFlags fl)
         : QDialog( parent, fl )
 {
     setupUi(this);
-    setAttribute(Qt::WA_QuitOnClose, FALSE);
+    setAttribute(Qt::WA_QuitOnClose, false);
     licenseTextEdit->setPlainText(getstringFromResource(":COPYING"));
     aboutTextEdit->setHtml(loadAbout());
     authorsTextEdit->setPlainText(getstringFromResource(tr(":/txt/authors_en.txt")));
@@ -92,7 +92,7 @@ QString AboutDialog::loadAbout()
     text.append("</ul>");
     text.append("<h5>"+tr("Output plugins:")+"</h5>");
     text.append("<ul type=\"square\">");
-    foreach(OutputFactory *fact, *Output::outputFactories())
+    foreach(OutputFactory *fact, *Output::factories())
     {
         text.append("<li>");
         text.append(fact->properties().name);
@@ -110,7 +110,7 @@ QString AboutDialog::loadAbout()
     text.append("</ul>");
     text.append("<h5>"+tr("Effect plugins:")+"</h5>");
     text.append("<ul type=\"square\">");
-    foreach(EffectFactory *fact, *Effect::effectFactories())
+    foreach(EffectFactory *fact, *Effect::factories())
     {
         text.append("<li>");
         text.append(fact->properties().name);
@@ -119,7 +119,7 @@ QString AboutDialog::loadAbout()
     text.append("</ul>");
     text.append("<h5>"+tr("General plugins:")+"</h5>");
     text.append("<ul type=\"square\">");
-    foreach(GeneralFactory *fact, *General::generalFactories())
+    foreach(GeneralFactory *fact, *General::factories())
     {
         text.append("<li>");
         text.append(fact->properties().name);
