@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,14 +20,18 @@
 
 #include <QSettings>
 #include <QDir>
-#include <QHttp>
+#include <QNetworkAccessManager>
+#include <QNetworkRequest>
+#include <QNetworkReply>
+#include <QNetworkProxy>
 #include <QUrl>
 #include <QMessageBox>
-#include "addurldialog.h"
 #include <qmmpui/playlistparser.h>
 #include <qmmpui/playlistformat.h>
 #include <qmmpui/playlistmodel.h>
+#include <qmmp/qmmpsettings.h>
 #include <qmmp/qmmp.h>
+#include "addurldialog.h"
 
 #define HISTORY_SIZE 10
 
@@ -35,17 +39,23 @@ AddUrlDialog::AddUrlDialog( QWidget * parent, Qt::WindowFlags f) : QDialog(paren
 {
     setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
-    setAttribute(Qt::WA_QuitOnClose, FALSE);
+    setAttribute(Qt::WA_QuitOnClose, false);
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     m_history = settings.value("URLDialog/history").toStringList();
     urlComboBox->addItems(m_history);
-    m_http = new QHttp(this);
+    m_http = new QNetworkAccessManager(this);
     //load global proxy settings
-    if (Qmmp::useProxy())
-        m_http->setProxy(Qmmp::proxy().host(),
-                         Qmmp::proxy().port(),
-                         Qmmp::useProxyAuth() ? Qmmp::proxy().userName() : QString(),
-                         Qmmp::useProxyAuth() ? Qmmp::proxy().password() : QString());
+    QmmpSettings *gs = QmmpSettings::instance();
+    if (gs->isProxyEnabled())
+    {
+        QNetworkProxy proxy(QNetworkProxy::HttpProxy, gs->proxy().host(),  gs->proxy().port());
+        if(gs->useProxyAuth())
+        {
+            proxy.setUser(gs->proxy().userName());
+            proxy.setPassword(gs->proxy().password());
+        }
+        m_http->setProxy(proxy);
+    }
 }
 
 AddUrlDialog::~AddUrlDialog()
@@ -54,7 +64,6 @@ AddUrlDialog::~AddUrlDialog()
         m_history.removeLast();
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.setValue("URLDialog/history", m_history);
-    m_http->close();
 }
 
 QPointer<AddUrlDialog> AddUrlDialog::instance = 0;
@@ -86,12 +95,12 @@ void AddUrlDialog::accept( )
             PlaylistFormat* prs = PlaylistParser::instance()->findByPath(s);
             if (prs)
             {
-                //download playlist;
-                QUrl url(s);
-                m_http->setHost(url.host(), url.port(80));
-                connect(m_http, SIGNAL(done (bool)), SLOT(readResponse(bool)));
-                m_http->get(url.path());
-                addButton->setEnabled(FALSE);
+                connect(m_http, SIGNAL(finished (QNetworkReply *)), SLOT(readResponse(QNetworkReply *)));
+                QNetworkRequest request;
+                request.setUrl(QUrl(s));
+                request.setRawHeader("User-Agent", QString("qmmp/%1").arg(Qmmp::strVersion()).toAscii());
+                addButton->setEnabled(false);
+                m_http->get(request);
                 return;
             }
         }
@@ -100,21 +109,23 @@ void AddUrlDialog::accept( )
     QDialog::accept();
 }
 
-void AddUrlDialog::readResponse(bool error)
+void AddUrlDialog::readResponse(QNetworkReply *reply)
 {
-    disconnect(m_http, SIGNAL(done (bool)));
-    if (error)
-        QMessageBox::critical (this, tr("Error"), m_http->errorString ());
+    addButton->setEnabled(true);
+    disconnect(m_http, SIGNAL(finished (QNetworkReply *)), 0, 0);
+    if (reply->error() != QNetworkReply::NoError)
+        QMessageBox::critical (this, tr("Error"), reply->errorString ());
     else if (!urlComboBox->currentText().isEmpty())
     {
         QString s = urlComboBox->currentText();
         PlaylistFormat* prs = PlaylistParser::instance()->findByPath(s);
         if (prs)
         {
-            m_model->addFiles(prs->decode(m_http->readAll()));
+            m_model->addFiles(prs->decode(reply->readAll()));
             QDialog::accept();
         }
     }
+    reply->deleteLater();
 }
 
 void AddUrlDialog::setModel( PlayListModel *m )
