@@ -25,13 +25,15 @@
 #include "skin.h"
 #include <QMouseEvent>
 
-Button::Button (QWidget *parent, uint normal, uint pressed)
+Button::Button (QWidget *parent, uint normal, uint pressed, uint cursor)
         : PixmapWidget (parent)
 {
     name_normal = normal;
     name_pressed = pressed;
-    skin = Skin::getPointer();
-    setON (FALSE);
+    name_cursor = cursor;
+    skin = Skin::instance();
+    setON (false);
+    setCursor (skin->getCursor (name_cursor));
     connect (skin, SIGNAL (skinChanged()), this, SLOT (updateSkin()));
 }
 
@@ -42,6 +44,7 @@ Button::~Button()
 void Button::updateSkin()
 {
     setPixmap (skin->getButton (name_normal));
+    setCursor (skin->getCursor (name_cursor));
 }
 
 void Button::setON (bool on)
@@ -53,14 +56,14 @@ void Button::setON (bool on)
 }
 void Button::mousePressEvent (QMouseEvent *e)
 {
-    setON (TRUE);
-    m_cursorin = TRUE;
+    setON (true);
+    m_cursorin = true;
     QWidget::mousePressEvent(e);
 }
 
 void Button::mouseReleaseEvent (QMouseEvent*)
 {
-    setON (FALSE);
+    setON (false);
     if (m_cursorin)
         emit clicked();
 }
@@ -68,10 +71,10 @@ void Button::mouseReleaseEvent (QMouseEvent*)
 void Button::mouseMoveEvent (QMouseEvent *e)
 {
     if ( !m_cursorin && rect().contains(e->pos()) ) {
-        m_cursorin = TRUE;
-        setON (TRUE);
+        m_cursorin = true;
+        setON (true);
     } else if ( m_cursorin && !rect().contains(e->pos()) ) {
-        m_cursorin = FALSE;
-        setON (FALSE);
+        m_cursorin = false;
+        setON (false);
     }
 }
