@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Ilya Kotov                                      *
+ *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,40 +27,38 @@
 #include "eqslider.h"
 
 
-EqSlider::EqSlider(QWidget *parent)
-        : PixmapWidget(parent)
+EqSlider::EqSlider(QWidget *parent): PixmapWidget(parent)
 {
-    m_skin = Skin::getPointer();
+    m_skin = Skin::instance();
     connect(m_skin, SIGNAL(skinChanged()), this, SLOT(updateSkin()));
     setPixmap(m_skin->getEqSlider(0));
-    m_moving = FALSE;
+    m_moving = false;
     m_min = -20;
     m_max = 20;
     m_old = m_value = 0;
-    draw(FALSE);
+    draw(false);
+    setCursor(m_skin->getCursor(Skin::CUR_EQSLID));
 }
 
-
 EqSlider::~EqSlider()
 {}
 
 void EqSlider::mousePressEvent(QMouseEvent *e)
 {
-    m_moving = TRUE;
+    m_moving = true;
     press_pos = e->y();
-    if (m_pos<e->y() && e->y()<m_pos+11)
+    if (m_pos<e->y() && e->y()<m_pos+11*m_skin->ratio())
     {
         press_pos = e->y()-m_pos;
     }
     else
     {
-        m_value = convert(qMax(qMin(height()-12,e->y()-6),0));
-        press_pos = 6;
+        m_value = convert(qMax(qMin(height()-12*m_skin->ratio(),e->y()-6*m_skin->ratio()),0));
+        press_pos = 6*m_skin->ratio();
         if (m_value!=m_old)
         {
             emit sliderMoved(m_value);
             m_old = m_value;
-            //qDebug ("%d",m_value);
         }
     }
     draw();
@@ -68,8 +66,8 @@ void EqSlider::mousePressEvent(QMouseEvent *e)
 
 void EqSlider::mouseReleaseEvent(QMouseEvent*)
 {
-    m_moving = FALSE;
-    draw(FALSE);
+    m_moving = false;
+    draw(false);
 }
 
 void EqSlider::mouseMoveEvent(QMouseEvent* e)
@@ -79,7 +77,7 @@ void EqSlider::mouseMoveEvent(QMouseEvent* e)
         int po = e->y();
         po = po - press_pos;
 
-        if (0<=po && po<=height()-12)
+        if (0<=po && po<=height()-12*m_skin->ratio())
         {
             m_value = convert(po);
             draw();
@@ -104,23 +102,25 @@ void EqSlider::setValue(double p)
     if (m_moving)
         return;
     m_value = -p;
-    draw(FALSE);
+    draw(false);
 }
 
 void EqSlider::setMax(double m)
 {
     m_max = m;
-    draw(FALSE);
+    draw(false);
 }
 
 void EqSlider::updateSkin()
 {
-    draw(FALSE);
+    resize(m_skin->getEqSlider(0).size());
+    draw(false);
+    setCursor(m_skin->getCursor(Skin::CUR_EQSLID));
 }
 
 void EqSlider::draw(bool pressed)
 {
-    int p=int(ceil(double(m_value-m_min)*(height()-12)/(m_max-m_min)));
+    int p=int(ceil(double(m_value-m_min)*(height()-12*m_skin->ratio())/(m_max-m_min)));
     m_pixmap = m_skin->getEqSlider(27-27*(m_value-m_min)/(m_max-m_min));
     QPainter paint(&m_pixmap);
     if (pressed)
@@ -133,7 +133,7 @@ void EqSlider::draw(bool pressed)
 
 double EqSlider::convert(int p)
 {
-    return (m_max - m_min)*(p)/(height() - 12) + m_min;
+    return (m_max - m_min)*(p)/(height() - 12*m_skin->ratio()) + m_min;
 }
 
 void EqSlider::wheelEvent(QWheelEvent *e)
@@ -141,7 +141,7 @@ void EqSlider::wheelEvent(QWheelEvent *e)
     m_value -= e->delta()/60;
     m_value = m_value > m_max ? m_max : m_value;
     m_value = m_value < m_min ? m_min : m_value;
-    draw(FALSE);
+    draw(false);
     emit sliderMoved(m_value);
 }
 
