@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Ilya Kotov                                      *
+ *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,14 +22,13 @@
 
 #include "pixmapwidget.h"
 
-/**
-	@author Ilya Kotov <forkotov02@hotmail.ru>
-*/
 class QMouseEvent;
 class QWheelEvent;
-
 class Skin;
 
+/**
+    @author Ilya Kotov <forkotov02@hotmail.ru>
+*/
 class EqSlider : public PixmapWidget
 {
 Q_OBJECT
@@ -57,7 +56,7 @@ private:
     double m_max, m_min, m_pos, m_value, m_old;
     QPixmap m_pixmap;
     double convert(int);   // value = convert(position);
-    void draw(bool pressed = TRUE);
+    void draw(bool pressed = true);
 
 protected:
     void mousePressEvent(QMouseEvent*);
