@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,40 +22,37 @@
 #include <QPainter>
 #include <QMenu>
 #include <QActionGroup>
-
 #include <qmmp/buffer.h>
-#include <qmmp/output.h>
+#include <qmmp/qmmp.h>
 #include <math.h>
 #include <stdlib.h>
-
 #include "skin.h"
 #include "fft.h"
 #include "inlines.h"
 #include "mainvisual.h"
 
 
-MainVisual *MainVisual::pointer = 0;
+MainVisual *MainVisual::m_instance = 0;
 
-MainVisual *MainVisual::getPointer()
+MainVisual *MainVisual::instance()
 {
-    if (!pointer)
-        qFatal ("MainVisual: this object not created!");
-    return pointer;
+    if (!m_instance)
+        qFatal ("MainVisual: this object is not created!");
+    return m_instance;
 }
 
 MainVisual::MainVisual (QWidget *parent)
-        : Visual (parent), m_vis (0), m_playing (FALSE)
+        : Visual (parent), m_vis (0), m_playing (false)
 {
-    m_skin = Skin::getPointer();
+    m_skin = Skin::instance();
+    m_ratio = m_skin->ratio();
     connect(m_skin, SIGNAL(skinChanged()), this, SLOT(updateSettings()));
-    resize(75,20);
-    m_pixmap = QPixmap (75,20);
     m_timer = new QTimer (this);
     connect(m_timer, SIGNAL (timeout()), this, SLOT (timeout()));
     m_nodes.clear();
     createMenu();
     readSettings();
-    pointer = this;
+    m_instance = this;
 }
 
 MainVisual::~MainVisual()
@@ -72,6 +69,7 @@ MainVisual::~MainVisual()
     settings.setValue("Visualization/rate", 1000/m_timer->interval());
     while (!m_nodes.isEmpty())
         delete m_nodes.takeFirst();
+    m_instance = 0;
 }
 
 void MainVisual::setVisual (VisualBase *newvis)
@@ -99,42 +97,32 @@ void MainVisual::clear()
     update();
 }
 
-void MainVisual::add (Buffer *b, unsigned long w, int c, int p)
+void MainVisual::add (unsigned char *data, qint64 size, int chan)
 {
     if (!m_timer->isActive () || !m_vis)
         return;
-    long len = b->nbytes, cnt;
+
     short *l = 0, *r = 0;
-
-    len /= c;
-    len /= (p / 8);
-    if (len > 512)
-        len = 512;
-    cnt = len;
-
-    if (c == 2)
+    qint64 samples = size/chan >> 1;
+    int frames = samples/512;
+    for (int i = 0; i < frames; ++i)
     {
-        l = new short[len];
-        r = new short[len];
-
-        if (p == 8)
-            stereo16_from_stereopcm8 (l, r, b->data, cnt);
-        else if (p == 16)
-            stereo16_from_stereopcm16 (l, r, (short *) b->data, cnt);
+        l = new short[512];
+        r = 0;
+        if (chan == 2)
+        {
+            r = new short[512];
+            stereo16_from_stereopcm16 (l, r, (short *) (data + i*4*512), 512);
+        }
+        else if (chan == 1)
+            mono16_from_monopcm16 (l, (short *) (data + i*2*512), 512);
+        else
+        {
+            r = new short[512];
+            stereo16_from_multichannel(l, r, (short *) (data + i*2*chan*512), 512, chan);
+        }
+        m_nodes.append (new VisualNode (l, r, 512));
     }
-    else if (c == 1)
-    {
-        l = new short[len];
-
-        if (p == 8)
-            mono16_from_monopcm8 (l, b->data, cnt);
-        else if (p == 16)
-            mono16_from_monopcm16 (l, (short *) b->data, cnt);
-    }
-    else
-        len = 0;
-
-    m_nodes.append (new VisualNode (l, r, len, w));
 }
 
 void MainVisual::timeout()
@@ -200,7 +188,7 @@ void MainVisual::mousePressEvent (QMouseEvent *e)
         foreach(QAction *act, m_visModeGroup->actions ())
         if (str == act->data().toString())
         {
-            act->setChecked(TRUE);
+            act->setChecked(true);
             break;
         }
     }
@@ -208,18 +196,18 @@ void MainVisual::mousePressEvent (QMouseEvent *e)
 
 void MainVisual::drawBackGround()
 {
-    m_bg = QPixmap (75,20);
+    m_bg = QPixmap (76 * m_ratio, 16 * m_ratio);
     if (m_transparentAction->isChecked())
     {
         m_bg.fill (Qt::transparent);
         return;
     }
     QPainter painter(&m_bg);
-    for (int x = 0; x < 75; x += 2)
+    for (int x = 0; x < 76 * m_ratio; x += 2)
     {
         painter.setPen(m_skin->getVisColor(0));
-        painter.drawLine(x + 1, 0, x + 1, 20);
-        for (int y = 0; y < 20; y +=2)
+        painter.drawLine(x + 1, 0, x + 1, 16 *m_ratio);
+        for (int y = 0; y < 16 *m_ratio; y += 2)
         {
             painter.setPen(m_skin->getVisColor(0));
             painter.drawPoint(x,y);
@@ -231,6 +219,9 @@ void MainVisual::drawBackGround()
 
 void MainVisual::updateSettings()
 {
+    m_ratio = m_skin->ratio();
+    resize(76 * m_ratio, 16 * m_ratio);
+    m_pixmap = QPixmap (76 * m_ratio, 16 * m_ratio);
     drawBackGround();
     m_pixmap = m_bg;
     update();
@@ -291,13 +282,13 @@ void MainVisual::createMenu()
     connect(m_menu, SIGNAL(triggered (QAction *)),SLOT(updateSettings()));
     QMenu *visMode = m_menu->addMenu(tr("Visualization Mode"));
     m_visModeGroup = new QActionGroup(this);
-    m_visModeGroup->setExclusive(TRUE);
+    m_visModeGroup->setExclusive(true);
     m_visModeGroup->addAction(tr("Analyzer"))->setData("Analyzer");
     m_visModeGroup->addAction(tr("Scope"))->setData("Scope");
     m_visModeGroup->addAction(tr("Off"))->setData("None");
     foreach(QAction *act, m_visModeGroup->actions ())
     {
-        act->setCheckable(TRUE);
+        act->setCheckable(true);
         visMode->addAction(act);
     }
 
@@ -311,36 +302,36 @@ void MainVisual::createMenu()
     m_analyzerTypeGroup->addAction(tr("Bars"))->setData(1);
     foreach(QAction *act, m_analyzerModeGroup->actions ())
     {
-        act->setCheckable(TRUE);
+        act->setCheckable(true);
         analyzerMode->addAction(act);
     }
     analyzerMode->addSeparator ();
     foreach(QAction *act, m_analyzerTypeGroup->actions ())
     {
-        act->setCheckable(TRUE);
+        act->setCheckable(true);
         analyzerMode->addAction(act);
     }
     analyzerMode->addSeparator ();
     m_peaksAction = analyzerMode->addAction(tr("Peaks"));
-    m_peaksAction->setCheckable(TRUE);
+    m_peaksAction->setCheckable(true);
 
 
     QMenu *refreshRate = m_menu->addMenu(tr("Refresh Rate"));
     m_fpsGroup = new QActionGroup(this);
-    m_fpsGroup->setExclusive(TRUE);
+    m_fpsGroup->setExclusive(true);
     m_fpsGroup->addAction(tr("50 fps"))->setData(50);
     m_fpsGroup->addAction(tr("25 fps"))->setData(25);
     m_fpsGroup->addAction(tr("10 fps"))->setData(10);
     m_fpsGroup->addAction(tr("5 fps"))->setData(5);
     foreach(QAction *act, m_fpsGroup->actions ())
     {
-        act->setCheckable(TRUE);
+        act->setCheckable(true);
         refreshRate->addAction(act);
     }
 
     QMenu *analyzerFalloff = m_menu->addMenu(tr("Analyzer Falloff"));
     m_analyzerFalloffGroup = new QActionGroup(this);
-    m_analyzerFalloffGroup->setExclusive(TRUE);
+    m_analyzerFalloffGroup->setExclusive(true);
     m_analyzerFalloffGroup->addAction(tr("Slowest"))->setData(1);
     m_analyzerFalloffGroup->addAction(tr("Slow"))->setData(2);
     m_analyzerFalloffGroup->addAction(tr("Medium"))->setData(3);
@@ -348,13 +339,13 @@ void MainVisual::createMenu()
     m_analyzerFalloffGroup->addAction(tr("Fastest"))->setData(5);
     foreach(QAction *act, m_analyzerFalloffGroup->actions ())
     {
-        act->setCheckable(TRUE);
+        act->setCheckable(true);
         analyzerFalloff->addAction(act);
     }
 
     QMenu *peaksFalloff = m_menu->addMenu(tr("Peaks Falloff"));
     m_peaksFalloffGroup = new QActionGroup(this);
-    m_peaksFalloffGroup->setExclusive(TRUE);
+    m_peaksFalloffGroup->setExclusive(true);
     m_peaksFalloffGroup->addAction(tr("Slowest"))->setData(1);
     m_peaksFalloffGroup->addAction(tr("Slow"))->setData(2);
     m_peaksFalloffGroup->addAction(tr("Medium"))->setData(3);
@@ -362,12 +353,12 @@ void MainVisual::createMenu()
     m_peaksFalloffGroup->addAction(tr("Fastest"))->setData(5);
     foreach(QAction *act, m_peaksFalloffGroup->actions ())
     {
-        act->setCheckable(TRUE);
+        act->setCheckable(true);
         peaksFalloff->addAction(act);
     }
     QMenu *background = m_menu->addMenu(tr("Background"));
     m_transparentAction = background->addAction(tr("Transparent"));
-    m_transparentAction->setCheckable(TRUE);
+    m_transparentAction->setCheckable(true);
     update();
 }
 
@@ -377,46 +368,46 @@ void MainVisual::readSettings()
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
 
     QString name = settings.value("Visualization/type","Analyzer").toString();
-    m_visModeGroup->actions ()[0]->setChecked(TRUE);
+    m_visModeGroup->actions ()[0]->setChecked(true);
     foreach(QAction *act, m_visModeGroup->actions ())
     if (name == act->data().toString())
-        act->setChecked(TRUE);
+        act->setChecked(true);
 
     m_peaksAction->setChecked(
-        settings.value("Visualization/show_peaks", TRUE).toBool());
+        settings.value("Visualization/show_peaks", true).toBool());
 
     int fps = settings.value("Visualization/rate", 25).toInt();
-    m_fpsGroup->actions ()[1]->setChecked(TRUE);
+    m_fpsGroup->actions ()[1]->setChecked(true);
     foreach(QAction *act, m_fpsGroup->actions ())
     if (fps == act->data().toInt())
-        act->setChecked(TRUE);
+        act->setChecked(true);
 
     int mode = settings.value("Visualization/analyzer_mode", 0).toInt();
-    m_analyzerModeGroup->actions ()[0]->setChecked(TRUE);
+    m_analyzerModeGroup->actions ()[0]->setChecked(true);
     foreach(QAction *act, m_analyzerModeGroup->actions ())
     if (mode == act->data().toInt())
-        act->setChecked(TRUE);
+        act->setChecked(true);
 
     int type = settings.value("Visualization/analyzer_type", 1).toInt();
-    m_analyzerTypeGroup->actions ()[1]->setChecked(TRUE);
+    m_analyzerTypeGroup->actions ()[1]->setChecked(true);
     foreach(QAction *act, m_analyzerTypeGroup->actions ())
     if (type == act->data().toInt())
-        act->setChecked(TRUE);
+        act->setChecked(true);
 
     int speed = settings.value("Visualization/peaks_falloff", 3).toInt();
-    m_peaksFalloffGroup->actions ()[2]->setChecked(TRUE);
+    m_peaksFalloffGroup->actions ()[2]->setChecked(true);
     foreach(QAction *act, m_peaksFalloffGroup->actions ())
     if (speed == act->data().toInt())
-        act->setChecked(TRUE);
+        act->setChecked(true);
 
     speed = settings.value("Visualization/analyzer_falloff", 3).toInt();
-    m_analyzerFalloffGroup->actions ()[2]->setChecked(TRUE);
+    m_analyzerFalloffGroup->actions ()[2]->setChecked(true);
     foreach(QAction *act, m_analyzerFalloffGroup->actions ())
     if (speed == act->data().toInt())
-        act->setChecked(TRUE);
+        act->setChecked(true);
 
     m_transparentAction->setChecked(
-        settings.value("Visualization/transparent_bg", FALSE).toBool());
+        settings.value("Visualization/transparent_bg", false).toBool());
 
     updateSettings();
 }
@@ -426,9 +417,9 @@ using namespace mainvisual;
 Analyzer::Analyzer()
         : m_analyzerBarWidth (4), m_fps (20)
 {
-    m_size = QSize(75,20);
     clear();
-    m_skin = Skin::getPointer();
+    m_skin = Skin::instance();
+    m_size = QSize(76*m_skin->ratio(), 16*m_skin->ratio());
 
     double peaks_speed[] = { 0.05, 0.1, 0.2, 0.4, 0.8 };
     double analyzer_speed[] = { 1.2, 1.8, 2.2, 2.8, 2.4 };
@@ -438,7 +429,7 @@ Analyzer::Analyzer()
         peaks_speed[settings.value("Visualization/peaks_falloff", 3).toInt()-1];
     m_analyzer_falloff =
         analyzer_speed[settings.value("Visualization/analyzer_falloff", 3).toInt()-1];
-    m_show_peaks = settings.value("Visualization/show_peaks", TRUE).toBool();
+    m_show_peaks = settings.value("Visualization/show_peaks", true).toBool();
 
     m_lines = settings.value("Visualization/analyzer_type", 1).toInt() == 0;
     m_mode = settings.value("Visualization/analyzer_mode", 0).toInt();
@@ -484,7 +475,7 @@ bool Analyzer::process (VisualNode *node)
         calc_freq (dest, node->left);
     }
     else
-        return FALSE;
+        return false;
     const double y_scale = 3.60673760222;   /* 20.0 / log(256) */
     int max = m_lines ? 75 : 19, y, j;
 
@@ -523,11 +514,12 @@ bool Analyzer::process (VisualNode *node)
                          ? magnitude : m_peaks[i];
         }
     }
-    return TRUE;
+    return true;
 }
 
 void Analyzer::draw (QPainter *p)
 {
+    int r = m_skin->ratio();
     if (m_lines)
         for (int j = 0; j < 75; ++j)
         {
@@ -539,11 +531,17 @@ void Analyzer::draw (QPainter *p)
                     p->setPen (m_skin->getVisColor (3+(int(m_intern_vis_data[j])-i)));
                 else
                     p->setPen (m_skin->getVisColor (18-int(m_intern_vis_data[j])));
-                p->drawPoint (j, m_size.height()-i);
+                p->drawPoint (j*r, m_size.height() - r*i);
+                if(r == 2)
+                    p->drawPoint (j*r+1, m_size.height() - r*i);
             }
             p->setPen (m_skin->getVisColor (23));
             if (m_show_peaks)
-                p->drawPoint (j, m_size.height()-int(m_peaks[j]));
+            {
+                p->drawPoint (j*r, m_size.height() - r*m_peaks[j]);
+                if(r == 2)
+                    p->drawPoint (j*r+1, m_size.height() - r*m_peaks[j]);
+            }
         }
     else
         for (int j = 0; j < 19; ++j)
@@ -556,25 +554,34 @@ void Analyzer::draw (QPainter *p)
                     p->setPen (m_skin->getVisColor (3+(int(m_intern_vis_data[j])-i)));
                 else
                     p->setPen (m_skin->getVisColor (18-int(m_intern_vis_data[j])));
-                p->drawLine (j*4,m_size.height()-i, (j+1)*4-2,m_size.height()-i);
+
+                p->drawLine (j*4*r,m_size.height()-r*i, (j*4+2)*r,m_size.height()-r*i);
+                if(r == 2)
+                    p->drawLine (j*4*r, m_size.height()-r*i +1, (j*4+2)*r,m_size.height()-r*i+1);
             }
             p->setPen (m_skin->getVisColor (23));
             if (m_show_peaks)
-                p->drawLine (j*4,m_size.height()-int(m_peaks[j]),
-                             (j+1) *4-2,m_size.height()-int(m_peaks[j]));
+            {
+                p->drawLine (j*4*r,m_size.height()-r*m_peaks[j],
+                             (j*4+2)*r,m_size.height()-r*m_peaks[j]);
+                if(r == 2)
+                    p->drawLine (j*4*r,m_size.height()-r*m_peaks[j]+1,
+                             (j*4+2)*r,m_size.height()-r*m_peaks[j]+1);
+            }
         }
 }
 
 Scope::Scope()
 {
     clear();
-    m_skin = Skin::getPointer();
+    m_skin = Skin::instance();
+    m_ratio = m_skin->ratio();
 }
 
 void Scope::clear()
 {
-    for (int i = 0; i< 75; ++i)
-        m_intern_vis_data[i] = 7;
+    for (int i = 0; i< 76; ++i)
+        m_intern_vis_data[i] = 5;
 }
 
 Scope::~Scope()
@@ -583,35 +590,35 @@ Scope::~Scope()
 bool Scope::process(VisualNode *node)
 {
     if (!node)
-        return FALSE;
+        return false;
 
-    int step = (node->length << 8)/74;
+    int step = (node->length << 8)/76;
     int pos = 0;
 
-    for (int i = 0; i < 75; ++i)
+    for (int i = 0; i < 76; ++i)
     {
         pos += step;
         m_intern_vis_data[i] = (node->left[pos >> 8] >> 12);
 
-        if (m_intern_vis_data[i] > 5)
-            m_intern_vis_data[i] = 5;
-        else if (m_intern_vis_data[i] < -5)
-            m_intern_vis_data[i] = -5;
+        if (m_intern_vis_data[i] > 4)
+            m_intern_vis_data[i] = 4;
+        else if (m_intern_vis_data[i] < -4)
+            m_intern_vis_data[i] = -4;
     }
-    return TRUE;
+    return true;
 }
 
 void Scope::draw(QPainter *p)
 {
-    for (int i = 0; i<73; ++i)
+    for (int i = 0; i<75; ++i)
     {
-        int h1 = 10 - m_intern_vis_data[i];
-        int h2 = 10 - m_intern_vis_data[i+1];
+        int h1 = 8 - m_intern_vis_data[i];
+        int h2 = 8 - m_intern_vis_data[i+1];
         if (h1 > h2)
             qSwap(h1, h2);
-        p->setPen (m_skin->getVisColor(19 + (10 - h2)/2));
-        p->drawLine(i, h1, i, h2);
+        p->setPen (m_skin->getVisColor(18 + qAbs(8 - h2)));
+        p->drawLine(i*m_ratio, h1*m_ratio, (i+1)*m_ratio, h2*m_ratio);
     }
-    for (int i = 0; i< 75; ++i)
+    for (int i = 0; i< 76; ++i)
         m_intern_vis_data[i] = 0;
 }
