@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,11 +22,10 @@
 #include <QDir>
 #include <QAction>
 #include <QMenu>
-
 #include <math.h>
-
 #include <qmmp/soundcore.h>
 #include <qmmp/visual.h>
+#include <qmmp/metadatamanager.h>
 #include <qmmpui/generalhandler.h>
 #include <qmmpui/general.h>
 #include <qmmpui/playlistparser.h>
@@ -34,8 +33,8 @@
 #include <qmmpui/commandlinemanager.h>
 #include <qmmpui/filedialog.h>
 #include <qmmpui/playlistmodel.h>
+#include <qmmpui/playlistmanager.h>
 #include <qmmpui/mediaplayer.h>
-
 #include "textscroller.h"
 #include "mainwindow.h"
 #include "skin.h"
@@ -57,10 +56,7 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
         : QMainWindow(parent)
 {
     m_vis = 0;
-    seeking = FALSE;
-    m_update = FALSE;
-    m_paused = FALSE;
-    m_playlistName = tr("Default");
+    m_update = false;
     m_option_manager = option_manager;
     setWindowIcon(QIcon(":/32x32/qmmp.png"));
 #if QT_VERSION >= 0x040500
@@ -68,48 +64,39 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
 #else
     setWindowFlags(Qt::Window | Qt::FramelessWindowHint | Qt::WindowSystemMenuHint);
 #endif
-    //setFixedSize (275,116);
-    resize(275,116);
     setWindowTitle("Qmmp");
 
     //prepare libqmmp and libqmmpui libraries for playing
     m_player = new MediaPlayer(this);
     m_core = new SoundCore(this);
-    m_playListModel = new PlayListModel(this);
-    m_player->initialize(m_core, m_playListModel);
+    m_pl_manager = new PlayListManager(this);
+    m_player->initialize(m_core, m_pl_manager);
     //additional featuries
     new PlaylistParser(this);
     m_generalHandler = new GeneralHandler(this);
 
     //user interface
     m_skin = new Skin(this);
+    resize(275 * m_skin->ratio(),116 * m_skin->ratio());
     Dock *dock = new Dock(this);
     dock->setMainWidget(this);
-    display = new MainDisplay(this);
-    setCentralWidget(display);
-    display->show();
-    display->setFocus ();
+    m_display = new MainDisplay(this);
+    setCentralWidget(m_display);
+    m_display->setFocus ();
 
-    m_playlist = new PlayList(this);
-    m_playlist->setModel(m_playListModel);
+    m_playlist = new PlayList(m_pl_manager, this);
     dock->addWidget(m_playlist);
 
     m_equalizer = new EqWidget(this);
     dock->addWidget(m_equalizer);
 
-    m_jumpDialog = new JumpToTrackDialog(this);
-    m_jumpDialog->setModel(m_playListModel);
+    m_jumpDialog = new JumpToTrackDialog(m_pl_manager, this);
     m_jumpDialog->hide();
 
-    m_titlebar = new TitleBar(this);
-    m_titlebar->move(0,0);
-    m_titlebar->show();
-    m_titlebar->setActive(TRUE);
-
     createActions();
     //prepare visualization
     Visual::initialize(this, m_visMenu, SLOT(updateActions()));
-    m_vis = MainVisual::getPointer();
+    m_vis = MainVisual::instance();
     Visual::add(m_vis);
     //connections
     connect (m_playlist,SIGNAL(next()),SLOT(next()));
@@ -118,34 +105,27 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
     connect (m_playlist,SIGNAL(pause()), m_core ,SLOT(pause()));
     connect (m_playlist,SIGNAL(stop()),SLOT(stop()));
     connect (m_playlist,SIGNAL(eject()),SLOT(addFile()));
-    connect (m_playlist,SIGNAL(newPlaylist()),SLOT(newPlaylist()));
     connect (m_playlist,SIGNAL(loadPlaylist()),SLOT(loadPlaylist()));
     connect (m_playlist,SIGNAL(savePlaylist()),SLOT(savePlaylist()));
 
-    connect(display,SIGNAL(shuffleToggled(bool)),m_playListModel,SLOT(prepareForShufflePlaying(bool)));
-    connect(display,SIGNAL(repeatableToggled(bool)),m_playListModel,SLOT(prepareForRepeatablePlaying(bool)));
+    connect(m_display,SIGNAL(shuffleToggled(bool)),m_pl_manager,SLOT(setShuffle(bool)));
+    connect(m_display,SIGNAL(repeatableToggled(bool)),m_pl_manager,SLOT(setRepeatableList(bool)));
 
     connect(m_equalizer, SIGNAL(valueChanged()), SLOT(updateEQ()));
+    connect(m_jumpDialog,SIGNAL(playRequest()), SLOT(replay()));
 
-    connect(m_jumpDialog,SIGNAL(playRequest()),this,SLOT(play()));
-
-    //connect(m_core, SIGNAL(finished()), SLOT(next()));
     connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(showState(Qmmp::State)));
     connect(m_core, SIGNAL(elapsedChanged(qint64)),m_playlist, SLOT(setTime(qint64)));
-    connect(m_core, SIGNAL(elapsedChanged(qint64)),m_titlebar, SLOT(setTime(qint64)));
     connect(m_core, SIGNAL(metaDataChanged()),SLOT(showMetaData()));
-    connect(m_core, SIGNAL(bufferingProgress(int)), TextScroller::getPointer(),
-            SLOT(setProgress(int)));
-
+    connect(m_core, SIGNAL(bufferingProgress(int)), TextScroller::getPointer(), SLOT(setProgress(int)));
     connect(m_generalHandler, SIGNAL(toggleVisibilityCalled()), SLOT(toggleVisibility()));
     connect(m_generalHandler, SIGNAL(exitCalled()), SLOT(close()));
 
     readSettings();
-    display->setEQ(m_equalizer);
-    display->setPL(m_playlist);
+    m_display->setEQ(m_equalizer);
+    m_display->setPL(m_playlist);
     dock->updateDock();
-    //m_playListModel->readSettings();
-    m_playListModel->doCurrentVisibleRequest();
+    m_pl_manager->currentPlayList()->doCurrentVisibleRequest();
     updateEQ();
 #ifndef Q_OS_WIN32
     QString cwd = QDir::currentPath();
@@ -153,13 +133,13 @@ MainWindow::MainWindow(const QStringList& args, BuiltinCommandLineOption* option
 #endif
     if (m_startHidden && m_generalHandler->visibilityControl())
         toggleVisibility();
+    if(args.isEmpty())
+        resume();
 }
 
 
 MainWindow::~MainWindow()
-{
-    //stop();
-}
+{}
 
 void MainWindow::play()
 {
@@ -169,16 +149,15 @@ void MainWindow::play()
 void MainWindow::replay()
 {
     stop();
+    m_pl_manager->activatePlayList(m_pl_manager->selectedPlayList());
     play();
 }
 
 void MainWindow::seek(qint64 pos)
 {
-    if (!seeking)
-        m_core->seek(pos);
+    m_core->seek(pos);
 }
 
-
 void MainWindow::forward()
 {
     seek(m_core->elapsed() + KEY_OFFSET);
@@ -202,8 +181,7 @@ void MainWindow::pause(void)
 
 void MainWindow::stop()
 {
-    //display->setTime(0);
-    m_core->stop();
+    m_player->stop();
 }
 
 void MainWindow::next()
@@ -227,35 +205,31 @@ void MainWindow::updateEQ()
 
 void MainWindow::showState(Qmmp::State state)
 {
-    disconnect(m_playListModel, SIGNAL(firstAdded()), this, SLOT(play()));
+    if(m_model)
+    {
+        disconnect(m_model, SIGNAL(firstAdded()), this, 0);
+        m_model = 0;
+    }
     switch ((int) state)
     {
     case Qmmp::Playing:
-    {
-        if (m_playListModel->currentItem())
-            m_equalizer->loadPreset(m_playListModel->currentItem()->url().section("/",-1));
+        if (m_pl_manager->currentPlayList()->currentItem())
+            m_equalizer->loadPreset(m_pl_manager->currentPlayList()->currentItem()->url().section("/",-1));
         if (m_playlist->listWidget())
             m_playlist->listWidget()->updateList(); //removes progress message from TextScroller
         break;
-    }
     case Qmmp::Paused:
-    {
-        //m_generalHandler->setState(General::Paused);
         break;
-    }
     case Qmmp::Stopped:
-    {
-        //m_generalHandler->setState(General::Stopped);
         m_playlist->setTime(-1);
-        m_titlebar->setTime(-1);
         if (m_playlist->currentItem())
             setWindowTitle(m_playlist->currentItem()->text());
         else
             setWindowTitle("Qmmp");
         break;
     }
-    }
 }
+
 void MainWindow::showMetaData()
 {
     qDebug("===== metadata ======");
@@ -268,7 +242,8 @@ void MainWindow::showMetaData()
     qDebug("TRACK = %s", qPrintable(m_core->metaData(Qmmp::TRACK)));
     qDebug("== end of metadata ==");
 
-    if (m_playlist->currentItem() && !m_core->metaData().isEmpty())
+    if (m_playlist->currentItem() &&
+        m_playlist->currentItem()->url() == m_core->metaData().value(Qmmp::URL))
     {
         m_playlist->currentItem()->updateMetaData(m_core->metaData());
         m_playlist->updateList();
@@ -288,40 +263,26 @@ void MainWindow::closeEvent (QCloseEvent *)
 void MainWindow::addDir()
 {
     FileDialog::popup(this, FileDialog::AddDirs, &m_lastDir,
-                      m_playListModel, SLOT(addFileList(const QStringList&)),
+                      m_pl_manager->selectedPlayList(), SLOT(addFileList(const QStringList&)),
                       tr("Choose a directory"));
 }
 
 void MainWindow::addFile()
 {
     QStringList filters;
-    filters << tr("All Supported Bitstreams")+" (" + Decoder::nameFilters().join (" ") +")";
-    filters << Decoder::filters();
+    filters << tr("All Supported Bitstreams")+" (" +
+            MetaDataManager::instance()->nameFilters().join (" ") +")";
+    filters << MetaDataManager::instance()->filters();
     FileDialog::popup(this, FileDialog::AddDirsFiles, &m_lastDir,
-                      m_playListModel, SLOT(addFileList(const QStringList&)),
+                      m_pl_manager->selectedPlayList(), SLOT(addFileList(const QStringList&)),
                       tr("Select one or more files to open"), filters.join(";;"));
 }
 
-void MainWindow::clear()
-{
-    m_playListModel->clear();
-}
-
-void MainWindow::startSeek()
-{
-    seeking = TRUE;
-}
-
-void MainWindow::endSeek()
-{
-    seeking = FALSE;
-}
-
 void MainWindow::changeEvent (QEvent * event)
 {
     if (event->type() == QEvent::ActivationChange)
     {
-        m_titlebar->setActive(isActiveWindow());
+        m_display->setActive(isActiveWindow());
     }
 }
 
@@ -331,35 +292,56 @@ void MainWindow::readSettings()
     if (!m_update)
     {
         settings.beginGroup("MainWindow");
-        //geometry
-        move(settings.value("pos", QPoint(100, 100)).toPoint());
-        //last directory
-        m_lastDir = settings.value("last_dir","/").toString();
-        m_startHidden = settings.value("start_hidden", FALSE).toBool();
+
+        move(settings.value("pos", QPoint(100, 100)).toPoint()); //geometry
+
+        m_lastDir = settings.value("last_dir","/").toString(); //last directory
+        m_startHidden = settings.value("start_hidden", false).toBool();
         settings.endGroup();
+        if(settings.value("General/always_on_top", false).toBool())
+            setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
         show();
         qApp->processEvents();
         //visibility
-        m_playlist->setVisible(settings.value("Playlist/visible",TRUE).toBool());
-        m_equalizer->setVisible(settings.value("Equalizer/visible",TRUE).toBool());
-        bool val = settings.value("Playlist/repeatable",FALSE).toBool();
+        m_playlist->setVisible(settings.value("Playlist/visible",true).toBool());
+        m_equalizer->setVisible(settings.value("Equalizer/visible",true).toBool());
+        bool val = settings.value("Playlist/repeatable",false).toBool();
 
         // Repeat/Shuffle
-        m_playListModel->prepareForRepeatablePlaying(val);
-        display->setIsRepeatable(val);
-        val = settings.value("Playlist/shuffle",FALSE).toBool();
-        display->setIsShuffle(val);
-        m_playListModel->prepareForShufflePlaying(val);
+        m_pl_manager->setRepeatableList(val);
+        m_display->setIsRepeatable(val);
+        val = settings.value("Playlist/shuffle",false).toBool();
+        m_display->setIsShuffle(val);
+        m_pl_manager->setShuffle(val);
 
-        // Playlist name
-        m_playlistName = settings.value("Playlist/playlist_name","Default").toString();
-
-        m_update = TRUE;
+        m_update = true;
     }
-    setWindowOpacity(settings.value("MainWindow/opacity", 1.0).toDouble());
-    m_equalizer->setWindowOpacity(settings.value("Equalizer/opacity", 1.0).toDouble());
-    m_playlist->setWindowOpacity(settings.value("PlayList/opacity", 1.0).toDouble());
-    m_hideOnClose = settings.value("MainWindow/hide_on_close", FALSE).toBool();
+    else
+    {
+        if(settings.value("General/always_on_top", false).toBool())
+        {
+            setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
+            m_playlist->setWindowFlags(m_playlist->windowFlags() | Qt::WindowStaysOnTopHint);
+            m_equalizer->setWindowFlags(m_equalizer->windowFlags() | Qt::WindowStaysOnTopHint);
+        }
+        else
+        {
+            setWindowFlags(windowFlags() & ~Qt::WindowStaysOnTopHint);
+            m_playlist->setWindowFlags(m_playlist->windowFlags() & ~Qt::WindowStaysOnTopHint);
+            m_equalizer->setWindowFlags(m_equalizer->windowFlags() & ~Qt::WindowStaysOnTopHint);
+        }
+        show();
+        m_playlist->setVisible(m_display->isPlaylistVisible());
+        m_equalizer->setVisible(m_display->isEqualizerVisible());
+    }
+
+    if(!settings.value("General/metacity_compat", false).toBool())
+    {
+        setWindowOpacity(settings.value("MainWindow/opacity", 1.0).toDouble());
+        m_equalizer->setWindowOpacity(settings.value("Equalizer/opacity", 1.0).toDouble());
+        m_playlist->setWindowOpacity(settings.value("PlayList/opacity", 1.0).toDouble());
+    }
+    m_hideOnClose = settings.value("MainWindow/hide_on_close", false).toBool();
 }
 
 void MainWindow::writeSettings()
@@ -371,29 +353,30 @@ void MainWindow::writeSettings()
     //last directory
     settings.setValue("last_dir",m_lastDir);
     settings.endGroup();
-
     // Repeat/Shuffle
     settings.beginGroup("Playlist");
-    settings.setValue("repeatable",display->isRepeatable());
-    settings.setValue("shuffle",display->isShuffle());
-
-    // Playlist name
-    settings.setValue("playlist_name",m_playlistName);
+    settings.setValue("repeatable",m_display->isRepeatable());
+    settings.setValue("shuffle",m_display->isShuffle());
+    settings.endGroup();
+    // playback state
+    settings.beginGroup("General");
+    settings.setValue("resume_playback", m_core->state() == Qmmp::Playing &&
+                      settings.value("resume_on_startup", false).toBool());
+    settings.setValue("resume_playback_time", m_core->totalTime() > 0 ? m_core->elapsed() : 0);
     settings.endGroup();
 }
 
 void MainWindow::showSettings()
 {
-    m_confDialog = new ConfigDialog(this);
-    if (m_confDialog->exec() == QDialog::Accepted)
-    {
-        readSettings();
-        m_playlist->readSettings();
-        TextScroller::getPointer()->readSettings();
-        //m_core->updateConfig();
-        m_visMenu->updateActions();
-    }
-    delete m_confDialog;
+    ConfigDialog *confDialog = new ConfigDialog(this);
+    confDialog->exec();
+    readSettings();
+    m_playlist->readSettings();
+    TextScroller::getPointer()->readSettings();
+    m_visMenu->updateActions();
+    m_skin->reloadSkin();
+    Dock::instance()->updateDock();
+    confDialog->deleteLater();
 }
 
 void MainWindow::toggleVisibility()
@@ -403,8 +386,8 @@ void MainWindow::toggleVisibility()
         show();
         raise();
         activateWindow();
-        m_playlist->setVisible(display->isPlaylistVisible());
-        m_equalizer->setVisible(display->isEqualizerVisible());
+        m_playlist->setVisible(m_display->isPlaylistVisible());
+        m_equalizer->setVisible(m_display->isEqualizerVisible());
         qApp->processEvents();
         setFocus ();
         if (isMinimized())
@@ -439,18 +422,18 @@ void MainWindow::createActions()
     QAction *repeateAllAction = m_mainMenu->addAction(tr("&Repeat Playlist"));
     QAction *repeateTrackAction = m_mainMenu->addAction(tr("&Repeat Track"));
     QAction *shuffleAction = m_mainMenu->addAction(tr("&Shuffle"));
-    repeateAllAction->setCheckable (TRUE);
-    repeateTrackAction->setCheckable (TRUE);
-    shuffleAction->setCheckable (TRUE);
+    repeateAllAction->setCheckable (true);
+    repeateTrackAction->setCheckable (true);
+    shuffleAction->setCheckable (true);
     repeateAllAction->setShortcut(tr("R")) ;
     repeateTrackAction->setShortcut(tr("Ctrl+R")) ;
     shuffleAction->setShortcut(tr("S")) ;
-    connect(repeateAllAction, SIGNAL(triggered (bool)), m_playListModel, SLOT(prepareForRepeatablePlaying(bool)));
+    connect(repeateAllAction, SIGNAL(triggered (bool)), m_pl_manager, SLOT(setRepeatableList(bool)));
     connect(repeateTrackAction, SIGNAL(triggered (bool)), m_player, SLOT(setRepeatable(bool)));
-    connect(shuffleAction, SIGNAL(triggered (bool)), m_playListModel, SLOT(prepareForShufflePlaying(bool)));
-    connect(m_playListModel, SIGNAL(repeatableListChanged(bool)), repeateAllAction, SLOT(setChecked(bool)));
+    connect(shuffleAction, SIGNAL(triggered (bool)), m_pl_manager, SLOT(setShuffle(bool)));
+    connect(m_pl_manager, SIGNAL(repeatableListChanged(bool)), repeateAllAction, SLOT(setChecked(bool)));
     connect(m_player, SIGNAL (repeatableChanged(bool)), repeateTrackAction, SLOT(setChecked(bool)));
-    connect(m_playListModel, SIGNAL(shuffleChanged(bool)), shuffleAction, SLOT(setChecked(bool)));
+    connect(m_pl_manager, SIGNAL(shuffleChanged(bool)), shuffleAction, SLOT(setChecked(bool)));
     m_mainMenu->addSeparator();
     m_mainMenu->addAction(tr("&Jump To File"),this, SLOT(jumpToFile()), tr("J"));
     m_mainMenu->addSeparator();
@@ -462,7 +445,7 @@ void MainWindow::createActions()
     m_mainMenu->addSeparator();
     m_mainMenu->addAction(tr("&About"), this, SLOT(about()));
     m_mainMenu->addAction(tr("&About Qt"), qApp, SLOT(aboutQt()));
-    Dock::getPointer()->addActions(m_mainMenu->actions());
+    Dock::instance()->addActions(m_mainMenu->actions());
     m_mainMenu->addSeparator();
     m_mainMenu->addAction(tr("&Exit"),this, SLOT(close ()), tr("Ctrl+Q"));
 
@@ -473,8 +456,8 @@ void MainWindow::createActions()
     backward->setShortcut(QKeySequence(Qt::Key_Left));
     connect(backward,SIGNAL(triggered(bool)),this,SLOT(backward()));
 
-    Dock::getPointer()->addActions( QList<QAction*>() << forward << backward );
-    Dock::getPointer()->addActions(m_mainMenu->actions());
+    Dock::instance()->addActions( QList<QAction*>() << forward << backward );
+    Dock::instance()->addActions(m_mainMenu->actions());
 }
 
 
@@ -489,12 +472,6 @@ QMenu* MainWindow::menu()
     return m_mainMenu;
 }
 
-void MainWindow::newPlaylist()
-{
-    m_playListModel->clear();
-    m_playlistName = tr("Default");
-}
-
 void MainWindow::loadPlaylist()
 {
     QStringList l;
@@ -509,9 +486,9 @@ void MainWindow::loadPlaylist()
         QString f_name = FileDialog::getOpenFileName(this,tr("Open Playlist"),m_lastDir,mask);
         if (!f_name.isEmpty())
         {
-            m_playListModel->clear();
-            m_playListModel->loadPlaylist(f_name);
-            m_playlistName = QFileInfo(f_name).baseName();
+            m_pl_manager->selectedPlayList()->clear();
+            m_pl_manager->selectedPlayList()->loadPlaylist(f_name);
+            m_pl_manager->selectedPlayList()->setName(QFileInfo(f_name).baseName());
             m_lastDir = QFileInfo(f_name).absoluteDir().path();
         }
     }
@@ -532,12 +509,11 @@ void MainWindow::savePlaylist()
 
         QString mask = tr("Playlist Files")+" (" + l.join(" *.").prepend("*.") + ")";
         QString f_name = FileDialog::getSaveFileName(this, tr("Save Playlist"),m_lastDir + "/" +
-                         m_playlistName + "." + l[0],mask);
+                         m_pl_manager->selectedPlayList()->name() + "." + l[0],mask);
 
         if (!f_name.isEmpty())
         {
-            m_playListModel->savePlaylist(f_name);
-            m_playlistName = QFileInfo(f_name).baseName();
+            m_pl_manager->selectedPlayList()->savePlaylist(f_name);
             m_lastDir = QFileInfo(f_name).absoluteDir().path();
         }
     }
@@ -550,10 +526,15 @@ void MainWindow::setFileList(const QStringList & l)
     if (m_core->state() == Qmmp::Playing || m_core->state() == Qmmp::Paused)
         stop();
     qApp->processEvents(); //receive stop signal
-    connect(m_playListModel, SIGNAL(firstAdded()), this, SLOT(play()));
-    if (!m_playListModel->setFileList(l))
+    connect(m_pl_manager->selectedPlayList(), SIGNAL(firstAdded()), this, SLOT(play()));
+    if (m_pl_manager->selectedPlayList()->setFileList(l))
     {
-        disconnect(m_playListModel, SIGNAL(firstAdded()), this, SLOT(play()));
+        m_pl_manager->activatePlayList(m_pl_manager->selectedPlayList());
+        m_model = m_pl_manager->selectedPlayList();
+    }
+    else
+    {
+        disconnect(m_pl_manager->selectedPlayList(), SIGNAL(firstAdded()), this, SLOT(play()));
         addFile();
     }
 }
@@ -566,49 +547,59 @@ void MainWindow::playPause()
         play();
 }
 
-bool MainWindow::processCommandArgs(const QStringList &slist,const QString& cwd)
+bool MainWindow::processCommandArgs(const QStringList &slist, const QString& cwd)
 {
-    if (slist.count() > 0)
+    if(slist.isEmpty())
+        return true;
+    QStringList paths;
+    foreach(QString arg, slist)
     {
-        QString str = slist[0];
-
-        if (str.startsWith("--enqueue") || str.startsWith("-e")) //check for "--enqueue" modifier
+        if(arg.startsWith("-"))
+            break;
+        else
+            paths.append(arg);
+    }
+    if(!paths.isEmpty())
+    {
+        QStringList full_path_list;
+        foreach(QString s, paths)
         {
-            if (slist.count() < 2)
-                return FALSE;
-            QStringList full_path_list;
-            for (int i = 1; i < slist.count(); ++i)
-            {
-                if ((slist.at(i).startsWith("/")) || (slist.at(i).contains("://")))   //is it absolute path or url?
-                    full_path_list << slist.at(i);
-                else
-                    full_path_list << cwd + "/" + slist.at(i);
-            }
-            m_playListModel->addFileList(full_path_list); //TODO url support
-        }
-        else if (str.startsWith("-")) // is it a command?
-        {
-            if (CommandLineManager::hasOption(str))
-                m_generalHandler->executeCommand(str);
-            else if (m_option_manager->identify(str))
-                m_option_manager->executeCommand(str, this);
+            if ((s.startsWith("/")) || (s.contains("://")))   //is it absolute path or url?
+                full_path_list << s;
             else
-                return FALSE;
+                full_path_list << cwd + "/" + s;
         }
-        else// maybe it is a list of files or dirs
+        setFileList(full_path_list);
+        return true;
+    }
+    QHash<QString, QStringList> commands = m_option_manager->splitArgs(slist);
+    if(commands.isEmpty())
+        return false;
+    foreach(QString key, commands.keys())
+    {
+        if(key == "--enqueue" || key == "-e")
         {
+            QStringList args = commands.value(key);
+            if(args.isEmpty())
+                return false;
             QStringList full_path_list;
-            foreach(QString s,slist)
+            foreach(QString s, args)
             {
                 if ((s.startsWith("/")) || (s.contains("://")))   //is it absolute path or url?
                     full_path_list << s;
                 else
                     full_path_list << cwd + "/" + s;
             }
-            setFileList(full_path_list); //TODO url support
+            m_pl_manager->currentPlayList()->addFileList(full_path_list);
         }
+        else if (CommandLineManager::hasOption(key))
+            m_generalHandler->executeCommand(key, commands.value(key));
+        else if (m_option_manager->identify(key))
+            m_option_manager->executeCommand(key, commands.value(key), this);
+        else
+            return false;
     }
-    return TRUE;
+    return true;
 }
 
 void MainWindow::jumpToFile()
@@ -628,9 +619,9 @@ void MainWindow::handleCloseRequest()
         QApplication::closeAllWindows();
 }
 
-void MainWindow::addUrl( )
+void MainWindow::addUrl()
 {
-    AddUrlDialog::popup(this,m_playListModel);
+    AddUrlDialog::popup(this, m_pl_manager->selectedPlayList());
 }
 
 SoundCore * MainWindow::soundCore() const
@@ -640,7 +631,7 @@ SoundCore * MainWindow::soundCore() const
 
 MainDisplay * MainWindow::mainDisplay() const
 {
-    return display;
+    return m_display;
 }
 
 void MainWindow::keyPressEvent(QKeyEvent *ke)
@@ -649,3 +640,14 @@ void MainWindow::keyPressEvent(QKeyEvent *ke)
                                 ke->modifiers(), ke->text(),ke->isAutoRepeat(), ke->count());
     QApplication::sendEvent(m_playlist,&event);
 }
+
+void MainWindow::resume()
+{
+    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    settings.beginGroup("General");
+    if(settings.value("resume_playback", false).toBool())
+    {
+        qint64 pos =  settings.value("resume_playback_time").toLongLong();
+        m_player->play(pos);
+    }
+}
