@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Ilya Kotov                                      *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,57 +38,48 @@
 #include "symboldisplay.h"
 #include "playlistcontrol.h"
 #include "keyboardmanager.h"
-
+#include "playlistbrowser.h"
+#include "playlistselector.h"
 #include <qmmpui/playlistitem.h>
 #include <qmmpui/playlistmodel.h>
+#include <qmmpui/playlistmanager.h>
 #include <qmmpui/fileloader.h>
 #include <qmmpui/generalhandler.h>
 #include <qmmp/soundcore.h>
 
-PlayList::PlayList (QWidget *parent)
+PlayList::PlayList (PlayListManager *manager, QWidget *parent)
         : QWidget (parent)
 {
-    m_update = FALSE;
-    m_resize = FALSE;
-    m_anchor_row = -1;
+    setAttribute(Qt::WA_AlwaysShowToolTips,true);
+    m_pl_manager = manager;
+    m_update = false;
+    m_resize = false;
+    m_skin = Skin::instance();
+    m_ratio = m_skin->ratio();
+    m_shaded = false;
+    m_pl_browser = 0;
+    m_pl_selector = 0;
 
-    createMenus();
+    resize (275*m_ratio, 116*m_ratio);
+    setSizeIncrement (25*m_ratio, 29*m_ratio);
+    setMinimumSize(275*m_ratio, 116*m_ratio);
 
-
-    resize (275,116);
-    setMinimumSize (275,116);
-    setBaseSize (275,116);
     m_listWidget = new ListWidget (this);
-    m_listWidget->show();
-    m_listWidget->setGeometry (12,20,243,58);
-
     m_plslider = new PlayListSlider (this);
-    m_plslider->show();
-
-    setSizeIncrement (25,29);
-    m_skin = Skin::getPointer();
-
-    m_buttonAdd = new Button (this,Skin::PL_BT_ADD,Skin::PL_BT_ADD);
-    m_buttonAdd->move (11,86);
-    m_buttonSub = new Button (this,Skin::PL_BT_SUB,Skin::PL_BT_SUB);
-    m_buttonSub->move (40,86);
-    m_selectButton  = new Button (this,Skin::PL_BT_SEL,Skin::PL_BT_SEL);
-    m_selectButton->move (70,86);
-    m_sortButton= new Button (this,Skin::PL_BT_SORT,Skin::PL_BT_SORT);
-    m_sortButton->move (99,86);
-    m_playlistButton = new Button (this,Skin::PL_BT_LST,Skin::PL_BT_LST);
-
+    m_buttonAdd = new Button (this,Skin::PL_BT_ADD,Skin::PL_BT_ADD, Skin::CUR_PNORMAL);
+    m_buttonSub = new Button (this,Skin::PL_BT_SUB,Skin::PL_BT_SUB, Skin::CUR_PNORMAL);
+    m_selectButton  = new Button (this,Skin::PL_BT_SEL,Skin::PL_BT_SEL, Skin::CUR_PNORMAL);
+    m_sortButton= new Button (this,Skin::PL_BT_SORT,Skin::PL_BT_SORT, Skin::CUR_PNORMAL);
+    m_playlistButton = new Button (this,Skin::PL_BT_LST,Skin::PL_BT_LST, Skin::CUR_PNORMAL);
+    m_resizeWidget = new QWidget(this);
+    m_resizeWidget->resize(25,25);
+    m_resizeWidget->setCursor(m_skin->getCursor (Skin::CUR_PSIZE));
     m_pl_control = new PlaylistControl (this);
-    m_pl_control->move (0,0);
-    m_pl_control->show();
 
     m_length_totalLength = new SymbolDisplay (this,14);
     m_length_totalLength->setAlignment (Qt::AlignLeft);
-    m_length_totalLength -> show();
 
     m_current_time = new SymbolDisplay (this,6);
-    m_current_time->show();
-
     m_keyboardManager = new KeyboardManager (this);
 
     connect (m_listWidget, SIGNAL (selectionChanged()), parent, SLOT (replay()));
@@ -96,7 +87,7 @@ PlayList::PlayList (QWidget *parent)
     connect (m_plslider, SIGNAL (sliderMoved (int)), m_listWidget, SLOT (scroll (int)));
     connect (m_listWidget, SIGNAL (positionChanged (int, int)), m_plslider,
              SLOT (setPos (int, int)));
-    connect (m_skin, SIGNAL (skinChanged()), this, SLOT (update()));
+    connect (m_skin, SIGNAL (skinChanged()), this, SLOT (updateSkin()));
     connect (m_buttonAdd, SIGNAL (clicked()), SLOT (showAddMenu()));
     connect (m_buttonSub, SIGNAL (clicked()), SLOT (showSubMenu()));
     connect (m_selectButton, SIGNAL (clicked()), SLOT (showSelectMenu()));
@@ -109,14 +100,64 @@ PlayList::PlayList (QWidget *parent)
     connect (m_pl_control, SIGNAL (pauseClicked()), SIGNAL (pause()));
     connect (m_pl_control, SIGNAL (stopClicked()), SIGNAL (stop()));
     connect (m_pl_control, SIGNAL (ejectClicked()), SIGNAL (eject()));
+
+    connect (m_pl_manager, SIGNAL (selectedPlayListChanged(PlayListModel *, PlayListModel *)),
+             m_listWidget, SLOT(setModel(PlayListModel*)));
+    m_listWidget->setModel(m_pl_manager->selectedPlayList());
+
     m_titleBar = new PlayListTitleBar (this);
     m_titleBar->move (0,0);
+    connect (m_pl_manager, SIGNAL (currentPlayListChanged(PlayListModel *, PlayListModel *)),
+             m_titleBar, SLOT(setModel(PlayListModel*)));
+    m_titleBar->setModel(m_pl_manager->currentPlayList());
+
+    createMenus();
+    createActions();
+
     readSettings();
+    setCursor(m_skin->getCursor(Skin::CUR_PNORMAL));
+    updatePositions();
 }
 
-
 PlayList::~PlayList()
-{}
+{
+    delete m_keyboardManager;
+}
+
+void PlayList::updatePositions()
+{
+    int sx = (width()-275*m_ratio)/25;
+    int sy = (height()-116*m_ratio)/29;
+    if (sx < 0 || sy < 0 || m_shaded) //skip shaded mode
+        return;
+
+    m_titleBar->resize (275*m_ratio+25*sx, 20*m_ratio);
+    m_plslider->resize (20*m_ratio, 58*m_ratio+sy*29);
+
+    if(m_pl_selector)
+    {
+        m_listWidget->resize (243*m_ratio+25*sx, 58*m_ratio+29*sy - m_pl_selector->height());
+        m_pl_selector->resize(243*m_ratio+25*sx, m_pl_selector->height());
+        m_pl_selector->move(12*m_ratio, 20*m_ratio + 58*m_ratio+29*sy - m_pl_selector->height());
+    }
+    else
+        m_listWidget->resize (243*m_ratio+25*sx, 58*m_ratio+29*sy);
+    m_listWidget->move (12*m_ratio,20*m_ratio);
+
+    m_buttonAdd->move (11*m_ratio, 86*m_ratio+29*sy);
+    m_buttonSub->move (40*m_ratio, 86*m_ratio+29*sy);
+    m_selectButton->move (70*m_ratio, 86*m_ratio+29*sy);
+    m_sortButton->move (99*m_ratio, 86*m_ratio+29*sy);
+
+    m_pl_control->move (128*m_ratio+sx*25, 100*m_ratio+29*sy);
+    m_playlistButton->move (228*m_ratio+sx*25,86*m_ratio+29*sy);
+
+    m_length_totalLength -> move (131*m_ratio+sx*25,88*m_ratio+29*sy);
+    m_current_time->move (190*m_ratio+sx*25,101*m_ratio+29*sy);
+
+    m_plslider->move (255*m_ratio+sx*25,20*m_ratio);
+    m_resizeWidget->move(width() - 25, height() - 29);
+}
 
 void PlayList::createMenus()
 {
@@ -152,26 +193,28 @@ void PlayList::createActions()
     QAction *remSelAct = new QAction (tr ("&Remove Selected"),this);
     remSelAct->setShortcut (tr ("Del"));
     m_subMenu->addAction (remSelAct);
-    connect (remSelAct, SIGNAL (triggered()),
-             m_playListModel, SLOT (removeSelected ()));
-    this->addAction (remSelAct);
+    connect (remSelAct, SIGNAL (triggered()), m_pl_manager, SLOT (removeSelected ()));
+    addAction (remSelAct);
 
     QAction *remAllAct = new QAction (tr ("&Remove All"),this);
     //remAllAct->setShortcut(tr("D")); FIXME: add correct shortcat
     m_subMenu->addAction (remAllAct);
-    connect (remAllAct, SIGNAL (triggered()), m_playListModel, SLOT (clear ()));
+    connect (remAllAct, SIGNAL (triggered()), m_pl_manager, SLOT (clear ()));
     m_actions << remAllAct;
 
     QAction *remUnselAct = new QAction (tr ("&Remove Unselected"),this);
     m_subMenu->addAction (remUnselAct);
-    connect (remUnselAct, SIGNAL (triggered()),
-             m_playListModel, SLOT (removeUnselected ()));
+    connect (remUnselAct, SIGNAL (triggered()), m_pl_manager, SLOT (removeUnselected ()));
+
+    m_subMenu->addSeparator();
+    m_subMenu->addAction (tr("Remove unavailable files"), m_pl_manager, SLOT(removeInvalidItems()));
+    m_subMenu->addAction (tr("Remove duplicates"), m_pl_manager, SLOT(removeDuplicates()));
 
     //listwidget menu
     QAction *detailsAct = new QAction (tr ("&View Track Details"),this);
     detailsAct->setShortcut (tr ("Alt+I"));
     m_listWidget->menu()->addAction (detailsAct);
-    connect (detailsAct, SIGNAL (triggered()), m_playListModel, SLOT (showDetails ()));
+    connect (detailsAct, SIGNAL (triggered()), m_pl_manager, SLOT (showDetails ()));
 
     // sort menu
     m_sortMenu->addAction (detailsAct);
@@ -184,6 +227,14 @@ void PlayList::createActions()
     connect (titleAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (titleAct, PlayListModel::TITLE);
 
+    QAction* albumAct = sort_mode_menu->addAction (tr ("By Album"));
+    connect (albumAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (albumAct, PlayListModel::ALBUM);
+
+    QAction* artistAct = sort_mode_menu->addAction (tr ("By Artist"));
+    connect (artistAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (artistAct, PlayListModel::ARTIST);
+
     QAction* nameAct = sort_mode_menu->addAction (tr ("By Filename"));
     connect (nameAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (nameAct, PlayListModel::FILENAME);
@@ -200,8 +251,7 @@ void PlayList::createActions()
     connect (trackAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (trackAct, PlayListModel::TRACK);
 
-    connect (signalMapper, SIGNAL (mapped (int)),
-             m_playListModel, SLOT (sort (int)));
+    connect (signalMapper, SIGNAL (mapped (int)), m_pl_manager, SLOT (sort (int)));
 
     m_sortMenu->addMenu (sort_mode_menu);
 
@@ -211,6 +261,14 @@ void PlayList::createActions()
     connect (titleAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (titleAct, PlayListModel::TITLE);
 
+    albumAct = sort_mode_menu->addAction (tr ("By Album"));
+    connect (albumAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (albumAct, PlayListModel::ALBUM);
+
+    artistAct = sort_mode_menu->addAction (tr ("By Artist"));
+    connect (artistAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (artistAct, PlayListModel::ARTIST);
+
     nameAct = sort_mode_menu->addAction (tr ("By Filename"));
     connect (nameAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (nameAct, PlayListModel::FILENAME);
@@ -227,53 +285,53 @@ void PlayList::createActions()
     connect (trackAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (trackAct, PlayListModel::TRACK);
 
-    connect (signalMapper, SIGNAL (mapped (int)),
-             m_playListModel, SLOT (sortSelection (int)));
+    connect (signalMapper, SIGNAL (mapped (int)), m_pl_manager, SLOT (sortSelection (int)));
 
     m_sortMenu->addMenu (sort_mode_menu);
 
     m_sortMenu->addSeparator();
-    m_sortMenu->addAction (tr ("Randomize List"),m_playListModel,SLOT (randomizeList()));
-    m_sortMenu->addAction (tr ("Reverse List"),m_playListModel,SLOT (reverseList()));
+    m_sortMenu->addAction (tr ("Randomize List"),m_pl_manager,SLOT (randomizeList()));
+    m_sortMenu->addAction (tr ("Reverse List"),m_pl_manager,SLOT (reverseList()));
 
     m_listWidget->menu()->addSeparator();
-    m_listWidget->menu()->addActions (m_subMenu->actions());
+    m_listWidget->menu()->addActions (m_subMenu->actions().mid(0,3)); //use 3 first actions
     m_listWidget->menu()->addMenu(GeneralHandler::instance()->createMenu(GeneralHandler::PLAYLIST_MENU,
                                   tr("Actions"), this));
 
     m_listWidget->menu()->addSeparator();
-    m_listWidget->menu()->addAction(tr("&Queue"),m_playListModel, SLOT(addToQueue()), tr("Q"));
+    m_listWidget->menu()->addAction(tr("&Queue"),m_pl_manager, SLOT(addToQueue()), tr("Q"));
     m_actions << m_listWidget->menu()->actions();
 
     //select menu
     QAction *invSelAct = new QAction (tr ("Invert Selection"),this);
     m_selectMenu->addAction (invSelAct);
-    connect (invSelAct, SIGNAL (triggered()),
-             m_playListModel, SLOT (invertSelection ()));
+    connect (invSelAct, SIGNAL (triggered()), m_pl_manager, SLOT (invertSelection ()));
 
     m_selectMenu->addSeparator();
 
     QAction *selNoneAct = new QAction (tr ("&Select None"),this);
-    //selNoneAct->setShortcut(tr("Ctrl+Shift+A"));
+    selNoneAct->setShortcut(tr("Shift+A"));
     m_selectMenu->addAction (selNoneAct);
-    connect (selNoneAct, SIGNAL (triggered()),
-             m_playListModel, SLOT (clearSelection ()));
+    connect (selNoneAct, SIGNAL (triggered()), m_pl_manager, SLOT (clearSelection ()));
     this->addAction (selNoneAct);
 
     QAction *selAllAct = new QAction (tr ("&Select All"),this);
     selAllAct->setShortcut (tr ("Ctrl+A"));
     m_actions << selAllAct;
     m_selectMenu->addAction (selAllAct);
-    connect (selAllAct, SIGNAL (triggered()),
-             m_playListModel, SLOT (selectAll ()));
-    //this->addAction (selAllAct);
+    connect (selAllAct, SIGNAL (triggered()), m_pl_manager, SLOT (selectAll ()));
 
-//  Playlist Menu
+    //  Playlist Menu
     QAction *newListAct = new QAction (tr ("&New List"),this);
-    newListAct->setShortcut (tr ("Shift+N"));
+    newListAct->setShortcut (tr ("Ctrl+T"));
     m_actions << newListAct;
     m_playlistMenu->addAction (newListAct);
-    connect (newListAct, SIGNAL (triggered()), this, SIGNAL (newPlaylist()));
+    connect (newListAct, SIGNAL (triggered()), m_pl_manager, SLOT (createPlayList()));
+    QAction *deleteListAct = new QAction (tr ("&Delete List"),this);
+    deleteListAct->setShortcut (tr ("Ctrl+W"));
+    m_actions << deleteListAct;
+    m_playlistMenu->addAction (deleteListAct);
+    connect (deleteListAct, SIGNAL (triggered()), SLOT (deletePlaylist()));
     m_playlistMenu->addSeparator();
 
     QAction *loadListAct = new QAction (tr ("&Load List"),this);
@@ -287,9 +345,27 @@ void PlayList::createActions()
     m_actions << saveListAct;
     m_playlistMenu->addAction (saveListAct);
     connect (saveListAct, SIGNAL (triggered()), this, SIGNAL (savePlaylist()));
-    //this->addActions (m_playlistMenu->actions());
 
-    Dock::getPointer()->addActions (m_actions);
+    m_playlistMenu->addSeparator();
+    QAction *nextListAct = new QAction (tr ("&Select Next Playlist"),this);
+    nextListAct->setShortcut (tr ("Ctrl+PgDown"));
+    m_actions << nextListAct;
+    m_playlistMenu->addAction (nextListAct);
+    connect (nextListAct, SIGNAL (triggered()), m_pl_manager, SLOT (selectNextPlayList()));
+
+    QAction *previousListAct = new QAction (tr ("&Select Previous Playlist"),this);
+    previousListAct->setShortcut (tr ("Ctrl+PgUp"));
+    m_actions << previousListAct;
+    m_playlistMenu->addAction (previousListAct);
+    connect (previousListAct, SIGNAL (triggered()), m_pl_manager, SLOT (selectPreviousPlayList()));
+
+    QAction *browseListsAct = new QAction (tr ("&Show Playlists"),this);
+    browseListsAct->setShortcut (tr ("P"));
+    m_actions << browseListsAct;
+    m_playlistMenu->addAction (browseListsAct);
+    connect (browseListsAct, SIGNAL (triggered()), SLOT (showPlayLists()));
+
+    Dock::instance()->addActions (m_actions);
 }
 
 void PlayList::closeEvent (QCloseEvent *e)
@@ -301,8 +377,8 @@ void PlayList::closeEvent (QCloseEvent *e)
 
 void PlayList::paintEvent (QPaintEvent *)
 {
-    int m_sx = (width()-275) /25;
-    int m_sy = (height()-116) /29;
+    int m_sx = (width()-275*m_ratio) /25;
+    int m_sy = (height()-116*m_ratio) /29;
     drawPixmap (m_sx, m_sy);
 }
 
@@ -310,58 +386,37 @@ void PlayList::drawPixmap (int sx, int sy)
 {
     QPainter paint;
     paint.begin (this);
-    paint.drawPixmap (0,20,m_skin->getPlPart (Skin::PL_LFILL));
-    for (int i = 1; i<sy+2; i++)
+    paint.drawPixmap (0,20*m_ratio, m_skin->getPlPart (Skin::PL_LFILL));
+    for (int i = 1; i<sy+2*m_ratio; i++)
     {
-        paint.drawPixmap (0,20+29*i,m_skin->getPlPart (Skin::PL_LFILL));
+        paint.drawPixmap (0,20*m_ratio+29*i,m_skin->getPlPart (Skin::PL_LFILL));
     }
-    paint.drawPixmap (0,78+29*sy,m_skin->getPlPart (Skin::PL_LSBAR));
+    paint.drawPixmap (0,78*m_ratio+29*sy,m_skin->getPlPart (Skin::PL_LSBAR));
     for (int i = 0; i<sx; i++)
     {
-        paint.drawPixmap (125+i*25,78+sy*29,m_skin->getPlPart (Skin::PL_SFILL1));
+        paint.drawPixmap (125*m_ratio+i*25,78*m_ratio+sy*29,m_skin->getPlPart (Skin::PL_SFILL1));
     }
-
-    paint.drawPixmap (125+sx*25,78+sy*29,m_skin->getPlPart (Skin::PL_RSBAR));
+    paint.drawPixmap (125*m_ratio+sx*25,78*m_ratio+sy*29,m_skin->getPlPart (Skin::PL_RSBAR));
     paint.end();
-
 }
 
-void PlayList::resizeEvent (QResizeEvent *e)
+void PlayList::resizeEvent (QResizeEvent *)
 {
-    int sx = (e->size().width()-275) /25;
-    int sy = (e->size().height()-116) /29;
-    if (sx < 0 || sy < 0)
-        return;
-
-    m_titleBar->resize (275+25*sx,20);
-    m_plslider->resize (20,58+sy*29);
-
-    m_listWidget->resize (243+25*sx,58+29*sy);
-
-    m_buttonAdd->move (11,86+29*sy);
-    m_buttonSub->move (40,86+29*sy);
-    m_selectButton->move (70,86+29*sy);
-    m_sortButton->move (99,86+29*sy);
-
-    m_pl_control->move (128+sx*25,100+29*sy);
-    m_playlistButton->move (228+sx*25,86+29*sy);
-
-    m_length_totalLength -> move (131+sx*25,88+29*sy);
-    m_current_time->move (190+sx*25,101+29*sy);
-
-    m_plslider->move (255+sx*25,20);
+    updatePositions();
 }
+
 void PlayList::mousePressEvent (QMouseEvent *e)
 {
     m_pos = e->pos ();
-    if ((m_pos.x() > width()-25) && (m_pos.y() > height()-25))
+    if (m_resizeWidget->underMouse())
     {
-        m_resize = TRUE;
-        setCursor (Qt::SizeFDiagCursor);
+        m_resize = true;
+        setCursor (m_skin->getCursor (Skin::CUR_PSIZE));
     }
     else
-        m_resize = FALSE;
+        m_resize = false;
 }
+
 void PlayList::mouseMoveEvent (QMouseEvent *e)
 {
     if (m_resize)
@@ -383,21 +438,14 @@ void PlayList::mouseMoveEvent (QMouseEvent *e)
 #endif
     }
 }
+
 void PlayList::mouseReleaseEvent (QMouseEvent *)
 {
-    setCursor (Qt::ArrowCursor);
+    setCursor (m_skin->getCursor (Skin::CUR_PNORMAL));
     /*if (m_resize)
         m_listWidget->updateList();*/
-    m_resize = FALSE;
-    Dock::getPointer()->updateDock();
-}
-void PlayList::setModel (PlayListModel *model)
-{
-    m_playListModel = model;
-    m_listWidget->setModel (model);
-    m_keyboardManager->setModel (model);
-    m_titleBar->setModel (model);
-    createActions();
+    m_resize = false;
+    Dock::instance()->updateDock();
 }
 
 void PlayList::changeEvent (QEvent * event)
@@ -410,25 +458,37 @@ void PlayList::changeEvent (QEvent * event)
 
 void PlayList::readSettings()
 {
+    QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
+    if (settings.value("PlayList/show_plalists", false).toBool())
+    {
+        if(!m_pl_selector)
+            m_pl_selector = new PlayListSelector(m_pl_manager, this);
+        m_pl_selector->show();
+    }
+    else
+    {
+        if(m_pl_selector)
+            m_pl_selector->deleteLater();
+        m_pl_selector = 0;
+    }
     if (m_update)
     {
         m_listWidget->readSettings();
         m_titleBar->readSettings();
+        if(m_pl_selector)
+            m_pl_selector->readSettings();
+        updatePositions();
     }
     else
     {
-        QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
-        if (settings.value("General/openbox_compat", FALSE).toBool())
+        if (settings.value("General/openbox_compat", false).toBool() ||
+            settings.value("General/metacity_compat", false).toBool())
             setWindowFlags (Qt::Tool | Qt::FramelessWindowHint);
         else
-            setWindowFlags (Qt::Dialog | Qt::FramelessWindowHint);
-        settings.beginGroup ("PlayList");
-        //position
-        move (settings.value ("pos", QPoint (100, 332)).toPoint());
-        settings.endGroup();
-        m_update = TRUE;
+            setWindowFlags (Qt::Dialog | Qt::FramelessWindowHint); 
+        move (settings.value ("PlayList/pos", QPoint (100, 332)).toPoint());  //position
+        m_update = true;
     }
-
 }
 
 void PlayList::writeSettings()
@@ -462,16 +522,9 @@ void PlayList::showSortMenu()
 
 QString PlayList::formatTime (int sec)
 {
-    int minutes = sec / 60;
-    int seconds = sec % 60;
-
-    QString str_minutes = QString::number (minutes);
-    QString str_seconds = QString::number (seconds);
-
-    if (minutes < 10) str_minutes.prepend ("0");
-    if (seconds < 10) str_seconds.prepend ("0");
-
-    return str_minutes + ":" + str_seconds;
+    if(sec > 3600)
+        sec /= 60;
+    return QString("%1:%2").arg(sec/60, 2, 10, QChar('0')).arg(sec%60, 2, 10, QChar('0'));
 }
 
 void PlayList::setTime(qint64 time)
@@ -482,14 +535,12 @@ void PlayList::setTime(qint64 time)
         m_current_time->display (formatTime (time/1000));
     m_current_time->update();
 
-    if (m_playListModel && SoundCore::instance())
+    if (SoundCore::instance())
     {
-        m_playListModel->totalLength();
-        QString str_length = formatTime (m_playListModel->totalLength()) +
+        QString str_length = formatTime (m_pl_manager->currentPlayList()->totalLength()) +
                              "/" + formatTime (SoundCore::instance()->totalTime()/1000);
         m_length_totalLength->display (str_length);
         m_length_totalLength->update();
-
     }
 }
 
@@ -499,10 +550,9 @@ void PlayList::updateList()
     m_titleBar->showCurrent();
 }
 
-
 PlayListItem *PlayList::currentItem()
 {
-    return m_playListModel ? m_playListModel->currentItem() : 0;
+    return m_pl_manager->currentPlayList()->currentItem();
 }
 
 void PlayList::showPlaylistMenu()
@@ -515,3 +565,50 @@ void PlayList::keyPressEvent (QKeyEvent *ke)
     if (m_keyboardManager->handleKeyPress (ke))
         update();
 }
+
+void PlayList::updateSkin()
+{
+    setCursor(m_skin->getCursor(Skin::CUR_PNORMAL)); // TODO shaded
+    m_resizeWidget->setCursor(m_skin->getCursor (Skin::CUR_PSIZE));
+    m_ratio = m_skin->ratio();
+    setMinimalMode(m_shaded);
+}
+
+void PlayList::deletePlaylist()
+{
+    m_pl_manager->removePlayList(m_pl_manager->selectedPlayList());
+}
+
+void PlayList::showPlayLists()
+{
+    if(!m_pl_browser)
+    {
+        m_pl_browser = new PlayListBrowser(m_pl_manager, this);
+        m_pl_browser->show();
+    }
+    else
+        m_pl_browser->show();
+}
+
+void PlayList::setMinimalMode(bool b)
+{
+    if(!m_shaded)
+        m_height = height();
+    m_shaded = b;
+    if(m_shaded)
+    {
+        m_height = height();
+        setSizeIncrement (25*m_ratio, 1);
+        setMinimumSize (275*m_ratio, 14*m_ratio);
+        resize(width(), 14*m_ratio);
+    }
+    else
+    {
+        setMinimumSize(275*m_ratio, 116*m_ratio);
+        resize (width(), m_height);
+        setSizeIncrement (25*m_ratio, 29*m_ratio);
+
+    }
+    updatePositions();
+    update();
+}
