@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Ilya Kotov                                      *
+ *   Copyright (C) 2007-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,23 +37,21 @@ class PlayListTitleBar : public PixmapWidget
 Q_OBJECT
 public:
     PlayListTitleBar(QWidget *parent = 0);
-
     ~PlayListTitleBar();
-
     void setActive(bool);
-    void setModel(PlayListModel *model);
     void readSettings();
 
 public slots:
     void showCurrent();
+    void setModel(PlayListModel *selected, PlayListModel *previous = 0);
 
 private slots:
     void updateSkin();
     void shade();
 
 private:
-    void drawPixmap(int);
-    void truncate();
+    void updatePositions();
+    void updatePixmap();
     Skin *m_skin;
     QPoint pos;
     bool m_active;
@@ -64,6 +62,7 @@ private:
     Button* m_shade2;
     bool m_shaded;
     bool m_align, m_resize;
+    int m_ratio;
     int m_height;
     PlayListModel* m_model;
     QString m_text;
