@@ -32,15 +32,16 @@
 PositionBar::PositionBar(QWidget *parent)
         : PixmapWidget(parent)
 {
-    m_skin = Skin::getPointer();
+    m_skin = Skin::instance();
     connect(m_skin, SIGNAL(skinChanged()), this, SLOT(updateSkin()));
     setPixmap(m_skin->getPosBar());
     mw = qobject_cast<MainWindow*>(window());
-    m_moving = FALSE;
+    m_moving = false;
     m_min = 0;
     m_max = 0;
     m_old = m_value = 0;
-    draw(FALSE);
+    draw(false);
+    setCursor(m_skin->getCursor(Skin::CUR_POSBAR));
 }
 
 
@@ -49,17 +50,16 @@ PositionBar::~PositionBar()
 
 void PositionBar::mousePressEvent(QMouseEvent *e)
 {
-
-    m_moving = TRUE;
+    m_moving = true;
     press_pos = e->x();
-    if (m_pos<e->x() && e->x()<m_pos+29)
+    if (m_pos<e->x() && e->x()<m_pos+29*m_skin->ratio())
     {
         press_pos = e->x()-m_pos;
     }
     else
     {
-        m_value = convert(qMax(qMin(width()-30,e->x()-15),0));
-        press_pos = 15;
+        m_value = convert(qMax(qMin(width()-30*m_skin->ratio(),e->x()-15*m_skin->ratio()),0));
+        press_pos = 15*m_skin->ratio();
         if (m_value!=m_old)
         {
             emit sliderMoved(m_value);
@@ -76,7 +76,7 @@ void PositionBar::mouseMoveEvent (QMouseEvent *e)
         qint64 po = e->x();
         po = po - press_pos;
 
-        if (0<=po && po<=width()-30)
+        if (0<=po && po<=width()-30*m_skin->ratio())
         {
             m_value = convert(po);
             draw();
@@ -87,13 +87,13 @@ void PositionBar::mouseMoveEvent (QMouseEvent *e)
 
 void PositionBar::mouseReleaseEvent(QMouseEvent*)
 {
-    draw(FALSE);
+    draw(false);
     if (m_value!=m_old && m_max > 0)
     {
         m_old = m_value;
         mw->seek(m_value);
     }
-    m_moving = FALSE;
+    m_moving = false;
 }
 
 void PositionBar::setValue(qint64 v)
@@ -101,25 +101,25 @@ void PositionBar::setValue(qint64 v)
     if (m_moving || m_max == 0)
         return;
     m_value = v;
-    draw(FALSE);
+    draw(false);
 }
 
 void PositionBar::setMax(qint64 max)
 {
     m_max = max;
-    draw(FALSE);
+    draw(false);
 }
 
 void PositionBar::updateSkin()
 {
-    draw(FALSE);
-    //setPixmap(m_skin->getPosBar());
-    //setButtonPixmap(Skin::BT_POSBAR_N);
+    resize(m_skin->getPosBar().size());
+    draw(false);
+    setCursor(m_skin->getCursor(Skin::CUR_POSBAR));
 }
 
 void PositionBar::draw(bool pressed)
 {
-    qint64 p=qint64(ceil(double(m_value-m_min)*(width()-30)/(m_max-m_min)));
+    qint64 p=qint64(ceil(double(m_value-m_min)*(width()-30*m_skin->ratio())/(m_max-m_min)));
     m_pixmap = m_skin->getPosBar();
     if (m_max > 0)
     {
@@ -129,11 +129,11 @@ void PositionBar::draw(bool pressed)
         else
             paint.drawPixmap(p,0,m_skin->getButton(Skin::BT_POSBAR_N));
     }
-        setPixmap(m_pixmap);
+    setPixmap(m_pixmap);
     m_pos = p;
 }
 
 qint64 PositionBar::convert(qint64 p)
 {
-    return qint64(ceil(double(m_max-m_min)*(p)/(width()-30)+m_min));
+    return qint64(ceil(double(m_max-m_min)*(p)/(width()-30*m_skin->ratio())+m_min));
 }
