@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,16 +23,14 @@
 #include "skin.h"
 #include "mainvisual.h"
 #include "inlines.h"
-
-
 #include "shadedvisual.h"
 
-ShadedVisual::ShadedVisual(QWidget *parent)
-        : Visual(parent)
-{
-    setFixedSize(38,5);
-    m_pixmap = QPixmap (38,5);
-    m_skin = Skin::getPointer();
+ShadedVisual::ShadedVisual(QWidget *parent) : Visual(parent)
+{    
+    m_skin = Skin::instance();
+    m_ratio = m_skin->ratio();
+    resize(m_ratio*38,m_ratio*5);
+    m_pixmap = QPixmap (m_ratio*38,m_ratio*5);
     m_timer = new QTimer(this);
     connect(m_timer, SIGNAL (timeout()), this, SLOT (timeout()));
     connect(m_skin, SIGNAL(skinChanged()), this, SLOT(updateSkin()));
@@ -41,47 +39,38 @@ ShadedVisual::ShadedVisual(QWidget *parent)
     clear();
 }
 
-
 ShadedVisual::~ShadedVisual()
 {}
 
-void ShadedVisual::add(Buffer *b, unsigned long w, int c, int p)
+void ShadedVisual::add(unsigned char *data, qint64 size, int chan)
 {
     if (!m_timer->isActive ())
         return;
-    long len = b->nbytes, cnt;
+    long len = size, cnt;
     short *l = 0, *r = 0;
 
-    len /= c;
-    len /= ( p / 8 );
+    len /= chan;
+    len /= 2;
     if ( len > 512 )
         len = 512;
     cnt = len;
 
-    if ( c == 2 )
+    if (chan == 2)
     {
         l = new short[len];
         r = new short[len];
-
-        if ( p == 8 )
-            stereo16_from_stereopcm8 ( l, r, b->data, cnt );
-        else if ( p == 16 )
-            stereo16_from_stereopcm16 ( l, r, ( short * ) b->data, cnt );
+        stereo16_from_stereopcm16 ( l, r, (short *) data, cnt);
     }
-    else if ( c == 1 )
+    else if (chan == 1)
     {
         l = new short[len];
-
-        if ( p == 8 )
-            mono16_from_monopcm8 ( l, b->data, cnt );
-        else if ( p == 16 )
-            mono16_from_monopcm16 ( l, ( short * ) b->data, cnt );
+        mono16_from_monopcm16 (l, (short *) data, cnt);
     }
     else
         len = 0;
 
     if (len)
-        m_nodes.append (new VisualNode (l, r, len, w));
+        m_nodes.append (new VisualNode (l, r, len));
 }
 
 void ShadedVisual::clear()
@@ -92,7 +81,7 @@ void ShadedVisual::clear()
     m_r = 0;
     m_pixmap.fill(m_skin->getVisColor(0));
     update();
-};
+}
 
 void ShadedVisual::timeout()
 {
@@ -164,11 +153,11 @@ void ShadedVisual::draw (QPainter *p)
 {
     for (int i = 0; i < m_l; ++i)
     {
-        p->fillRect (i*3, 0, 3, 2, QBrush(m_skin->getVisColor (17-i)));
+        p->fillRect (i*3*m_ratio, 0, 3*m_ratio, 2*m_ratio, QBrush(m_skin->getVisColor (17-i)));
     }
     for (int i = 0; i < m_r; ++i)
     {
-        p->fillRect (i*3, 3, 3, 2, QBrush(m_skin->getVisColor (17-i)));
+        p->fillRect (i*3*m_ratio, 3*m_ratio, 3*m_ratio, 2*m_ratio, QBrush(m_skin->getVisColor (17-i)));
     }
 }
 
@@ -190,5 +179,8 @@ void ShadedVisual::showEvent (QShowEvent *)
 
 void ShadedVisual::updateSkin()
 {
+    m_ratio = m_skin->ratio();
+    resize(m_ratio*38,m_ratio*5);
+    m_pixmap = QPixmap (m_ratio*38,m_ratio*5);
     clear();
 }
