@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   Based on Promoe, an XMMS2 Client                                      *
@@ -31,14 +31,15 @@
 
 #include <qmmp/qmmp.h>
 #include "skin.h"
+#include "cursorimage.h"
 
-Skin *Skin::pointer = 0;
+Skin *Skin::m_instance = 0;
 
-Skin *Skin::getPointer()
+Skin *Skin::instance()
 {
-    if (!pointer)
-        pointer = new Skin();
-    return pointer;
+    if (!m_instance)
+        m_instance = new Skin();
+    return m_instance;
 }
 
 QPixmap Skin::getPixmap (const QString& name, QDir dir)
@@ -57,10 +58,9 @@ QPixmap Skin::getPixmap (const QString& name, QDir dir)
     return QPixmap();
 }
 
-Skin::Skin (QObject *parent)
-        : QObject (parent)
+Skin::Skin (QObject *parent) : QObject (parent)
 {
-    pointer = this;
+    m_instance = this;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     QString path = settings.value("skin_path","").toString();
     if (path.isEmpty() || !QDir(path).exists ())
@@ -71,46 +71,88 @@ Skin::Skin (QObject *parent)
     skinDir.mkdir ("skins");
 }
 
-
 Skin::~Skin()
 {}
 
 void Skin::setSkin (const QString& path)
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    m_use_cursors = settings.value("General/skin_cursors", false).toBool();
+    m_double_size = settings.value("General/double_size", false).toBool();
     settings.setValue("skin_path",path);
-
-    qDebug ("Skin: set skin %s",qPrintable(path));    //TODO don't clear lists
+    qDebug ("Skin: using %s",qPrintable(path));
     m_skin_dir = QDir (path);
-
+    //clear old values
     m_pledit_txt.clear();
-    loadPLEdit();
-    loadMain();
     buttons.clear();
-    loadButtons();
-    loadShufRep();
     titlebar.clear();
-    loadTitleBar();
-    loadPosBar();
     m_numbers.clear();
-    loadNumbers();
     m_pl_parts.clear();
-    loadPlayList();
     m_eq_parts.clear();
-    loadEq_ex();
     m_eq_bar.clear();
     m_eq_spline.clear();
-    loadEqMain();
     m_vis_colors.clear();
+    cursors.clear();
+    //load skin parts
+    loadPLEdit();
+    loadMain();
+    loadButtons();
+    loadShufRep();
+    loadTitleBar();
+    loadPosBar();
+    loadNumbers();
+    loadPlayList();
+    loadEq_ex();
+    loadEqMain();
     loadVisColor();
     loadLetters();
     loadMonoSter();
     loadVolume();
     loadBalance();
     loadRegion();
+    loadCursors();
+    if(m_double_size)
+    {
+        uint key;
+        foreach(key, buttons.keys())
+            buttons[key] = scalePixmap(buttons[key]);
+        foreach(key, titlebar.keys())
+            titlebar[key] = scalePixmap(titlebar[key]);
+        foreach(key, m_pl_parts.keys())
+            m_pl_parts[key] = scalePixmap(m_pl_parts[key]);
+        foreach(key, m_eq_parts.keys())
+            m_eq_parts[key] = scalePixmap(m_eq_parts[key]);
+        foreach(key, m_ms_parts.keys())
+            m_ms_parts[key] = scalePixmap(m_ms_parts[key]);
+        foreach(key, m_parts.keys())
+            m_parts[key] = scalePixmap(m_parts[key]);
+        foreach(QChar c, m_letters.keys())
+            m_letters[c] = scalePixmap(m_letters[c]);
+        m_main = scalePixmap(m_main);
+        posbar = scalePixmap(posbar);
+        int i;
+        for(i = 0; i < m_numbers.size(); ++i)
+            m_numbers[i] = scalePixmap(m_numbers[i]);
+
+        for(i = 0; i < m_eq_bar.size(); ++i)
+            m_eq_bar[i] = scalePixmap(m_eq_bar[i]);
+
+        for(i = 0; i < m_eq_spline.size(); ++i)
+            m_eq_spline[i] = scalePixmap(m_eq_spline[i]);
+
+        for(i = 0; i < m_volume.size(); ++i)
+            m_volume[i] = scalePixmap(m_volume[i]);
+        for(i = 0; i < m_balance.size(); ++i)
+            m_balance[i] = scalePixmap(m_balance[i]);
+    }
     emit skinChanged();
 }
 
+void Skin::reloadSkin()
+{
+    setSkin (m_skin_dir.absolutePath ());
+}
+
 void Skin::loadMain()
 {
     QPixmap *pixmap = getPixmap ("main");
@@ -121,6 +163,51 @@ void Skin::loadMain()
     delete pixmap;
 }
 
+void Skin::loadCursors()
+{
+    if(!m_use_cursors)
+    {
+        for(int i = CUR_NORMAL; i <= CUR_WSWINBUT; ++i)
+            cursors[i] = QCursor(Qt::ArrowCursor);
+        cursors[CUR_PSIZE] = QCursor(Qt::SizeFDiagCursor);
+        return;
+    }
+    cursors[CUR_NORMAL] = createCursor(getPath("normal"));
+    cursors[CUR_CLOSE] = createCursor(getPath("close"));
+    cursors[CUR_MAINMENU] = createCursor(getPath("mainmenu"));
+    cursors[CUR_MIN] = createCursor(getPath("min"));
+    cursors[CUR_POSBAR] = createCursor(getPath("posbar.cur"));
+    cursors[CUR_SONGNAME] = createCursor(getPath("songname"));
+    cursors[CUR_TITLEBAR] = createCursor(getPath("titlebar.cur"));
+    cursors[CUR_VOLBAL] = createCursor(getPath("volbal"));
+    cursors[CUR_WINBUT] = createCursor(getPath("winbut"));
+
+    cursors[CUR_WSNORMAL] = createCursor(getPath("wsnormal"));
+    cursors[CUR_WSPOSBAR] = createCursor(getPath("wsposbar"));
+
+    cursors[CUR_EQCLOSE] = createCursor(getPath("eqclose"));
+    cursors[CUR_EQNORMAL] = createCursor(getPath("eqnormal"));
+    cursors[CUR_EQSLID] = createCursor(getPath("eqslid"));
+    cursors[CUR_EQTITLE] = createCursor(getPath("eqtitle"));
+
+    cursors[CUR_PCLOSE] = createCursor(getPath("pclose"));
+    cursors[CUR_PNORMAL] = createCursor(getPath("pnormal"));
+    cursors[CUR_PSIZE] = createCursor(getPath("psize"));
+    if(cursors[CUR_PSIZE].shape() == Qt::ArrowCursor)
+        cursors[CUR_PSIZE] = QCursor(Qt::SizeFDiagCursor);
+    cursors[CUR_PTBAR] = createCursor(getPath("ptbar"));
+    cursors[CUR_PVSCROLL] = createCursor(getPath("pvscroll"));
+    cursors[CUR_PWINBUT] = createCursor(getPath("pwinbut"));
+
+    cursors[CUR_PWSNORM] = createCursor(getPath("pwsnorm"));
+    cursors[CUR_PWSSIZE] = createCursor(getPath("pwssize"));
+
+    cursors[CUR_VOLBAR] = createCursor(getPath("volbar"));
+    cursors[CUR_WSCLOSE] = createCursor(getPath("wsclose"));
+    cursors[CUR_WSMIN] = createCursor(getPath("wsmin"));
+    cursors[CUR_WSWINBUT] = createCursor(getPath("wswinbut"));
+}
+	
 void Skin::loadButtons()
 {
 
@@ -147,12 +234,10 @@ void Skin::loadButtons()
     buttons[BT_EJECT_N] = pixmap->copy (114, 0,22,16);
     buttons[BT_EJECT_P] = pixmap->copy (114,16,22,16);
     delete pixmap;
-
 }
 
 void Skin::loadTitleBar()
 {
-
     QPixmap *pixmap = getPixmap ("titlebar");
 
     if (!pixmap)
@@ -173,12 +258,10 @@ void Skin::loadTitleBar()
     titlebar[TITLEBAR_SHADED_A] = pixmap->copy (27,29,275,14);
     titlebar[TITLEBAR_SHADED_I] = pixmap->copy (27,42,275,14);
     delete pixmap;
-
 }
 
 void Skin::loadPosBar()
 {
-
     QPixmap *pixmap = getPixmap ("posbar");
 
     if (!pixmap)
@@ -198,7 +281,6 @@ void Skin::loadPosBar()
     }
     posbar = pixmap->copy (0,0,248,pixmap->height());
     delete pixmap;
-
 }
 
 void Skin::loadNumbers()
@@ -236,7 +318,6 @@ void Skin::loadNumbers()
 
 void Skin::loadPlayList()
 {
-
     QPixmap *pixmap = getPixmap ("pledit");
 
     if (!pixmap)
@@ -304,6 +385,27 @@ QPixmap *Skin::getPixmap (const QString& name)
     return 0;
 }
 
+QString Skin::getPath (const QString& name)
+{
+    m_skin_dir.setFilter (QDir::Files | QDir::Hidden | QDir::NoSymLinks);
+    QFileInfoList f = m_skin_dir.entryInfoList();
+    bool nameHasExt = name.contains('.');
+    for (int j = 0; j < f.size(); ++j)
+    {
+        QFileInfo fileInfo = f.at (j);
+        QString fn = fileInfo.fileName().toLower();
+        if (!nameHasExt && fn.section (".",0,0) == name)
+        {
+            return fileInfo.filePath();
+        } else if (nameHasExt && fn == name)
+        {
+            return fileInfo.filePath();
+        }
+    }
+    return QString();
+}
+
+
 void Skin::loadPLEdit()
 {
     QString path = findFile("pledit.txt", m_skin_dir);
@@ -384,7 +486,6 @@ void Skin::loadEqMain()
         m_eq_spline << pixmap->copy (115, 294+i, 1, 1);
     }
     delete pixmap;
-
 }
 
 void Skin::loadEq_ex()
@@ -486,7 +587,6 @@ void Skin::loadShufRep()
     buttons[SHUFFLE_OFF_P] = pixmap->copy (28,15,46,15);
 
     delete pixmap;
-
 }
 
 void Skin::loadLetters(void)
@@ -654,8 +754,6 @@ void Skin::loadBalance()
 
 void Skin::loadRegion()
 {
-    //m_mwRegion = QRegion();
-    //m_plRegion = QRegion();
     m_regions.clear();
     QString path = findFile("region.txt", m_skin_dir);
 
@@ -684,6 +782,7 @@ QRegion Skin::createRegion(const QString &path, const QString &key)
 
     QList<QString>::iterator n;
     n = numbers.begin();
+    int r = m_double_size ? 2 : 1;
     for (int i = 0; i < numPoints.size(); ++i)
     {
         QList <int> lp;
@@ -696,7 +795,7 @@ QRegion Skin::createRegion(const QString &path, const QString &key)
 
         for (int l = 0; l < lp.size(); l+=2)
         {
-            points << QPoint(lp.at(l), lp.at(l+1));
+            points << QPoint(lp.at(l)*r, lp.at(l+1)*r);
         }
         region = region.united(QRegion(QPolygon(points)));
     }
@@ -717,10 +816,16 @@ QPixmap * Skin::getDummyPixmap(const QString& name)
             return new QPixmap (fileInfo.filePath());
         }
     }
-    qFatal("Skin: default skin corrupted");
+    qFatal("Skin: default skin is corrupted");
     return 0;
 }
 
+QPixmap Skin::scalePixmap(const QPixmap &pix, int ratio)
+{
+    return pix.scaled(pix.width() * ratio, pix.height() * ratio,
+                      Qt::KeepAspectRatio);
+}
+
 const QString Skin::findFile(const QString &name, QDir dir)
 {
     dir.setFilter (QDir::Files | QDir::Hidden | QDir::NoSymLinks);
