@@ -59,12 +59,12 @@ void SkinReader::generateThumbs()
     //clear removed skins from cache
     foreach(QFileInfo thumbFile, d)
     {
-        bool del = TRUE;
+        bool del = true;
         foreach(QFileInfo fileInfo, f)
         {
             if (fileInfo.baseName () == thumbFile.baseName ())
             {
-                del = FALSE;
+                del = false;
                 break;
             }
         }
@@ -79,12 +79,12 @@ void SkinReader::generateThumbs()
     //add new skins to cache
     foreach(QFileInfo fileInfo, f)
     {
-        bool create = TRUE;
+        bool create = true;
         foreach(QFileInfo thumbInfo, d)
         {
             if (fileInfo.baseName () == thumbInfo.baseName ())
             {
-                create = FALSE;
+                create = false;
                 break;
             }
         }
@@ -95,9 +95,9 @@ void SkinReader::generateThumbs()
             QString name = fileInfo.fileName ().toLower();
 
             if (name.endsWith(".tgz") || name.endsWith(".tar.gz") || name.endsWith(".tar.bz2"))
-                untar(fileInfo.filePath (), cache_dir.absolutePath (), TRUE);
+                untar(fileInfo.filePath (), cache_dir.absolutePath (), true);
             if (name.endsWith(".zip") || name.endsWith(".wsz"))
-                unzip(fileInfo.filePath (), cache_dir.absolutePath (), TRUE);
+                unzip(fileInfo.filePath (), cache_dir.absolutePath (), true);
         }
     }
     //add thumbs to map
@@ -126,9 +126,9 @@ void SkinReader::unpackSkin(const QString &path)
         dir.remove(file.fileName());
     //unpack
     if (path.endsWith(".tgz") || path.endsWith(".tar.gz") || path.endsWith(".tar.bz2"))
-        untar(path, QDir::homePath() +"/.qmmp/cache/skin", FALSE);
+        untar(path, QDir::homePath() +"/.qmmp/cache/skin", false);
     if (path.endsWith(".zip") || path.endsWith(".wsz"))
-        unzip(path, QDir::homePath() +"/.qmmp/cache/skin", FALSE);
+        unzip(path, QDir::homePath() +"/.qmmp/cache/skin", false);
 }
 
 const QStringList SkinReader::skins()
