@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -43,13 +43,15 @@ TextScroller::TextScroller ( QWidget *parent )
         : QWidget ( parent )
 {
     pointer = this;
-    m_skin = Skin::getPointer();
+    m_skin = Skin::instance();
     m_pixmap = QPixmap ( 150,15 );
     resize(150,15);
     x = 0;
+    m_offset = 0;
     m_progress = -1;
+    m_metrics = 0;
     m_text = "Qt-based Multimedia Player (Qmmp " + Qmmp::strVersion() + ")";
-    m_update = FALSE;
+    m_update = false;
     readSettings();
     m_timer = new QTimer ( this );
     connect (m_timer, SIGNAL (timeout()), SLOT (addOffset()));
@@ -57,14 +59,14 @@ TextScroller::TextScroller ( QWidget *parent )
     m_timer->start();
     updateSkin();
     connect(m_skin, SIGNAL(skinChanged()), this, SLOT(updateSkin()));
-    m_autoscroll = TRUE;
+    m_autoscroll = true;
     m_menu = new QMenu(this);
     QAction *autoscrollAction = new QAction(tr("Autoscroll Songname"), m_menu);
-    autoscrollAction->setCheckable (TRUE);
+    autoscrollAction->setCheckable (true);
     connect(autoscrollAction, SIGNAL(toggled(bool)), SLOT(setAutoscroll(bool)));
     m_menu->addAction(autoscrollAction);
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    autoscrollAction->setChecked(settings.value("TextScroller/autoscroll", TRUE).toBool());
+    autoscrollAction->setChecked(settings.value("TextScroller/autoscroll", true).toBool());
     setAutoscroll(autoscrollAction->isChecked());
 }
 
@@ -73,14 +75,22 @@ TextScroller::~TextScroller()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.setValue("TextScroller/autoscroll", m_autoscroll);
+    if(m_metrics)
+        delete m_metrics;
 }
 
 void TextScroller::addOffset()
 {
     x--;
-    if ( 154 + x < - m_metrics->width (m_scrollText) - 15 +1)
+    if(m_bitmap)
     {
-        x=-154;
+        if (154 + x < - m_scrollText.size() * 5 - 15 + 1)
+            x = -154;
+    }
+    else
+    {
+        if (154 + x < - m_metrics->width (m_scrollText) - 15 + 1)
+            x = -154;
     }
     update();
 }
@@ -95,13 +105,19 @@ void TextScroller::setText(const QString& text)
         m_text = text;
         m_scrollText = "*** " + text;
         x = m_autoscroll ? -50 : -150;
+        m_bitmap =  m_bitmapConf && (m_text.toLatin1() == m_text.toLocal8Bit());
     }
+    if(m_bitmap)
+        m_offset = m_scrollText.size() * 5 + 15;
+    else
+         m_offset = m_metrics->width (m_scrollText) + 15;
     update();
 }
 
 void TextScroller::updateSkin()
 {
     m_color.setNamedColor(m_skin->getPLValue("mbfg"));
+    setCursor(m_skin->getCursor(Skin::CUR_SONGNAME));
 }
 
 
@@ -125,18 +141,22 @@ void TextScroller::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     QString fontname = settings.value("MainWindow/Font","").toString();
+    m_bitmapConf = settings.value("MainWindow/bitmap_font", false).toBool();
     m_font.fromString(fontname);
 
     if (m_update)
     {
         delete m_metrics;
-        m_metrics = new QFontMetrics(m_font);
+        m_bitmap =  m_bitmapConf && (m_text.toLatin1() == m_text.toLocal8Bit());
     }
     else
     {
-        m_update = TRUE;
-        m_metrics = new QFontMetrics(m_font);
+        m_update = true;
+        m_bitmap = false;
+
     }
+    m_metrics = new QFontMetrics(m_font);
+    setText(m_text);
 }
 
 void TextScroller::setProgress(int progress)
@@ -157,6 +177,23 @@ void TextScroller::showEvent (QShowEvent *)
         m_timer->start();
 }
 
+inline void drawBitmapText(int x, int y, const QString &text, QPainter *paint, Skin *skin)
+{
+    QString lowertext = text.toLower();
+    int chwidth, ypix;
+    {
+        QPixmap samplechar = skin->getLetter('a');
+        chwidth = samplechar.width();
+        ypix = y - samplechar.height();
+    }
+    for (int i = 0; i < lowertext.size(); i++)
+    {
+        QPixmap pixchar = skin->getLetter(lowertext[i]);
+        paint->drawPixmap(x, ypix, pixchar);
+        x += chwidth;
+    }
+}
+
 void TextScroller::paintEvent (QPaintEvent *)
 {
     QPainter paint (this);
@@ -164,13 +201,28 @@ void TextScroller::paintEvent (QPaintEvent *)
     paint.setFont(m_font);
     if (m_progress < 0)
     {
-        if (m_autoscroll)
+        if(m_bitmap)
         {
-            paint.drawText (154 + x + m_metrics->width (m_scrollText) + 15,12, m_scrollText);
-            paint.drawText (154 + x,12, m_scrollText);
+            if (m_autoscroll)
+            {
+                drawBitmapText (154 + x + m_offset * 2, 12, m_scrollText, &paint, m_skin);
+                drawBitmapText (154 + x + m_offset, 12, m_scrollText, &paint, m_skin);
+                drawBitmapText (154 + x, 12, m_scrollText, &paint, m_skin);
+            }
+            else
+                drawBitmapText (154 + x,12, m_text, &paint, m_skin);
         }
         else
-            paint.drawText (154 + x,12, m_text);
+        {
+            if (m_autoscroll)
+            {
+                paint.drawText (154 + x + m_offset * 2, 12, m_scrollText);
+                paint.drawText (154 + x + m_offset, 12, m_scrollText);
+                paint.drawText (154 + x, 12, m_scrollText);
+            }
+            else
+                paint.drawText (154 + x,12, m_text);
+        }
     }
     else
         paint.drawText (4,12, tr("Buffering:") + QString(" %1\%").arg(m_progress));
@@ -180,11 +232,13 @@ void TextScroller::mousePressEvent (QMouseEvent *e)
 {
     if (e->button() == Qt::RightButton)
         m_menu->exec(e->globalPos());
-    else if (e->button() == Qt::LeftButton && m_autoscroll) {
+    else if (e->button() == Qt::LeftButton && m_autoscroll)
+    {
         m_timer->stop();
         press_pos = e->x() - (x + 154);
-        m_pressing = TRUE;
-    } else
+        m_pressing = true;
+    }
+    else
         QWidget::mousePressEvent(e);
 }
 
@@ -192,22 +246,26 @@ void TextScroller::mouseReleaseEvent (QMouseEvent *e)
 {
     if (e->button() == Qt::RightButton)
         m_menu->exec(e->globalPos());
-    else if (e->button() == Qt::LeftButton && m_autoscroll) {
+    else if (e->button() == Qt::LeftButton && m_autoscroll)
+    {
         m_timer->start();
-        m_pressing = FALSE;
-    } else
+        m_pressing = false;
+    }
+    else
         QWidget::mouseReleaseEvent(e);
 }
 
 void TextScroller::mouseMoveEvent (QMouseEvent *e)
 {
-    if (m_pressing) {
+    if (m_pressing)
+    {
         int bound = m_metrics->width (m_scrollText) + 15 - 1;
         x = (e->x() - press_pos) % bound;
         if (x < 0)
         	x += bound;
         x = x - bound - 154;
         update();
-    } else
+    }
+    else
         QWidget::mouseMoveEvent(e);
 }
